--- **LibInit** should make using Ace3 even more easier and pleasant.
-- An embeddable library which offer clean methods to build a configuration table
-- instead of directly fiddling wit an Ace options table
-- @name LibInit
-- @class module
-- @author Alar of Daggerspine
-- @release 31
--
local __FILE__=tostring(debugstack(1,2,0):match("(.*):9:")) -- Always check line number in regexp and file

local MAJOR_VERSION = "LibInit"
local MINOR_VERSION = 33
local off=(_G.RED_FONT_COLOR_CODE or '|cffff0000') .. _G.VIDEO_OPTIONS_DISABLED ..  _G.FONT_COLOR_CODE_CLOSE or '|r'
local on=(_G.GREEN_FONT_COLOR_CODE or '|cff00ff00') .. _G.VIDEO_OPTIONS_ENABLED ..  _G.FONT_COLOR_CODE_CLOSE or '|r'
local nop=function()end
local pp=print -- Keeping a handy plain print around
local assert=assert
local strconcat=strconcat
local tostring=tostring
local _G=_G -- Unmodified env
local dprint=function() end
--@debug@
LoadAddOn("LibDebug")
LoadAddOn("Blizzard_DebugTools")
if LibDebug then
	--pulling libdebug print in without pulling also the whole _G management and without changing loading addon env
	LibDebug()
	dprint=print
	setfenv(1,_G)
end
--@end-debug@
--GAME_LOCALE="itIT"
local me, ns = ...
local LibStub=LibStub
local obj,old=LibStub:NewLibrary(MAJOR_VERSION,MINOR_VERSION)
local upgrading
if obj then
	upgrading=old
--@debug@
	if old then
		dprint(strconcat("Upgrading ",MAJOR_VERSION,'.',old,' to',MINOR_VERSION,' from ',__FILE__))
	else
		dprint(strconcat("Loading ",MAJOR_VERSION,'.',MINOR_VERSION,' from ',__FILE__))
	end
--@end-debug@
else
--@debug@
	dprint(strconcat("Equal or newer ",MAJOR_VERSION,' already loaded from ',__FILE__))
--@end-debug@
	return
end
local lib=obj --#Lib
local L
local C=LibStub("LibInit-Colorize")()
-- Upvalues
local _G=_G
local floor=floor
local abs=abs
local wipe=wipe
local print=print
local next = next
local pairs = pairs
local pcall = pcall
local type = type
local GetTime = GetTime
local gcinfo = gcinfo
local unpack = unpack
local geterrorhandler = geterrorhandler
local GetContainerNumSlots=GetContainerNumSlots
local GetContainerItemID=GetContainerItemID
local GetItemInfo=GetItemInfo
local UnitHealth=UnitHealth
local UnitHealthMax=UnitHealthMax
local setmetatable=setmetatable
local NUM_BAG_SLOTS=NUM_BAG_SLOTS
local InCombatLockdown=InCombatLockdown
local error=error
local tinsert=tinsert
local debugstack=debugstack
local ipairs=ipairs
local GetAddOnMetadata=GetAddOnMetadata
local format=format
local tostringall=tostringall
local tonumber=tonumber
local strconcat=strconcat
local strjoin=strjoin
local strsplit=strsplit
local select=select
local coroutine=coroutine
local cachedGetItemInfo
local toc=select(4,GetBuildInfo())

--]]
-- Help sections
local titles
local RELNOTES
local LIBRARIES
local PROFILE
local HELPSECTIONS
local AceConfig = LibStub("AceConfig-3.0",true)
assert(AceConfig,"LibInit needs AceConfig-3.0")
local AceRegistry = LibStub("AceConfigRegistry-3.0",true)
local AceDBOptions=LibStub("AceDBOptions-3.0",true)
local AceConfigDialog=LibStub("AceConfigDialog-3.0",true)
local AceGUI=LibStub("AceGUI-3.0",true)
local Ace=LibStub("AceAddon-3.0")
local AceLocale=LibStub("AceLocale-3.0",true)
local AceDB  = LibStub("AceDB-3.0",true)


-- Persistent tables
lib.mixinTargets=lib.mixinTargets or {}
lib.toggles=lib.toggles or {}
lib.chats=lib.chats or {}
lib.options=lib.options or {}
lib.pool=lib.pool or setmetatable({},{__mode="k"})
lib.coroutines=lib.coroutines or setmetatable({},{__index=function(t,k) rawset(t,k,{}) return t[k] end})
-- Recycling function from ACE3
local new, del, copy, cached, stats
do
	local pool = lib.pool
--@debug@
	local newcount, delcount,createdcount,cached = 0,0,0
--@end-debug@
	function new()
--@debug@
		newcount = newcount + 1
--@end-debug@
		local t = next(pool)
		if t then
			pool[t] = nil
			return t
		else
--@debug@
			createdcount = createdcount + 1
--@end-debug@
			return {}
		end
	end
	function copy(t)
		local c = new()
		for k, v in pairs(t) do
			c[k] = v
		end
		return c
	end
	function del(t)
--@debug@
		delcount = delcount + 1
--@end-debug@
		wipe(t)
		pool[t] = true
	end
	function cached()
		local n = 0
		for k in pairs(pool) do
			n = n + 1
		end
		return n
	end
--@debug@
	function stats()
		print("Created:",createdcount)
		print("Aquired:",newcount)
		print("Released:",delcount)
		print("Cached:",cached())
	end
--@end-debug@
--[===[@non-debug@
	function stats()
		return
	end
--@end-non-debug@]===]
end
--- Create a new AceAddon-3.0 addon.
-- Any library you specified will be embeded, and the addon will be scheduled for
-- its OnInitializee and OnEnabled callbacks.
-- The final addon object, with all libraries embeded, will be returned.
-- Options table format:
-- 	*profile: choose the initial profile (if omittete, uses a per character one)
--		*noswitch: disables Ace profile managemente, user will not be able to change it
--		*nogui: do not generate a gui for configuration
--		*nohelp: do not generate help (actually, help generation is not yet implemented)
--		*enhancedProfile: adds "Switch all profiles to default" and "Remove unused profiles" do Ace profile gui
--
-- @tparam[opt] table target to use as a base for the addon (optional)
-- @tparam string name Name of the addon object to create
-- @tparam[opt] table options options list
-- @tparam[opt] bool full If true, all available and embeddable Ace3 library are embedded
-- @tparam[opt] string ... List of libraries to embed into the addon
-- @treturn table new addon
--
-- @usage
-- --Create a simple addon object
-- MyAddon = LibStub("LibInit"):NewAddon("MyAddon", "AceEvent-3.0")
--
-- -- Create a Addon object based on the table of a frame
-- local MyFrame = CreateFrame("Frame")
-- MyAddon = LibStub("LibInit"):NewAddon(MyFrame, "MyAddon", "AceEvent-3.0")
-- -- Create an Addon based on the private table provided by Blizzard Code:
-- local myname,addon = ...
-- LibStub("LibInit"):NewAddon(addon,myname)
--
---
function lib:NewAddon(target,...)
	local name
	local customOptions
	local start=1
	if type(target) ~= "table" then
		name=target
		target={}
	else
		name=(select(1,...))
		start=2
	end
	assert(Ace,"Could not find Ace3 Library")
	assert(type(name)=="string","Name is mandatory")
	local appo={}
	appo[MAJOR_VERSION]=true
	appo["AceConsole-3.0"]=true
	for i=start,select('#',...) do
		local mix=select(i,...)
		if type(mix)=="boolean" and mix then
			for n,k in  LibStub:IterateLibraries() do
				if (n:match("Ace%w*-3%.0") and k.Embed) then appo[n]=true end
			end
		elseif type(mix)=="string" then
			appo[mix]=true
		elseif type(mix)=="table" then
			customOptions=mix
		end
	end
	local mixins=new()
	for i,_ in pairs(appo) do
		tinsert(mixins,i)
	end
	local target=Ace:NewAddon(target,name,unpack(mixins))
	del(mixins)
	appo=nil
	local options={}
	options.name=name
	options.first=true
	options.libstub=__FILE__
	options.version=GetAddOnMetadata(name,'Version') or "Internal"
	if (options.version:sub(1,1)=='@') then
		options.version=GetAddOnMetadata(name,'X-Version') or "Internal"
	end
	local b,e=options.version:find(" ")
	if b and b>1 then
		options.version=options.version:sub(1,b-1)
	end
	options.revision=GetAddOnMetadata(name,'X-revision') or "Alpha"
	if (options.revision:sub(1,1)=='@') then
		options.revision='Development'
	end
	options.prettyversion=format("%s (Revision: %s)",tostringall(options.version,options.revision))
	options.title=GetAddOnMetadata(name,"title") or 'No title'
	options.notes=GetAddOnMetadata(name,"notes") or 'No notes'
	-- Setting sensible default for mandatory fields
	options.ID=GetAddOnMetadata(name,"X-ID") or name
	options.DATABASE=GetAddOnMetadata(name,"X-Database") or "db" .. options.ID
	lib.toggles[target]={}
	if customOptions then
		for k,v in pairs(customOptions) do
			local key=strlower(k)
			if key=="enhanceprofile" then key = "enhancedprofile" end
			if 	key=="profile"
				or key=="noswitch"
				or key=="nogui"
				or key=="nohelp"
				or key=="enhancedprofile"
					then
				options[key]=v
			else
				error("Invalid options: " .. k)
			end
		end
	end
	lib.options[target]=options
	RELNOTES=L["Release Notes"]
	PROFILE=L["Profile"]
	HELPSECTIONS={PROFILE,RELNOTES}
	titles={
		RELNOTES=RELNOTES,
		PROFILE=PROFILE
	}
	return target
end
-- Combat scheduler done with LibCallbackHandler
local CallbackHandler = LibStub:GetLibrary("CallbackHandler-1.0")
if not lib.CombatScheduler then
	lib.CombatScheduler = CallbackHandler:New(lib,"_OnLeaveCombat","_CancelCombatAction")
	lib.CombatFrame=CreateFrame("Frame")
	lib.CombatFrame:SetScript("OnEvent",function()
		lib.CombatScheduler:Fire("LIBINIT_END_COMBAT")
		if lib.CombatScheduler.insertQueue then
			wipe(lib.CombatScheduler.insertQueue) -- hackish, depends on internal callbackhanlder implementation
		end
		wipe(lib.CombatScheduler.events)
		lib.CombatScheduler.recurse=0
		for _,co in pairs(lib.coroutines) do
			if co.waiting then
				co.waiting=false
				co.repeater()
			end
		end
	end)
	lib.CombatFrame:RegisterEvent("PLAYER_REGEN_ENABLED")
end
local tremove=tremove
local function Run(args) tremove(args,1)(unpack(args)) end
--- Executes an action as soon as combat restrictions lift
-- Action can be executed immediately if toon is out of combat
-- @tparam string|function action To be executed, Can be a function or a method name
-- @tparam[opt] mixed ... More parameters will be directly passed to action
--
function lib:OnLeaveCombat(action,...)
	if type(action)~="string" and type(action)~="function" then
		error("Usage: OnLeaveCombat (\"action\", ...): 'action' - string or function expected.", 2)
	end
	if type(action)=="string" and type(self[action]) ~= "function" then
		error("Usage: OnLeaveCombat (\"action\", ...): 'action' - method '"..tostring(action).."' not found on self.", 2)
	end
	if type(action) =="string" then
		lib._OnLeaveCombat(self,"LIBINIT_END_COMBAT",Run,{self[action],self,...})
	else
		lib._OnLeaveCombat(self,"LIBINIT_END_COMBAT",Run,{action,...})
	end
	if (not InCombatLockdown()) then
		lib.CombatFrame:GetScript("OnEvent")()
	end
end

function lib:NewSubModule(name,...)
	local obj=self:NewModule(name,...)
	-- To avoid strange interactions
	obj.OnInitialized=function()end -- placeholder
	obj.OnInitialize=function(self,...) return  self:OnInitialized(...) end
	obj.OnEnable=nil
	obj.OnDisable=nil
	return obj
end
function lib:NewSubClass(name)
	return self:NewSubModule(name,self)
end
function lib:NewTable()
	return new()
end
function lib:DelTable(t)
	return del(t)
end
function lib:CachedTableCount()
	return cached()
end
function lib:CacheStats()
	return stats()
end
--- Returns a closure to call a method as simple local function
--@usage local print=lib:Wrap("print")
function lib:Wrap(nome)
	if (nome=="Trace") then
		return function(...) lib._Trace(self,1,...) end
	end
	if (type(self[nome])=="function") then
		return function(...) self[nome](self,...) end
	else
		return nop
	end
end
function lib:GetAddon(name)
	return Ace:GetAddon(name,true)
end
function lib:GetLocale()
	return AceLocale:GetLocale(self.name)
end
function lib:Gradient(perc)
	return self:ColorGradient(perc,0,1,0,1,1,0,1,0,0)
end
function lib:ColorToString(r,g,b)
	return format("%02X%02X%02X", 255*r, 255*g, 255*b)
end
function lib:ColorGradient(perc, ...)
	if perc >= 1 then
		local r, g, b = select(select('#', ...) - 2, ...)
		return r, g, b
	elseif perc <= 0 then
		local r, g, b = ...
		return r, g, b
	end
	local num = select('#', ...) / 3
	local segment, relperc = math.modf(perc*(num-1))
	local r1, g1, b1, r2, g2, b2 = select((segment*3)+1, ...)
	return r1 + (r2-r1)*relperc, g1 + (g2-g1)*relperc, b1 + (b2-b1)*relperc
end
-- Gestione variabili
local varmeta={}
do
	local function f1(self,flag,value)
		return self:Apply(flag,value)
	end
	local function f2(self,flag,value)
		return self['Apply' .. flag](self,value)
	end
	varmeta={
		__index =
		function(table,cmd)
			local self=rawget(table,'_handler')
			if (type(self["Apply" .. cmd]) =='function') then
				rawset(table,cmd,f2)
			elseif (type(self.Apply)=='function') then
				rawset(table,cmd,f1)
			else
				rawset(table,cmd,function(...) end)
			end
			return rawget(table,cmd)
		end
	}
end
function lib:GetChatFrame(chat)
	if (chat) then
		if (lib.chats[chat]) then return lib.chats[chat] end
		for i=1,NUM_CHAT_WINDOWS do
			local frame=_G["ChatFrame" .. i]
			if (not frame) then break end
			if (frame.name==chat) then lib.chats[chat]=frame return frame end
		end
		return nil
	end
	return DEFAULT_CHAT_FRAME
end

local Myclass
---
-- Check if the unit in target hast the requested class
-- @tparam #string class Requested Class
-- @tparam #string target Requested Unit (default 'player')
-- @return #boolean true if target has the requeste class
function lib:Is(class,target)
	target=target or "player"
	if (target == "player") then
		if (not Myclass) then
			Myclass=select(2,UnitClass('player'))
		end
		return Myclass==strupper(class)
	else
		local    rc,_,unitclass=pcall(UnitClass,target)
		if (rc) then
			return unitclass==strupper(class)
		else
			return false
		end
	end
end
---
-- Parses a command from chat or from an table options handjer command
-- Internally calls AceConsole-3.0:GetArgs
-- @tparam mixed msg Can be a string (chat command) or a table (called by Ace3 Options Table Handler)
-- @tparam number n index in command list
-- @return command,subcommand,arg,full string after command
function lib:Parse(msg,n)
	if (not msg) then
		return nil
	end
	if (type(msg) == 'table' and msg.input ) then msg=msg.input end
	if (type(msg) ~= 'string') then return end
	return self:GetArgs(msg,n)
end
---
-- Parses an itemlink and returns itemId without calling API again
-- @tparam string itemlink A standard wow itemlink
-- @treturn number itemId or 0
function lib:GetItemID(itemlink)
	if (type(itemlink)=="string") then
			local itemid,context=GetItemInfoFromHyperlink(itemlink)
			return tonumber(itemid) or 0
			--return tonumber(itemlink:match("Hitem:(%d+):")) or 0
	else
			return 0
	end
end
---
-- Return the toal numner of bag slots
function lib:GetTotalBagSlots()
	local i=0
	for bag=0,NUM_BAG_SLOTS do
		i=i+GetContainerNumSlots(bag)
	end
	return i
end
---
-- Scans Bags for an item based on different criteria
--
-- All parameters are optional.
-- With no parameters ScanBags returns the first empty slot
--
-- @tparam[opt] number index is index in GetItemInfo result. 0 is a special case to match just itemid
-- @tparam[opt] number value is the value against to match. 0 is a special case for empty slot
-- @tparam[opt] number startbag and startslot are used to restart scan from the last item found
-- @tparam[opt] number startslot
-- @return Found ItemId,bag,slot,full GetItemInfo result
function lib:ScanBags(index,value,startbag,startslot)
	index=index or 0
	value=value or 0
	startbag=startbag or 0
	startslot=startslot or 1
	for bag=startbag,NUM_BAG_SLOTS do
		for slot=startslot,GetContainerNumSlots(bag),1 do
			local itemlink=GetContainerItemLink(bag,slot)
			if (itemlink) then
				if (index==0) then
					if (self:GetItemID(itemlink)==value) then
						return itemlink,bag,slot
					end
				else
					local test=CachedGetItemInfo(itemlink,index)
					if (value==test) then
						return itemlink,bag,slot
					end
				end
			elseif value==0 then
				return bag,slot

			end
		end
	end
	return false
end
--- Returns unit's health as a normalized percent value
-- @tparam string unit A standard unit name
-- @treturn number health as percent value

function lib:Health(unit)
		local totale=UnitHealthMax(unit) or 1
		local corrente=UnitHealth(unit) or 1
		if (corrente == 0) then corrente =1 end
		if (totale==0) then totale = corrente end
		local life=corrente/totale*100
		return math.ceil(life)
end

function lib:Age(secs)
		return self:TimeToStr(GetTime() - secs)
end
function lib:Mana(unit)
		local totale=UnitManaMax(unit) or 1
		local corrente=UnitMana(unit) or 1
		if (corrente == 0) then corrente =1 end
		if (totale==0) then totale = corrente end
		local life=corrente/totale*100
		return math.ceil(life)
end
function lib:IsFriend(player)
	local i
	for i =1,GetNumFriends() do
		local name,_,_,_,_ =GetFriendInfo(i)
		if (name == player) then
			return true
		end
	end
	return false
end
function lib:GetDistanceFromMe(unit)
	if not unit then return 99999 end
	local x,y=GetPlayerMapPosition(unit)
	return self:GetUnitDistance(x,y)
end
function lib:GetUnitDistance(x,y,unit)
		unit=unit or "player"
		local from={}
		local to={}
		from.x,from.y=GetPlayerMapPosition(unit)
		to.x=x
		to.y=y
		return self:GetDistance(from,to) * 10000
end
function lib:GetDistance(a,b)
--------------
-- Calculates distance betweeb 2 points given as
-- a.x,a.y and b.x,b.y
	local x=b.x - a.x
	local y=b.y -a.y
	local d=x*x + y* y
	local rc,distance=pcall(math.sqrt,d)
	if (rc) then
				return distance
		else
				return 99999
		end
end
---
-- Returns a numeric representation of version.
-- Can be overridden
-- In default incarnation assumes that version is in the form x,y,z
-- @return z+y*100+x*10000
--
function lib:NumericVersion()
	local v=tonumber(self.version)
	if (v) then return v end
	if (type(self.version) == "string") then
		local a,b,c=self.version:match("(%d*)%D?(%d*)%D?(%d*)%D*")
		a=tonumber(a) or 0
		b=tonumber(b) or 0
		c=tonumber(c) or 0
		return a*10000+b*100+c
	else
		return 0
	end
end
function lib:OnInitialized()
	print("|cff33ff99"..tostring( self ).."|r:",format(ITEM_MISSING,"OnInitialized"))
end
function lib:LoadHelp()
end
function lib:SetDbDefaults()
end
function lib:SetOptionsTable()
end
local function loadOptionsTable(self)
	local options=lib.options[self]
	self.OptionsTable={
		handler=self,
		type="group",
		childGroups="tab",
		name=options.title,
		desc=options.notes,
		args={
			gui = {
				name="GUI",
				desc=_G.CHAT_CONFIGURATION,
				type="execute",
				func="Gui",
				guiHidden=true,
			},
--@debug@
			help = {
				name="HELP",
				desc="Show help",
				type="execute",
				func="Help",
				guiHidden=true,
			},
			debug = {
				name="DBG",
				desc="Enable debug",
				type="execute",
				func="Debug",
				guiHidden=true,
				cmdHidden=true,
			},
--@end-debug@
			silent = {
				name="SILENT",
				desc="Eliminates startup messages",
				type="execute",
				func=function()
					self.db.global.silent=not self.db.global.silent
					print("Silent is now",self.db.global.silent,self.db.global.silent and "true" or "false" )
				end,
				guiHidden=true,
			},
			on = {
				name=strlower(_G.ENABLE),
				desc=_G.ENABLE .. ' ' .. options.title,
				type="execute",
				func="Enable",
				guiHidden=true,
			},
			off = {
				name=strlower(_G.DISABLE),
				desc=_G.DISABLE .. ' ' .. options.title,
				type="execute",
				func="Disable",
				guiHidden=true,
				arg='Active'
			},
		}
	}
end
local function loadDbDefaults(self)
	self.DbDefaults={
		char={
			firstrun=true,
			lastversion=0,
		},
		global={
			firstrun=true,
			lastversion=0,
			lastinterface=60200
		},
		profile={
			toggles={
					Active=true,
			},
			["*"]={},
		}
	}
	self.MenuLevels={"root"}
	self.ItemOrder=setmetatable({},{
		__index=function(table,key) rawset(table,key,1)
			return 1
		end
		}
	)
end
local function BuildHelp(self)
	local main=self.name
	for _,section in ipairs(HELPSECTIONS) do
		if (section == RELNOTES) then
			self:HF_Load(section,main..section,' ' .. tostring(self.version) .. ' (r:' .. tostring(self.revision) ..')')
		else
			self:HF_Load(section,main .. section,'')
		end
	end
end
function lib:IsFirstRun()
	return self.db.global.firstrun
end
function lib:IsNewVersion()
	return self.numericversion > self.db.global.lastnumericversion and self.db.global.lastnumericversion or false
end
function lib:IsNewTocVersion()
	return self.interface > self.db.global.lastinterface  and self.db.global.lastinterface or false
end
function lib:RegisterDatabase(dbname,defaults,profile)
	return AceDB:New(dbname,defaults,profile)
end
local function SetCommonProfile(info,...)
	local db=info.handler.db
	for k,v in pairs(db.sv.profileKeys) do
		db.sv.profileKeys[k]="Default"
	end
	db:SetProfile("Default")
end
local function PurgeProfiles(info,...)
	local profiles=new()
	local used=new()
	local db=info.handler.db
	db:GetProfiles(profiles)
	for k,v in pairs(db.sv.profileKeys) do
		used[v]=true
	end
--@debug@
	DevTools_Dump(profiles)
	DevTools_Dump(used)
--@end-debug@
	for _,v in ipairs(profiles) do
		if not used[v] then
			db:DeleteProfile(v)
		end
	end
	del(used)
	del(profiles)

end
local function SetupProfileSwitcher(tbl,addon)
	local profiles=tbl.handler:ListProfiles({args="both"})
	local default=profiles.Default or "Default"
	wipe(profiles)
	tbl.args.UseDefault_Desc={
		order=900,
		type='description',
		name="\n"..format(L['UseDefault_Desc'],default)
	}
	tbl.args.UseDefault={
		order=910,
		type='execute',
		func=SetCommonProfile,
		name=format(L['UseDefault1'],default),
		desc=format(L['UseDefault2'],default),
		width="double",
	}
	tbl.args.Purge_Desc={
		order=920,
		type='description',
		--name="forcedescname",
		name="\n"..L['Purge_Desc'],
	}
	tbl.args.Purge={
		order=930,
		type='execute',
		func=PurgeProfiles,
		name=L['Purge1'],
		desc=L['Purge2'],
		width="double",
	}
end
function lib:OnInitialize(...)
	self.numericversion=self:NumericVersion() -- Initialized now becaus NumericVersion could be overrided
	--CachedGetItemInfo=self:GetCachingGetItemInfo()
	loadOptionsTable(self)
	loadDbDefaults(self)
	self:SetOptionsTable(self.OptionsTable) --hook
	self:SetDbDefaults(self.DbDefaults) -- hook
	local options=lib.options[self]
	self.version=self.version or options.version
	self.prettyversion=self.prettyversion or options.prettyversion
	self.revision=self.revision or options.revision
	if (AceDB and not self.db) then
		self.db=AceDB:New(options.DATABASE,nil,options.profile)
		dprint(self.db:GetCurrentProfile())
	end
	if self.db then
		self.db:RegisterDefaults(self.DbDefaults)
		if (not self.db.global.silent) then
			self:Print(format("Version %s %s loaded (%s)",
				self:Colorize(options.version,'green'),
				self:Colorize(format("(Revision: %s)",options.revision),"silver"),
				"Disable message with /" .. strlower(options.ID) .. " silent")
			)
		end
		self:SetEnabledState(self:GetBoolean("Active"))
	else
		self.db=setmetatable({},{
			__index=function(t,l)
				assert(false,"You need AceDB-3.0 in order to use database")
			end
			}
		)
		self:SetEnabledState(true)
	end
	-- I have for sure some library that needs to be intialized Before the addon
	for _,library in self:IterateEmbeds(self) do
		local lib=LibStub(library)
		if (lib.OnEmbedPreInitialize) then
			lib:OnEmbedPreInitialize(self)
		end
	end

	self.help=setmetatable(
			{},
			{__index=function(table,key)
					rawset(table,key,"")
					return rawget(table,key)
					end
			}
	)
	--===============================================================================
	-- Calls initialization Callback
	local ignoreProfile=self:OnInitialized(...)
	--===============================================================================
	if (not self.OnDisabled) then
		self.OptionsTable.args.on=nil
		self.OptionsTable.args.off=nil
		self.OptionsTable.args.standby=nil
	end
	if (type(self.LoadHelp)=="function") then self:LoadHelp() end
	local main=options.name
	BuildHelp(self)
	if AceConfig and not options.nogui then
		AceConfig:RegisterOptionsTable(main,self.OptionsTable,{main,strlower(options.ID)})
		self.CfgDlg=AceConfigDialog:AddToBlizOptions(main,main )
		if (not ignoreProfile and not options.noswitch) then
			if (AceDBOptions) then
				local profileOpts=AceDBOptions:GetOptionsTable(self.db)
				self.ProfileOpts={} -- We dont want to propagate this change to all ace3 addons
				for k,v in pairs(profileOpts) do
					if k=='args' then
						self.ProfileOpts.args={}
						for k2,v2 in pairs(v) do
							self.ProfileOpts.args[k2]=v2
						end
					else
						self.ProfileOpts[k]=v
					end
				end
				titles.PROFILE=self.ProfileOpts.name
				self.ProfileOpts.name=self.name
				if options.enhancedprofile then
					SetupProfileSwitcher(self.ProfileOpts,self)
				end
				local profile=main..PROFILE
			end
			AceConfig:RegisterOptionsTable(main .. PROFILE,self.ProfileOpts)
			AceConfigDialog:AddToBlizOptions(main .. PROFILE,titles.PROFILE,main)
		end
	else
		self.OptionsTable.args.gui=nil
	end
	if (self.help[RELNOTES]~='') then
		self.CfgRel=AceConfigDialog:AddToBlizOptions(main..RELNOTES,titles.RELNOTES,main)
	end
	if AceDB then
		self:UpdateVersion()
	end
end
function lib:UpdateVersion()
	if (type(self.db.char) == "table") then
		self.db.char.lastversion=self.numericversion
		self.db.char.firstun=false
	end
	if (type(self.db.global)=="table") then
		self.db.global.lastversion=self.numericversion
		self.db.global.firstrun=false
		self.db.global.lastinterface=self.interface
	end
end

-- help related functions
function lib:HF_Push(section,text)
	if section then section=titles[section] end
	section=section or self.lastsection or RELNOTES
	self.lastsection=section
	self.help[section]=self.help[section]  .. '\n' .. text
end
local getlibs
do
	local libs={}
		function lib:HF_Lib(libname)
				local o,minor=LibStub(libname,true)
				if (o and libs) then
						if (not libs[o] or libs[o] <minor) then
								libs[libname]=minor
						end
				end
		end
		function getlibs(self)
				local appo={}
				if (not libs) then return end
				for i,_ in pairs(libs) do
						table.insert(appo,i)
				end
				table.sort(appo)
				for _,libname in pairs(appo) do
						local minor=libs[libname]
						self:HF_Pre(format("%s release: %s",self:Colorize(libname,'green'),self:Colorize(minor,'orange')),LIBRARIES)
				end
				libs=nil
		end
end

function lib:HF_Toggle(flag,description)
	flag=C(format("/%s toggle %s: ",strlower(lib.options[self].ID),flag),'orange') ..C(description,'white')
	self:HF_Push(TOGGLES,"\n" .. C(flag,'orange'))
end

function lib:HF_Title(text,section)
	self:HF_Push(section,C(text or '','yellow') .. "\n")
end
function lib:HF_Command(text,description,section)
	self:HF_Push(section,C(text or '','orange') .. ':' ..  C(description or '','yellow') .. "\n")
end

function lib:HF_Paragraph(text,section)
	self:HF_Push(section,"\n"..C(text,'green'))
end
function lib:HF_CmdA(command,description,tooltip)
	self:HF_Push(nil,
	C('/' .. command,'orange') .. ' : ' .. (description or '') .. '\n' .. C(tooltip or '','yellow'))
end
function lib:HF_Cmd(command,description,tooltip)
	command=lib.options[self].ID .. ' ' .. command
	self:HF_CmdA(command,description,tooltip)
end
function lib:HF_Pre(testo,section)
	self:HF_Push(section,testo)
end
function lib:Wiki(testo,section)
	section=section or self.lastsection or RELNOTES
	self.lastsection=section
	local fmtbullet=" * %s\n"
	local progressive=1
	local fmtnum=" %2d. %s\n"
	local fmthead1="|cff" .. C.Orange  .."%s|r\n \n \n"
	local fmthead2="|cff" .. C.Yellow  .."%s|r\n \n"
	local text=''
	for line in testo:gmatch("(%C*)%c+") do
		line=line:gsub("^ *","")
		line=line:gsub(" *$","")
		local i,j= line:find('^%=+')
		if (i) then
			if (j==1) then
				text=text .. fmthead1:format(line:sub(j+1,-j-1))
			else
				text=text .. fmthead2:format(line:sub(j+1,-j-1))
			end
		else
			local i,j= line:find('^%*+')
			if (i) then
				text=text.. fmtbullet:format(line:sub(j+1))
			else
				local i,j= line:find('^#+')
				if (i) then
					text=text .. fmtnum:format(progressive,line:sub(j+1))
					progressive=progressive + 1
				else
					text=text .. line.."\n"
				end
			end
		end
	end
	self.help[section]=self.help[section]  .. '\n' .. text
end

function lib:RelNotes(major,minor,revision,t)
	local fmt=self:Colorize("Release note for %d.%d.%s",'Yellow') .."\n%s"
	local lines={}
	local spacer=""
	local maxpanlen=70
	lines={strsplit("\n",t)}
	local max=5
	for i,tt in ipairs(lines) do
		local prefix,text=tt:match("^(%a+):(.*)")
		if (prefix == "Fixed" or prefix=="Fix") then
			prefix=self:Colorize("Fix: ",'Red')
			spacer="       "
		elseif (prefix == "Feature") then
			prefix=self:Colorize("Feature: ",'Green')
			spacer=             "         "
		else
			text=tt
			prefix=spacer
		end
		local tta=""
		tt=text
		while (tt:len() > maxpanlen)  do
			local p=tt:find("[%s%p]",maxpanlen -10) or maxpanlen
			tta=tta..prefix..tt:sub(1,p) .. "\n"
			prefix=spacer
			tt=tt:sub(p+1)
		end
		tta=tta..prefix..tt
		tta=tta:gsub("Upgrade:",self:Colorize("Upgrade:",'Azure'))
		lines[i]=tta:gsub("Example:",self:Colorize("Example:",'Orange'))
		max=max-1
		if (max<1) then
			break
		end
	end
	self:HF_Push(RELNOTES,fmt:format(major,minor,revision,strjoin("\n",unpack(lines))))
end

function lib:HF_Load(section,optionname,versione)
-- Creazione pannello di help
-- Livello due del
	if (section == LIBRARIES) then
		getlibs(self)
	end
	local testo =self.help[section]
	--debug(section)
	--debug(optionname)
	--debug(self.title)
	if (testo ~= '') then
		AceConfig:RegisterOptionsTable(optionname, {
			name = lib.options[self].title .. (versione or ""),
			type = "group",
			args = {
				help = {
					type = "description",
					name = testo,
					fontSize='medium',
				},
			},
		})
		AceConfigDialog:SetDefaultSize(optionname, 600, 400)
	end
end
-- var area
local function getgroup(self)
	local group=self.OptionsTable
	local m=self.MenuLevels
	for i=2,#m do
			group=group.args[self.MenuLevels[i]]
	end
	if (type(group) ~= "table") then
			group={}
	end
	return group
end
local function getorder(self,group)
	local i=self.ItemOrder[group.name]+1
	self.ItemOrder[group.name]=i
	return i
end
local function toflag(...)
	local appo=''
	for i=1,select("#",...) do
		appo=appo .. tostring(select(i,...))
	end
		return appo:gsub("%W",'')
end
function lib:EndLabel()
	local m=self.MenuLevels
	if (#m > 1) then
			table.remove(m)
	end
end

--self:AddLabel("General","General Options",C.Green)
function lib:AddLabel(title,description,stringcolor)
	self:EndLabel()
	description=description or title
	stringcolor=stringcolor or C.yellow
	local t=self:AddSubLabel(title,description,stringcolor)
	t.childGroups="tab"
	self:AddSeparator(description)
	return t
end
--self:AddSubLabel("Local","Local Options",C.Green)
function lib:AddSubLabel(title,description,stringcolor)
	local m=self.MenuLevels
	description=description or title
	stringcolor=stringcolor or C.orange
	local group=getgroup(self)
	local flag=toflag(group.name,title)
	group.args[flag]={
			name="|cff" .. stringcolor .. title .. "|r",
			desc=description,
			type="group",
			cmdHidden=true,
			args={},
			order=getorder(self,group),
	}
	table.insert(m,flag)
	return group.args[flag]
end

--self:AddText("Testo"[,texture[,height[,width[,texcoords]]]])
function lib:AddText(text,image,imageHeight,imageWidth,imageCoords)
	local group=getgroup(self)
	local flag=toflag(group.name,text)
	local t={
			name=text,
			type="description",
			image=image,
			imageHeight=imageHeight,
			imageWidth=imageWidth,
			imageCoords=imageCoords,
			desc=text,
			order=getorder(self,group),

	}
	group.args[flag]=t
	return t
end

--self:AddToggle("AUTOLEAVE",true,"Quick Battlefield Leave","Alt-Click on hide button in battlefield alert leaves the queue")
function lib:AddBoolean(...) return self:AddToggle(...) end
function lib:AddToggle(flag,defaultvalue,name,description,icon)
	description=description or name
	local group=getgroup(self)
	local t={
			name=name,
			type="toggle",
			get="OptToggleGet",
			set="OptToggleSet",
			desc=description,
			width='full',
			arg=flag,
			cmdHidden=true,
			icon=icon,
			order=getorder(self,group),
	}
	lib.toggles[self][flag]=t
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
		self.db.profile.toggles[flag]=defaultvalue
	end
	return t
end

-- self:AddEdit("REFLECTTO",1,{a=1,b=2},"Whisper reflection receiver:","All your whispers will be forwarded to this guy")
function lib:AddSelect(flag,defaultvalue,values,name,description)
	description=description or name
	local group=getgroup(self)
	local t={
			name=name,
			type="select",
			get="OptToggleGet",
			set="OptToggleSet",
			desc=description,
			width="full",
			values=values,
			arg=flag,
			cmdHidden=true,
			order=getorder(self,group)
	}
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
		self.db.profile.toggles[flag]=defaultvalue
	end
	lib.toggles[self][flag]=t
	return t
end
function lib:AddMultiSelect(flag,defaultvalue,...)
	local t=self:AddSelect(flag,defaultvalue,...)
	t.type="multiselect"
	if type(self.db.profile.toggles[flag])~="table" then
		self.db.profile.toggles[flag]={}
	end
	if type(self.db.profile.toggles[flag]._default)=="nil" then
		self.db.profile.toggles[flag]=defaultvalue
		self.db.profile.toggles[flag]._default=true
	end
	return t
end
--self:AddSlider("RESTIMER",5,1,10,"Enable res timer","Shows a timer for battlefield resser",1)
function lib:AddRange(...) return self:AddSlider(...) end
function lib:AddSlider(flag,defaultvalue,min,max,name,description,step)
	description=description or name
	min=min or 0
	max=max or 100
	local group=getgroup(self)
	local isPercent=nil
	if (type(step)=="boolean") then
		isPercent=step
		step=nil
	else
		step=tonumber(step) or 1
	end
	local t={
		name=name,
		type="range",
		get="OptToggleGet",
		set="OptToggleSet",
		desc=description,
		width="full",
		arg=flag,
		step=step,
		isPercent=isPercent,
		min=min,
		max=max,
		order=getorder(self,group),
	}
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
		self.db.profile.toggles[flag]=defaultvalue
	end
	lib.toggles[self][flag]=t
	return t
end
-- self:AddEdit("REFLECTTO","","Whisper reflection receiver:","All your whispers will be forwarded to this guy","How to use it")
function lib:AddEdit(flag,defaultvalue,name,description,usage)
	description=description or name
	usage = usage or description
	local group=getgroup(self)
	local t={
			name=name,
			type="input",
			get="OptToggleGet",
			set="OptToggleSet",
			desc=description,
			arg=flag,
			usage=usage,
			order=getorder(self,group),

	}
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
			self.db.profile.toggles[flag]=defaultvalue
	end
	lib.toggles[self][flag]=t
	return t
end

-- self:AddAction("openSpells","Opens spell panel","You can choose yoru spells in spell panel")
function lib:AddAction(method,label,description,private)
	label=label or method
	description=description or label
		local group=getgroup(self)
		local t={
			func=method,
			name=label,
			type="execute",
			desc=description,
			confirm=false,
			cmdHidden=true,
			order=getorder(self,group)
		}
	if (private) then t.hidden=true end
	group.args[strlower(label)]=t
	lib.toggles[self][method]=t
	return t
end

function lib:AddPrivateAction(method,name,description)
	return self:AddAction(method,name,description,true)
end
function lib:AddKeyBinding(flag,name,description)
	name=name or strlower(name)
	description=description or name
	local group=getgroup(self)
	local t={
		name=name,
		type="keybinding",
		get="OptToggleGet",
		set="OptToggleSet",
		desc=description,
		arg=flag,
		order=getorder(self,group)
	}
	group.args[flag]=t
	lib.toggles[self][flag]=t
	return t
end
function lib:AddTable(flag,table)
	local group=getgroup(self)
	group.args[flag]=table
	lib.toggles[self][flag]=table
end
local function OpenCmd(self,info,args)
	return self[info.arg](self,args,strsplit(' ',args))
end
function lib:AddOpenCmd(command,method,description,arguments,private)
	method=method or command
	description=description or command
	local group=getgroup(self)
	if (not private) then
		local command=C('/' .. lib.options[self].ID .. ' ' .. command .. " (" .. description .. ")" ,'orange')
		local t={
			name=command,
			type="description",
			order=getorder(self,group),
			fontSize='medium',
			width='full'
		}
		group.args[command .. 'title']=t
	end
	local t={
		name=command,
		type="input",
		arg=method,
		get=function(...) end,
		set=function(...) return OpenCmd(self,...) end,
		desc=description,
		order=getorder(self,group),
		guiHidden=true,
		hidden=private
	}
	if (type(arguments)=="table") then
		local validate={}
		for _,v in pairs(arguments) do
			validate[v]=v
		end
		t.values=validate
		t.type="select"
	end
	self.OptionsTable.args[command]=t

	return t
end
function lib:AddPrivateOpenCmd(command,method,description,arguments)
	return self:AddOpenCmd(command,method,description,arguments,true)
end
function lib:GetVarInfo(flag)
	return lib.toggles[self][flag]
end

--self:AddSubCmd(flagname,method,label,description)
function lib:AddSubCmd(flag,method,name,description,input)
	method=method or flag
	name=name or flag
	description=description or name
	local group=getgroup(self)
	debug("AddSubCmd " .. flag .. " for " .. method)
	local t={
		func=method,
		name=name,
		type="execute",
		input=input,
		desc=description,
		confirm=true,
		order=getorder(self,group),
		guiHidden=true,
	}
	group.args[flag]=t
	return t
end



--self:AddChatCmd(method,label,description)
function lib:AddChatCmd(method,label,description)
	if (not self.RegisterChatCommand) then
		LibStub("AceConsole-3.0"):Embed(self)
	end
	label=label or method
	self:RegisterChatCommand(label,method)
	description=description or label

	local group=getgroup(self)
	local t={
			name=C('/' .. label ..  " (" .. description .. ")",'orange'),
			type="description",
			order=getorder(self,group),
			fontSize="medium",
			width="full"
	}
	group.args[label .. 'title']=t
	return t
end

--self:AddSeparator(text)

function lib:AddSeparator(text)
	local group=getgroup(self)
	local i=getorder(self,group)
	local flag=group.name .. i
	flag=flag:gsub('%W','')
	local t={
			name=text,
			type="header",
			order=i,
	}
	group.args[flag]=t
	return t
end

function lib:OnEmbedEnable(first)
end

function lib:OnEmbedDisable()
end


function lib:OnEnable()
	if (self.OnEnabled) then
		if (not self.db.global.silent) then
			self:Print(C(VIDEO_OPTIONS_ENABLED,"green"))
		end
		pcall(self.OnEnabled,self,lib.options[self].first)
		lib.options[self].first=nil
	end
end
function lib:OnDisable(...)
	if (self.OnDisabled) then
		if (not self.db.global.silent) then
			self.print(C(VIDEO_OPTIONS_DISABLED,'red'))
		end
		pcall(self.OnDisabled,self,...)
	end
end
local function _GetMethod(target,prefix,func)
	if (func == 'Start' or func == 'Stop') then return end
	local method=prefix .. func
	if (type(target[method])== "function") then
			return method
	elseif (type(target["_" .. prefix])) then
			return "_" .. prefix
	end
end
function lib:StartAutomaticEvents()
	for k,v in pairs(self) do
		if (type(v)=='function') then
			if (k:sub(1,3)=='Evt') then
				self:RegisterEvent(k:sub(4),k)
			end
		end
	end
end
function lib:StopAutomaticEvents(ignore)
	for k,v in pairs(self) do
		if (type(v)=='function') then
			if (k:sub(1,3)=='Evt') then
				if (ignore and k==ignore or k:sub(4)==ignore) then
					--a kickstart event not to be disabled
				else
					self:UnregisterEvent(k:sub(4))
				end
			end
		end
	end
end
function lib:Dprint(...)
end
function lib:Notify(...)
	return self:CustomPrint(C.orange.r,C.orange.g,C.orange.b, nil, nil, ' ', ...)
end
function lib:Debug()
	self.DebugOn=not self.DebugOn
	self:Print("Debug:",self.DebugOn and on or off)
	if self.DebugOn then
		self.Dprint=dprint
	else
		self.Dprint=nop
	end
end

function lib:Colorize(stringa,colore)
	return C(stringa,colore) .. "|r"
end
function lib:GetTocVersion()
	return select(4,GetBuildInfo())
end
function lib:Toggle()
	if (self:IsEnabled()) then
		self:Disable()
	else
		self:Enable()
	end
end
function lib:Vars()
	return pairs(self.db.profile.toggles)
end
function lib:SetBoolean(flag,value)
	if (value) then
		value=true
	else
		value=false
	end
	self.db.profile.toggles[flag]=value
	return not value
end
function lib:GetBoolean(flag)
	if (self.db.profile.toggles[flag]) then
		return true
	else
		return false
	end
end
lib.GetToggle=lib.GetBoolean -- alias
function lib:GetNumber(flag,default)
	return tonumber(self:GetSet(flag) or default or 0)
end
function lib:GetString(flag,default)
	return tostring(self:GetSet(flag) or default or '')
end

function lib:PrintBoolean(flag)
	if (type(flag) == "string") then
		flag=self:GetBoolean(flag)
	end
	if (flag) then
		return on
	else
		return off
	end
end
function lib:GetSet(...)
	local flag,value=select(1,...)
	if (select('#',...) == 2) then
		self.db.profile.toggles[flag]=value
	else
		return self.db.profile.toggles[flag]
	end
end
function lib:GetIndexedVar(flag,index)
	local rc=GetVar(flag)
	if index and type(rc)=="table" then
		return rc[index]
	else
		return rc
	end

end
function lib:GetVar(flag)
	return self:GetSet(flag)
end
function lib:SetVar(flag,value)
	return self:GetSet(flag,value)
end
--- Simulates a configuration  variable change.
--
-- Generates Apply* events if needed
-- @tparam string flag Variable name
function lib:Trigger(flag)
	local info=self:GetVarInfo(flag)
	if (info) then
		local value=info.type=="toggle" and self:GetBoolean(flag) or self:GetVar(flag)
		self._Apply[flag](self,flag,value)
	end

end
function lib:OptToggleSet(info,value,extra)
	local flag=info.option.arg
	local tipo=info.option.type

	if (tipo=="toggle") then
		self:SetBoolean(flag,value)
	elseif (tipo=="multiselect") then
		self.db.profile.toggles[flag][value]=extra
	else
		self:GetSet(flag,value)
	end
	if (self:IsEnabled()) then
		self._Apply[flag](self,flag,value)
	end
end
function lib:OptToggleGet(info,extra)
	local flag=info.option.arg
	local tipo=info.option.type
	if (tipo=="toggle") then
		return self:GetBoolean(flag)
	elseif (tipo=="multiselect") then
		if type(self.db.profile.toggles[flag])~="table" then
			self.db.profile.toggles[flag]={}
		end
		return self.db.profile.toggles[flag][extra]
	else
		return self:GetSet(flag)
	end
end
function lib:ApplySettings()
	if (type(self.ApplyAll)=="function") then
		self:ApplyAll()
	else
		for i,v in self:Vars() do
			self._Apply[i](self,i,v)
		end
	end
end
local neveropened=true
function lib:Gui(info)
	if (AceConfigDialog and AceGUI) then
		if (neveropened) then
			InterfaceAddOnsList_Update()
			neveropened=false
		end
		InterfaceOptionsFrame_OpenToCategory(self.CfgDlg)
	else
		self:Print("No GUI available")
	end
end

function lib:Help(info)
	if (AceConfigDialog and AceGUI) then
		if (neveropened) then
			InterfaceAddOnsList_Update()
			neveropened=false
		end
		InterfaceOptionsFrame_OpenToCategory(self.CfgRel)
	else
		self:Print("No GUI available")
	end
end
function lib:Long(msg) C:OnScreen('Yellow',msg,20) end
function lib:Onscreen_Orange(msg) C:OnScreen('Orange',msg,2) end
function lib:Onscreen_Purple(msg) C:OnScreen('Purple',msg,8) end
function lib:Onscreen_Yellow(msg) C:OnScreen('Yellow',msg,1) end
function lib:Onscreen_Azure(msg) C:OnScreen('Azure',msg,1) end
function lib:Onscreen_Red(msg) C:OnScreen('Red',msg,1) end
function lib:Onscreen_Green(msg) C:OnScreen('Green',msg,1) end
function lib:OnScreen(color,...) C:OnScreen(color,strjoin(' ',tostringall(...))) end
function lib:TimeToStr(time) -- Converts time data to a string format
	local p,s,m,h;
	if (not time) then
		return ("0:00")
	end
	if (time < 0) then
		time=abs(time)
		p='-'
	else
		p=''
	end
	s = floor(mod(time, 60));
	m = floor(time/ 60);
	if (m > 59) then
		h=floor(m/60)
		m=floor(mod(m,60))
	end
	if (h) then
		return format("%s%d:%02d:%02d",p,h,m,s)
	else
		return format("%s%d:%02d",p,m,s)
	end
end

function lib:GetColorTable()
	return C
end
-- In case of upgrade, we need to redo embed for ALL Addons
-- This function get called on addon creation
-- Anything I define here is immediately available to addon code
function lib:Embed(target)
	-- All methods are pulled in via metatable in order to not pollute addon table
	local mt=getmetatable(target)
	if not mt then mt={__tostring=function(me) return me.name end} end
	mt.__index=lib.mixins
	setmetatable(target,mt)
	target._Apply=target._Apply or {}
	target._Apply._handler=target
	for k,v in pairs(self) do
		if type(v)=="string" or type(v)=="number" then pp (self,k,v) end
	end
	setmetatable(target._Apply,varmeta)
	lib.mixinTargets[target] = true
end

local function kpairs(t,f)
	local a = new()
	for n in pairs(t) do table.insert(a, n) end
	table.sort(a, f)
	local i = 0      -- iterator variable
	local iter = function ()   -- iterator function
		i = i + 1
		if a[i] == nil then
				del(a)
				return nil
		else
				local k=a[i]
				a[i]=nil -- Should optimize memory usage
				return k, t[k]
		end
	end
	return iter
end
if (not _G.kpairs) then
		_G.kpairs=kpairs
end
function lib:getKpairs()
	return kpairs
end
-- This metatable is used to generate a sorted proxy to an hashed table.
-- It should not used directly
lib.mt={__metatable=true,__version=MINOR_VERSION}
local mt=lib.mt
function mt:__index(k)
	if k=="n" then
		return #mt.keys[self.__source]
	end
	return self.__source[k]
end
function mt:__len()
	return #self.__keys
end
function mt:__newindex(k,v)
	local pos=#self.__keys+1
	for i,x in ipairs(self.__keys) do
		if x>k then
			pos=i
			break;
		end
	end
	if (k:sub(1,2)~="__") then
		table.insert(self.__keys,pos,k)
	end
	self.__source[k]=v -- We want to trigger metamethods on original table
end
function mt:__call()
	do
		local current=0
		return function(unsorted,i)
			current=current+1
			local k=self.__keys[current]
			if k then return k,self.__source[k] end
		end,self,0
	end
end
function lib:GetSortedProxy(table)
	local proxy=setmetatable({__keys={},__source=table,__metatable=true},mt)
	for k,v in pairs(table) do
		proxy[k]=v
	end
	return proxy
end

function lib:ScheduleLeaveCombatAction(method, ...)
	return self:OnLeaveCombat(method,...)
end

--- Generates and executes a coroutine with configurable interval and combat status
-- If called for already running coroutine changes the interval and the combat status
-- @tparam number interval between steps
-- @tparam string|function action To be executed, Can be a function or a method name
-- @tparam[opt] bool
--
function lib:coroutineExecute(interval,func,safeForCombat)
	if type(func)=="string" then
		func=self[func]
	end
	assert(type(func) =="function","coroutineExecute arg1 was not convertible to a function " .. tostring(func))
	local c=lib.coroutines[func]
	c.combatSafe=safeForCombat
	c.interval=interval
	c.obj=self
	if type(c.co)=="thread" and coroutine.status(c.co)=="suspended" then print("Already running",func) return end
	c.co=coroutine.create(func)
	c.paused=false
	c.repeater=function()
		if not c.combatSafe and InCombatLockdown() then
			c.waiting=true
			return
		end
		if c.paused then return end
		local rc,res=pcall(coroutine.resume,c.co,c.obj)
		if rc and res then
			C_Timer.After(c.interval,c.repeater)
		else
			c=nil
		end
	end
	c.repeater()
	return c
end
function lib:coroutinePause(func)
	if type(func)=="string" then
		func=self[func]
	end
	local co=rawget(lib.coroutines,func)
	if co then
		co.paused=true
	end
end
function lib:coroutineRestart(func)
	if type(func)=="string" then
		func=self[func]
	end
	local co=rawget(lib.coroutines,func)
	if co then
		co.paused=false
		pcall(co.repeater)
	end
end
if not lib.secureframe then
	lib.secureframe=CreateFrame("Button",nil,nil,"StaticPopupButtonTemplate,SecureActionButtonTemplate")
	lib.secureframe:Hide()
end
local function StopSpellCasting(this)
	local b2=_G[this:GetName().."Button2"]
	local AC=lib.secureframe
	AC:SetParent(b2)
	AC:SetAllPoints()
	AC:SetText(b2:GetText())
	AC:SetAttribute("type","stop")
	AC:SetScript("PostClick",function() b2:Click() end)
	AC:Show()
end
local function StopSpellCastingCleanup(this)
	local AC=lib.secureframe
	AC:SetParent(nil)
	AC:Hide()

end
local StaticPopupDialogs=StaticPopupDialogs
local StaticPopup_Show=StaticPopup_Show
--- Show a popup
-- Display a popup message with Accept and optionally Cance button
-- @tparam string msg Message to be shown
-- @tparam[opt] number timeout In seconds, if omitted assumes 60
-- @tparam[opt] func OnAccept Executed when clicked on Accept
-- @tparam[opt] func OnCancel Executed when clicked on Cancel (if nill, Cancel button is not shown)
-- @tparam[opt] mixed data Passed to the callbacl function
-- @tparam[opt] bool StopCasting If true, when the popup appear will stop any running casting.
-- Useful to ask confirmation before performing a programmatic initiated spellcasting
function lib:Popup(msg,timeout,OnAccept,OnCancel,data,StopCasting)
	if InCombatLockdown() then
		return self:ScheduleLeaveCombatAction("Popup",msg,timeout,OnAccept,OnCancel,data,StopCasting)
	end
	msg=msg or "Something strange happened"
	if type(timeout)=="function" then
		StopCasting=data
		data=OnCancel
		OnAccept=timeout
		timeout=60
	end
	StaticPopupDialogs["LIBINIT_POPUP"] = StaticPopupDialogs["LIBINIT_POPUP"] or
	{
	text = msg,
	showAlert = true,
	timeout = timeout or 60,
	exclusive = true,
	whileDead = true,
	interruptCinematic = true
	};
	local popup=StaticPopupDialogs["LIBINIT_POPUP"]
	if StopCasting then
		popup.OnShow=StopSpellCasting
		popup.OnHide=StopSpellCastingCleanup
	else
		popup.OnShow=nil
		popup.OnHide=nil
	end
	popup.text=msg
	popup.OnCancel=nil
	popup.OnAccept=OnAccept
	popup.button1=ACCEPT
	popup.button2=nil
	if (OnCancel) then
		if (type(OnCancel)=="function") then
			popup.OnCancel=OnCancel
		end
		popup.button2 = CANCEL
	else
		popup.button1=OKAY
	end
	StaticPopup_Show("LIBINIT_POPUP",nil,nil,data);
end
-- Interface widgets
local factory={} --#factory
do
	local nonce=0
	local GetTime=GetTime
	local function SetScript(this,...)
		this.child:SetScript(...)
	end
	local function SetStep(this,value)
		this:SetObeyStepOnDrag(true)
		this:SetValueStep(value)
		this:SetStepsPerPage(1)
	end
	function factory:Slider(father,min,max,current,message,tooltip)
		if type(message)=="table" then
			tooltip=message.desc
			message=message.name
		end
		local name=tostring(GetTime()*1000) ..nonce
		nonce=nonce+1
		local sl = CreateFrame('Slider',name, father, 'OptionsSliderTemplate')
		sl:SetWidth(128)
		sl:SetHeight(20)
		sl:SetOrientation('HORIZONTAL')
		sl:SetMinMaxValues(min, max)
		sl:SetValue(current)
		sl.SetStep=SetStep
		sl.Low=_G[name ..'Low']
		sl.Low:SetText(min)
		sl.High=_G[name .. 'High']
		sl.High:SetText(max)
		sl.Text=_G[name.. 'Text']
		sl.Text:SetText(message)
		sl.OnValueChanged=function(this,value)
			if (not this.unrounded) then
				value = math.floor(value)
			end
			if (this.isPercent) then
				this.Text:SetFormattedText('%d%%',value)
			else
				this.Text:SetText(value)
			end
			return value
		end
		sl.SetText=function(this,value) this.Text:SetText(value) end
		sl.SetFormattedText=function(this,...) this.Text:SetFormattedText(...) end
		sl.SetTextColor=function(this,...) this.Text:SetTextColor(...) end
		sl:SetScript("OnValueChanged",sl.OnValueChanged)
		sl.tooltipText=tooltip
		return sl
	end
	function factory:Checkbox(father,current,message,tooltip)
		if type(message)=="table" then
			tooltip=message.desc
			message=message.name
		end
		local name=tostring(GetTime()*1000) ..nonce
		nonce=nonce+1
		local frame=CreateFrame("Frame",nil,father)
		local ck=CreateFrame("CheckButton",name,frame,"ChatConfigCheckButtonTemplate")
		frame.SetScript=SetScript
		frame.child=ck
		ck:SetPoint('TOPLEFT')
		ck.Text=_G[name..'Text']
		ck.Text:SetText(message)
		ck:SetChecked(current)
		ck.tooltip=tooltip
		frame:SetWidth(ck:GetWidth()+ck.Text:GetWidth()+2)
		frame:SetHeight(ck:GetHeight())
		return frame
	end
	function factory:Dropdown(father,current,list,message,tooltip)
		if type(message)=="table" then
			tooltip=message.desc
			message=message.name
		end
		do
		local dd=CreateFrame("Frame",nil,father)
		if (tooltip) then
			dd.tooltip=tooltip
			dd:SetScript("OnEnter",function(self)
					GameTooltip:SetOwner(self, "ANCHOR_RIGHT");
					GameTooltip:SetText(self.tooltip, nil, nil, nil, nil, (self.tooltipStyle or true));
				end
			)
		end
		dd:SetScript("OnLeave",function() GameTooltip:Hide() end)
		dd.text=dd:CreateFontString(nil,"ARTWORK","GameFontHighlight")
		function dd:SetText(...)
			self.text:SetText(...)
		end
		function dd:SetFormattedText(...)
			self.text:SetFormattedText(...)
		end
		function dd:SetTextColor(...)
			self.text:SetTextColor(...)
		end
		function dd:OnChange() end
		function dd:OnValueChanged(this,index,value)
			value=value or index
			UIDropDownMenu_SetSelectedID(dd,index)
			return self:OnChange(value)
		end
		function dd:SetOnChange(func)
			self.OnChange=func
		end
		dd.list=list
		local name=tostring(GetTime()*1000) ..nonce
		nonce=nonce+1
		dd.dropdown=CreateFrame('Frame',name,father,"UIDropDownMenuTemplate")
		UIDropDownMenu_Initialize(dd, function(...)
			local i=0
			for k,v in pairs(dd.list) do
				i=i+1
				local info=UIDropDownMenu_CreateInfo()
				info.text=v
				info.value=v
				info.func=function(...) return dd:OnValueChanged(...) end
				info.arg1=i
				info.arg2=v
				UIDropDownMenu_AddButton(info,1)
			end
		end)
		UIDropDownMenu_SetWidth(dd, 100);
		UIDropDownMenu_SetButtonWidth(dd, 124)
		UIDropDownMenu_SetSelectedID(dd, 1)
		UIDropDownMenu_JustifyText(dd, "LEFT")
		end
	end
end
function lib:GetFactory()
	return factory
end
local meta={__index=_G,
__newindex=function(t,k,v)
	assert(type(_G[k]) == 'nil',"Attempting to override global " ..k)
	return rawset(t,k,v)
end
}
function lib:SetCustomEnvironment(new_env)
	local old_env = getfenv(2)
	if old_env==new_env then return end
	if getmetatable(new_env)==meta then return end
	if not getmetatable(new_env) then
		if not new_env.print then new_env.print=dprint end
		setmetatable(new_env,meta)
		new_env.dprint=dprint
	else
		assert(false,"new_env already has metatable")
	end
	setfenv(2, new_env)
end
--- reembed routine
-- Prepares the mixins table
lib.mixins=lib.mixins or {}
wipe(lib.mixins)
for name,method in pairs(lib) do
	if type(method)=="function" and name~="NewAddon" and name~="GetAddon" and name:sub(1,1)~="_" then
		lib.mixins[name] = method
	end
end
for target,_ in pairs(lib.mixinTargets) do
	lib:Embed(target)
end
local l=AceLocale
if not l then
	L=setmetatable({},{
		__index=function(t,k) return k end
	})
	return
end
-- To avoid clash between versions, localization is versioned on major and minor
-- Lua strings are immutable so having more copies of the same string does not waist a noticeable slice of memory
local me=MAJOR_VERSION .. MINOR_VERSION
--@do-not-package@
-- Actual translations for test purpose
-- This part will NOT be packaged at all
do
	local L=l:NewLocale(me,"enUS",true,true)
	L["Configuration"] = "Configuration"
	L["Description"] = "Description"
	L["Libraries"] = "Libraries"
	L["Purge1"] = "Delete unused profiles"
	L["Purge2"] = "Deletes all profiles that are not used by a character"
	L["Purge_Desc"] = "You can delete all unused profiles with just one click"
	L["Release Notes"] = "Release Notes"
	L["Toggles"] = "Toggles"
	L["UseDefault1"] = "Switch all characters to \"%s\" profile"
	L["UseDefault2"] = "Uses the \"%s\" profiles for all your toons"
	L["UseDefault_Desc"] = "You can force all your characters to use the \"%s\" profile in order to manage a single configuration"
	L=l:NewLocale(me,"ptBR")
	if (L) then
	L["Configuration"] = "configura\195\167\195\163o"
	L["Description"] = "Descri\195\167\195\163o"
	L["Libraries"] = "bibliotecas"
	L["Release Notes"] = "Notas de Lan\195\167amento"
	L["Toggles"] = "Alterna"
	end
	L=l:NewLocale(me,"frFR")
	if (L) then
	L["Configuration"] = "configuration"
	L["Description"] = "description"
	L["Libraries"] = "biblioth\195\168ques"
	L["Release Notes"] = "notes de version"
	L["Toggles"] = "Bascule"
	end
	L=l:NewLocale(me,"deDE")
	if (L) then
	L["Configuration"] = "Konfiguration"
	L["Description"] = "Beschreibung"
	L["Libraries"] = "Bibliotheken"
	L["Release Notes"] = "Release Notes"
	L["Toggles"] = "Schaltet"
	end
	L=l:NewLocale(me,"koKR")
	if (L) then
	L["Configuration"] = "\234\181\172\236\132\177"
	L["Description"] = "\236\132\164\235\170\133"
	L["Libraries"] = "\235\157\188\236\157\180\235\184\140\235\159\172\235\166\172"
	L["Release Notes"] = "\235\166\180\235\166\172\236\138\164 \235\133\184\237\138\184"
	L["Toggles"] = "\236\160\132\237\153\152"
	end
	L=l:NewLocale(me,"esMX")
	if (L) then
	L["Configuration"] = "Configuraci\195\179n"
	L["Description"] = "Descripci\195\179n"
	L["Libraries"] = "Bibliotecas"
	L["Release Notes"] = "Notas de la versi\195\179n"
	L["Toggles"] = "Alterna"
	end
	L=l:NewLocale(me,"ruRU")
	if (L) then
	L["Configuration"] = "\208\154\208\190\208\189\209\132\208\184\208\179\209\131\209\128\208\176\209\134\208\184\209\143"
	L["Description"] = "\208\158\208\191\208\184\209\129\208\176\208\189\208\184\208\181"
	L["Libraries"] = "\208\145\208\184\208\177\208\187\208\184\208\190\209\130\208\181\208\186\208\184"
	L["Release Notes"] = "\208\159\209\128\208\184\208\188\208\181\209\135\208\176\208\189\208\184\209\143 \208\186 \208\178\209\139\208\191\209\131\209\129\208\186\209\131"
	L["Toggles"] = "\208\159\208\181\209\128\208\181\208\186\208\187\209\142\209\135\208\181\208\189\208\184\208\181"
	end
	L=l:NewLocale(me,"zhCN")
	if (L) then
	L["Configuration"] = "\233\133\141\231\189\174"
	L["Description"] = "\232\175\180\230\152\142"
	L["Libraries"] = "\229\155\190\228\185\166\233\166\134"
	L["Release Notes"] = "\229\143\145\232\161\140\232\175\180\230\152\142"
	L["Toggles"] = "\229\136\135\230\141\162"
	end
	L=l:NewLocale(me,"esES")
	if (L) then
	L["Configuration"] = "Configuraci\195\179n"
	L["Description"] = "Descripci\195\179n"
	L["Libraries"] = "Bibliotecas"
	L["Release Notes"] = "Notas de la versi\195\179n"
	L["Toggles"] = "Alterna"
	end
	L=l:NewLocale(me,"zhTW")
	if (L) then
	L["Configuration"] = "\233\133\141\231\189\174"
	L["Description"] = "\232\175\180\230\152\142"
	L["Libraries"] = "\229\155\190\228\185\166\233\166\134"
	L["Release Notes"] = "\229\143\145\232\161\140\232\175\180\230\152\142"
	L["Toggles"] = "\229\136\135\230\141\162"
	end
	L=l:NewLocale(me,"itIT")
	if (L) then
	L["Configuration"] = "Configurazione"
	L["Description"] = "Descrizione"
	L["Libraries"] = "Librerie"
	L["Purge1"] = "Cancella i profili inutilizzati"
	L["Purge2"] = "Cancella tutti i profili che non sono usati da un personaggio"
	L["Purge_Desc"] = "Puoi cancellare tutti i profili inutilizzati con un singolo click"
	L["Release Notes"] = "Note di rilascio"
	L["Toggles"] = "Interruttori"
	L["UseDefault1"] = "Imposta il profilo \"%s\" su tutti i personaggi"
	L["UseDefault2"] = "Usa il profilo '%s\" per tutti i personaggi"
	L["UseDefault_Desc"] = "Puoi far usare a tutti i tuoi personaggi il profilo \"%s\""
	end
end
L=LibStub("AceLocale-3.0"):GetLocale(me,true)
if true then return end
--@end-do-not-package@
do
	local L=l:NewLocale(me,"enUS",true,true)
L["%s |4follower:followers; with %s"] = true
L["(Ignores low bias ones)"] = true
L["Add %1$d levels to %2$s"] = true
L["Adds a list of other useful followers to tooltip"] = true
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = true
L["Allowed Rewards"] = true
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = true
L["Applied when 'maximize result' is enabled. Default is 80%"] = true
L["Applies the best armor set"] = true
L["Applies the best armor upgrade"] = true
L["Applies the best weapon set"] = true
L["Applies the best weapon upgrade"] = true
L["Archaelogy"] = true
L["Big screen"] = true
L["Blacklisted"] = true
L["Blacklisted missions are ignored in Mission Control"] = true
L["Building Final report"] = true
L["Capped %1$s. Spend at least %2$d of them"] = true
L["Complete all missions without confirmation"] = true
L["Consider again"] = true
L["Disable if you dont want the full Garrison Commander Header."] = true
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = true
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = true
L["Do not show follower icon on plots"] = true
L["Duration Time"] = true
L["Enhance tooltip"] = true
L["Environment Preference"] = true
L["Epic followers are NOT sent alone on xp only missions"] = true
L["Expiration Time"] = true
L["Follower"] = true
L["Follower equipment set or upgrade"] = true
L["Follower experience"] = true
L["Follower set minimum upgrade"] = true
L["Follower Training"] = true
L["Followers status "] = true
L["Garrison Appearance"] = true
L["Garrison Comander Quick Mission Completion"] = true
L["Garrison Commander Mission Control"] = true
L["Global approx. xp reward"] = true
L["Global success chance"] = true
L["Gold incremented!"] = true
L["Hide followers"] = true
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = true
L["IF checked, shows armors on the left and weapons on the right "] = true
L["If you continue, you will lose them"] = true
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = true
L["Ignore \"maxed\""] = true
L["Ignore epic for xp missions."] = true
L["Ignore for all missions"] = true
L["Ignore for this mission"] = true
L["Ignore rare missions"] = true
L["Increased Rewards"] = true
L["Item minimum level"] = true
L["Item Tokens"] = true
L["Left Click to see available missions"] = true
L["Legendary Items"] = true
L["Level 100 epic followers are not used for xp only missions."] = true
L["Makes main mission panel movable"] = true
L["Makes shipyard panel movable"] = true
L["Maximize result"] = true
L["Maximum mission duration."] = true
L["Minimum chance"] = true
L["Minimum mission duration."] = true
L["Minimum needed chance"] = true
L["Minimum requested level for equipment rewards"] = true
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = true
L["Minimun chance success under which ignore missions"] = true
L["Minumum needed chance"] = true
L["Mission Control"] = true
L["Mission Duration"] = true
L["Mission shown"] = true
L["Mission shown for follower"] = true
L["Mission Success"] = true
L["Mission time reduced!"] = true
L["Mission with lower success chance will be ignored"] = true
L["Missionlist"] = true
L["Must reload interface to apply"] = true
L["No confirmation"] = true
L["No follower gained xp"] = true
L["No mission prefill"] = true
L["Not blacklisted"] = true
L["Nothing to report"] = true
L["Number of followers"] = true
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = true
L["Only meaningful upgrades are shown"] = true
L["Original concept and interface by %s"] = true
L["Original method"] = true
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = true
L["Other"] = true
L["Other rewards"] = true
L["Other settings"] = true
L["Other useful followers"] = true
L["Processing mission %d of %d"] = true
L["Profession"] = true
L["Racial Preference"] = true
L["Rare missions will not be considered"] = true
L["Reagents"] = true
L["Reputation Items"] = true
L["Reward type"] = true
L["Right-Click to blacklist"] = true
L["Right-Click to remove from blacklist"] = true
L["Rush orders"] = true
L["Shipyard Appearance"] = true
L["Show Garrison Commander menu"] = true
L["Show itemlevel"] = true
L["Show upgrades"] = true
L["Show xp"] = true
L["Slayer"] = true
L["Some follower"] = true
L["Sort missions by:"] = true
L["Submit all your mission at once. No question asked."] = true
L["Success Chance"] = true
L["Swap upgrades positions"] = true
L["Switch between Garrison Commander and Master Plan interface for missions"] = true
L["Threat Counter"] = true
L["To go: %d"] = true
L["Toggles Garrison Commander Menu Header on/off"] = true
L["Toys and Mounts"] = true
L["Unchecking this will allow you to set specific success chance for each reward type"] = true
L["Unlock Panel"] = true
L["Upgrade %1$s to  %2$d itemlevel"] = true
L["Upgrading to |cff00ff00%d|r"] = true
L["Use big screen"] = true
L["Use GC Interface"] = true
L["Uses armor token"] = true
L["Uses weapon token"] = true
L["When checked, show on each follower button missing xp to next level"] = true
L["When checked, show on each follower button weapon and armor level for maxed followers"] = true
L["Xp incremented!"] = true
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = true
L["You can also send mission one by one clicking on each button."] = true
L["You can open the menu clicking on the icon in top right corner"] = true
L["You have ignored followers"] = true
L["You never performed this mission"] = true
L["You performed this mission %d times with a win ratio of"] = true

	L=l:NewLocale(me,"ptBR")
	if (L) then
--[[Translation missing --]]
--[[ L["%s |4follower:followers; with %s"] = ""--]] 
--[[Translation missing --]]
--[[ L["(Ignores low bias ones)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Add %1$d levels to %2$s"] = ""--]] 
--[[Translation missing --]]
--[[ L["Adds a list of other useful followers to tooltip"] = ""--]] 
--[[Translation missing --]]
--[[ L["Affects only little screen mode, hiding the per follower mission list if not checked"] = ""--]] 
--[[Translation missing --]]
--[[ L["Allowed Rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applied when 'maximize result' is enabled. Default is 80%"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best armor set"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best armor upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best weapon set"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best weapon upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Archaelogy"] = ""--]] 
--[[Translation missing --]]
--[[ L["Big screen"] = ""--]] 
--[[Translation missing --]]
--[[ L["Blacklisted"] = ""--]] 
--[[Translation missing --]]
--[[ L["Blacklisted missions are ignored in Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Building Final report"] = ""--]] 
--[[Translation missing --]]
--[[ L["Capped %1$s. Spend at least %2$d of them"] = ""--]] 
--[[Translation missing --]]
--[[ L["Complete all missions without confirmation"] = ""--]] 
--[[Translation missing --]]
--[[ L["Consider again"] = ""--]] 
--[[Translation missing --]]
--[[ L["Disable if you dont want the full Garrison Commander Header."] = ""--]] 
--[[Translation missing --]]
--[[ L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = ""--]] 
--[[Translation missing --]]
--[[ L["Do not show follower icon on plots"] = ""--]] 
--[[Translation missing --]]
--[[ L["Duration Time"] = ""--]] 
--[[Translation missing --]]
--[[ L["Enhance tooltip"] = ""--]] 
--[[Translation missing --]]
--[[ L["Environment Preference"] = ""--]] 
--[[Translation missing --]]
--[[ L["Epic followers are NOT sent alone on xp only missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Expiration Time"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower equipment set or upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower experience"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower set minimum upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower Training"] = ""--]] 
--[[Translation missing --]]
--[[ L["Followers status "] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Appearance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Comander Quick Mission Completion"] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Commander Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Global approx. xp reward"] = ""--]] 
--[[Translation missing --]]
--[[ L["Global success chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Gold incremented!"] = ""--]] 
--[[Translation missing --]]
--[[ L["Hide followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = ""--]] 
--[[Translation missing --]]
--[[ L["IF checked, shows armors on the left and weapons on the right "] = ""--]] 
--[[Translation missing --]]
--[[ L["If you continue, you will lose them"] = ""--]] 
--[[Translation missing --]]
--[[ L["IF you have a Salvage Yard you probably dont want to have this one checked"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore \"maxed\""] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore epic for xp missions."] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore for all missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore for this mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore rare missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Increased Rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Item minimum level"] = ""--]] 
--[[Translation missing --]]
--[[ L["Item Tokens"] = ""--]] 
--[[Translation missing --]]
--[[ L["Left Click to see available missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Legendary Items"] = ""--]] 
--[[Translation missing --]]
--[[ L["Level 100 epic followers are not used for xp only missions."] = ""--]] 
--[[Translation missing --]]
--[[ L["Makes main mission panel movable"] = ""--]] 
--[[Translation missing --]]
--[[ L["Makes shipyard panel movable"] = ""--]] 
--[[Translation missing --]]
--[[ L["Maximize result"] = ""--]] 
--[[Translation missing --]]
--[[ L["Maximum mission duration."] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum mission duration."] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum needed chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum requested level for equipment rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum requested upgrade for followers set (Enhancements are always included)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimun chance success under which ignore missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minumum needed chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Duration"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission shown for follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Success"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission time reduced!"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission with lower success chance will be ignored"] = ""--]] 
--[[Translation missing --]]
--[[ L["Missionlist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Must reload interface to apply"] = ""--]] 
--[[Translation missing --]]
--[[ L["No confirmation"] = ""--]] 
--[[Translation missing --]]
--[[ L["No follower gained xp"] = ""--]] 
--[[Translation missing --]]
--[[ L["No mission prefill"] = ""--]] 
--[[Translation missing --]]
--[[ L["Not blacklisted"] = ""--]] 
--[[Translation missing --]]
--[[ L["Nothing to report"] = ""--]] 
--[[Translation missing --]]
--[[ L["Number of followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Only first %1$d missions with over %2$d%% chance of success are shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Only meaningful upgrades are shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original concept and interface by %s"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original method"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other settings"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other useful followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Processing mission %d of %d"] = ""--]] 
--[[Translation missing --]]
--[[ L["Profession"] = ""--]] 
--[[Translation missing --]]
--[[ L["Racial Preference"] = ""--]] 
--[[Translation missing --]]
--[[ L["Rare missions will not be considered"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reagents"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reputation Items"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reward type"] = ""--]] 
--[[Translation missing --]]
--[[ L["Right-Click to blacklist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Right-Click to remove from blacklist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Rush orders"] = ""--]] 
--[[Translation missing --]]
--[[ L["Shipyard Appearance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show Garrison Commander menu"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show itemlevel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show upgrades"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show xp"] = ""--]] 
--[[Translation missing --]]
--[[ L["Slayer"] = ""--]] 
--[[Translation missing --]]
--[[ L["Some follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Sort missions by:"] = ""--]] 
--[[Translation missing --]]
--[[ L["Submit all your mission at once. No question asked."] = ""--]] 
--[[Translation missing --]]
--[[ L["Success Chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Swap upgrades positions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Switch between Garrison Commander and Master Plan interface for missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Threat Counter"] = ""--]] 
--[[Translation missing --]]
--[[ L["To go: %d"] = ""--]] 
--[[Translation missing --]]
--[[ L["Toggles Garrison Commander Menu Header on/off"] = ""--]] 
--[[Translation missing --]]
--[[ L["Toys and Mounts"] = ""--]] 
--[[Translation missing --]]
--[[ L["Unchecking this will allow you to set specific success chance for each reward type"] = ""--]] 
--[[Translation missing --]]
--[[ L["Unlock Panel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Upgrade %1$s to  %2$d itemlevel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Upgrading to |cff00ff00%d|r"] = ""--]] 
--[[Translation missing --]]
--[[ L["Use big screen"] = ""--]] 
--[[Translation missing --]]
--[[ L["Use GC Interface"] = ""--]] 
--[[Translation missing --]]
--[[ L["Uses armor token"] = ""--]] 
--[[Translation missing --]]
--[[ L["Uses weapon token"] = ""--]] 
--[[Translation missing --]]
--[[ L["When checked, show on each follower button missing xp to next level"] = ""--]] 
--[[Translation missing --]]
--[[ L["When checked, show on each follower button weapon and armor level for maxed followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Xp incremented!"] = ""--]] 
--[[Translation missing --]]
--[[ L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = ""--]] 
--[[Translation missing --]]
--[[ L["You can also send mission one by one clicking on each button."] = ""--]] 
--[[Translation missing --]]
--[[ L["You can open the menu clicking on the icon in top right corner"] = ""--]] 
--[[Translation missing --]]
--[[ L["You have ignored followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["You never performed this mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["You performed this mission %d times with a win ratio of"] = ""--]] 

	end
	L=l:NewLocale(me,"frFR")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4sujet:sujets; avec %s"
L["(Ignores low bias ones)"] = "(Ignorer celles \195\160 basse priorit\195\169)"
L["Add %1$d levels to %2$s"] = "Ajoute %1$d niveaux \195\160 %2$s"
L["Adds a list of other useful followers to tooltip"] = "Ajoute une liste d'autres sujets utiles dans l'infobulle"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "N'affecte que le mode petit \195\169cran, masquant la liste par mission de sujet si d\195\169coch\195\169"
L["Allowed Rewards"] = "R\195\169compenses re\195\167ues"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "Permet un pourcentage de r\195\169ussite inf\195\169rieur pour des missions de ressources. Utiliser /gac gui pour le changer. Il est par d\195\169faut \195\160 80 %."
L["Applied when 'maximize result' is enabled. Default is 80%"] = "Affecter quand \194\171 maximiser le r\195\169sultat \194\187 est actif. Il est par d\195\169faut de 80 %"
L["Applies the best armor set"] = "Applique le meilleur ensemble d'armure"
L["Applies the best armor upgrade"] = "Applique la meilleure am\195\169lioration d'armure"
L["Applies the best weapon set"] = "Applique le meilleur ensemble d'arme"
L["Applies the best weapon upgrade"] = "Applique la meilleure am\195\169lioration d'arme"
L["Archaelogy"] = "Arch\195\169ologie"
L["Big screen"] = "Grand \195\169cran"
L["Blacklisted"] = "Liste noire"
L["Blacklisted missions are ignored in Mission Control"] = "Les missions en liste noire sont ignor\195\169es dans Contr\195\180le de mission"
L["Building Final report"] = "Cr\195\169ation du rapport final"
L["Capped %1$s. Spend at least %2$d of them"] = "Maxi pour %1$s. En d\195\169pensera au moins %2$d"
L["Complete all missions without confirmation"] = "Terminer toutes les missions sans confirmation"
L["Consider again"] = "Reconsid\195\169rer"
L["Disable if you dont want the full Garrison Commander Header."] = "\195\128 d\195\169sactiver si vous ne voulez pas de l'intitul\195\169 naval complet"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "D\195\169sactive le remplissage automatique des sujets sur la page de mission, ou maintenir CTRL tout en cliquant sur une mission."
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "D\195\169sactiver ceci vous donnera l'interface de version 1.1.8. Rechargera l'interface maintenant."
L["Do not show follower icon on plots"] = "Ne pas afficher l'ic\195\180ne des sujets dans leurs emplacements"
L["Duration Time"] = "Dur\195\169e"
L["Enhance tooltip"] = "Infobulle am\195\169lior\195\169e"
L["Environment Preference"] = "Pr\195\169f\195\169rence d'environnement"
L["Epic followers are NOT sent alone on xp only missions"] = "Les sujets \195\169piques ne sont PAS envoy\195\169s seuls dans des missions d'XP uniquement"
L["Expiration Time"] = "D\195\169lai avant expiration"
L["Follower"] = "Sujet"
L["Follower equipment set or upgrade"] = "\195\137quipement du sujet d\195\169fini ou am\195\169lior\195\169"
L["Follower experience"] = "Exp\195\169rience du sujet"
L["Follower set minimum upgrade"] = "Am\195\169lioration minimale du sujet d\195\169finie"
L["Follower Training"] = "Formation de sujet"
L["Followers status "] = "Statuts des sujets"
L["Garrison Appearance"] = "Arriv\195\169e de fief"
L["Garrison Comander Quick Mission Completion"] = "Terminer rapidement toutes les missions navales"
L["Garrison Commander Mission Control"] = "Contr\195\180le des missions navales"
L["Global approx. xp reward"] = "\195\137valuation totale du gain en XP"
L["Global success chance"] = "Chance totale de succ\195\168s"
L["Gold incremented!"] = "Or augment\195\169 !"
L["Hide followers"] = "Masquer les sujets"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[Si activ\195\169, cliquer sur une ic\195\180ne d'am\195\169lioration fera dispara\195\174tre l'objet et am\195\169liorera le sujet
|cFFFF0000AUCUNE CONFIRMATION !|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "SI coch\195\169, affiche les armures \195\160 gauche et les armes \195\160 droite"
L["If you continue, you will lose them"] = "Si vous continuez, vous le(s) perdrez"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "SI vous avez un centre de tri, vous ne voulez probablement pas avoir \195\167a une fois v\195\169rifi\195\169"
L["Ignore \"maxed\""] = "Ignorer \"maximis\195\169\""
L["Ignore epic for xp missions."] = "Ignorer sujet \195\169pique pour les missions \195\160 XP."
L["Ignore for all missions"] = "Ignorer pour toutes les missions"
L["Ignore for this mission"] = "Ignorer pour cette mission"
L["Ignore rare missions"] = "Ignorer les missions rares"
L["Increased Rewards"] = "Augmentation des r\195\169compenses"
L["Item minimum level"] = "Niveau minimum de l'objet"
L["Item Tokens"] = "Objets-jeton"
L["Left Click to see available missions"] = "Cliquer gauche pour voir les missions disponibles"
L["Legendary Items"] = "Objet l\195\169gendaire"
L["Level 100 epic followers are not used for xp only missions."] = "Les sujets \195\169piques de niveau 100 ne sont pas utilis\195\169s pour les missions d'XP uniquement."
L["Makes main mission panel movable"] = "Faire que le panneau principal de missions soit mobile"
L["Makes shipyard panel movable"] = "Faire que le panneau du port naval soit mobile"
L["Maximize result"] = "Maximiser le r\195\169sultat"
L["Maximum mission duration."] = "Dur\195\169e maximale de mission."
L["Minimum chance"] = "Chance minimale"
L["Minimum mission duration."] = "Dur\195\169e minimale de mission."
L["Minimum needed chance"] = "Chance minimale n\195\169cessaire"
L["Minimum requested level for equipment rewards"] = "Niveau requis minimum pour les r\195\169compenses d'\195\169quipement"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "Am\195\169lioration minimale requise pour l'\195\169quipement des sujets (les am\195\169liorations sont toujours inclus)"
L["Minimun chance success under which ignore missions"] = "R\195\169ussite minimale en dessous de laquelle les missions seront ignor\195\169es"
L["Minumum needed chance"] = "Chance minimale n\195\169cessaire"
L["Mission Control"] = "Contr\195\180le de missions"
L["Mission Duration"] = "Dur\195\169e de missions"
L["Mission shown"] = "Affichage de missions"
L["Mission shown for follower"] = "Mission affich\195\169e pour les sujets"
L["Mission Success"] = "Succ\195\168s de missions"
L["Mission time reduced!"] = "Dur\195\169e de mission r\195\169duite !"
L["Mission with lower success chance will be ignored"] = "Les missions avec des chances faibles seront ignor\195\169es"
L["Missionlist"] = "Liste des missions"
L["Must reload interface to apply"] = "Devra recharger l'interface pour activer"
L["No confirmation"] = "Ne pas confirmer"
L["No follower gained xp"] = "Aucune sujet n'a eu d'XP"
L["No mission prefill"] = "Pas de constitution auto. de missions"
L["Not blacklisted"] = "Ne pas mettre en liste noire"
L["Nothing to report"] = "Rien \195\160 signaler"
L["Number of followers"] = "Nombre de sujets"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "Seuls les %1$d premi\195\168res missions avec plus de %2$d%% de chances de succ\195\168s sont affich\195\169es"
L["Only meaningful upgrades are shown"] = "N'afficher que les am\195\169liorations utiles"
L["Original concept and interface by %s"] = "Conception et interface originels de %s"
L["Original method"] = "M\195\169thode originale"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "Trie original restaure la m\195\169thode de trie par d\195\169faut, quelle qu'elle f\195\187t (si vous avez un autre addon pour trier les missions, il devrait fonctionner \195\160 nouveau)"
L["Other"] = "Autre"
L["Other rewards"] = "Autres r\195\169compenses"
L["Other settings"] = "Autres param\195\168tres"
L["Other useful followers"] = "Autres sujets utiles"
L["Processing mission %d of %d"] = "Traitement de la mission %d sur %d"
L["Profession"] = "M\195\169tier"
L["Racial Preference"] = "Pr\195\169f\195\169rence de race"
L["Rare missions will not be considered"] = "Les missions rares ne sont pas examin\195\169es"
L["Reagents"] = "R\195\169actifs"
L["Reputation Items"] = "Objets de r\195\169putations"
L["Reward type"] = "Type de r\195\169compense"
L["Right-Click to blacklist"] = "Clic-droit pour mettre en liste noire"
L["Right-Click to remove from blacklist"] = "Clic-droit pour retirer de la liste noire"
L["Rush orders"] = "Commandes urgentes"
L["Shipyard Appearance"] = "Aspect du port naval"
L["Show Garrison Commander menu"] = "Afficher le menu de Garrison Commander"
L["Show itemlevel"] = "Afficher l'ilvl"
L["Show upgrades"] = "Affiche les am\195\169liorations"
L["Show xp"] = "Afficher l'XP"
L["Slayer"] = "Pourfendeur"
L["Some follower"] = "Un sujet"
L["Sort missions by:"] = "Trier les missions par :"
L["Submit all your mission at once. No question asked."] = "Soumettre toutes vos missions en une fois. Aucune confirmation demand\195\169e."
L["Success Chance"] = "Chance de succ\195\168s"
L["Swap upgrades positions"] = "Mettre \195\160 jour les positions permut\195\169es"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "Permuter l'interface entre Garrison Commander et Master Plan pour les missions"
L["Threat Counter"] = "Niveau de menace"
L["To go: %d"] = "Aller \195\160 : %d"
L["Toggles Garrison Commander Menu Header on/off"] = "Activer/d\195\169sactiver le menu d'intitul\195\169 de Garrison Commander"
L["Toys and Mounts"] = "Jouets et montures"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "D\195\169cocher pour d\195\169finir les chances de r\195\169ussite pour chaque type de r\195\169compense"
L["Unlock Panel"] = "D\195\169verrouille le panneau"
L["Upgrade %1$s to  %2$d itemlevel"] = "Am\195\169lioration du ilvl de %1$s \195\160 %2$d"
L["Upgrading to |cff00ff00%d|r"] = "Am\195\169lioration \195\160 |cff00ff00%d|r"
L["Use big screen"] = "Utilise la gd taille"
L["Use GC Interface"] = "Utiliser l'interface de GC"
L["Uses armor token"] = "Utiliser le jeton d'armure"
L["Uses weapon token"] = "Utiliser le jeton d'arme"
L["When checked, show on each follower button missing xp to next level"] = "Quand coch\195\169, affiche l'XP n\195\169cessaire, pour le prochain niveau, sur chaque bouton de sujets"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "Quand coch\195\169, affiche le niveau d'arme et d'armure sur chaque bouton des sujets maximis\195\169s"
L["Xp incremented!"] = "XP augment\195\169e !"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "Vous gaspillez |cffff0000%d|cffffd200 point(s) !!!"
L["You can also send mission one by one clicking on each button."] = "Vous pouvez aussi d\195\169buter les missions une par une en cliquant sur chaque bouton."
L["You can open the menu clicking on the icon in top right corner"] = "Vous pouvez ouvrir le menu en cliquant sur l'ic\195\180ne dans le coin sup\195\169rieur droit"
L["You have ignored followers"] = "Vous avez ignor\195\169 des sujets"
L["You never performed this mission"] = "Vous n'avez jamais effectu\195\169 cette mission"
L["You performed this mission %d times with a win ratio of"] = "Vous avez effectu\195\169 cette mission %d fois avec un rapport de"

	end
	L=l:NewLocale(me,"deDE")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4Anh\195\164nger:Anh\195\164nger; mit %s"
L["(Ignores low bias ones)"] = "(Niedrigstufige werden ignoriert)"
L["Add %1$d levels to %2$s"] = "Erh\195\182he die %2$s um %1$d Stufen"
L["Adds a list of other useful followers to tooltip"] = "F\195\188ge dem Tooltip eine Liste anderer n\195\188tzlicher Anh\195\164nger hinzu"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "Nur f\195\188r den Kleinfenstermodus; Versteckt die Pro-Anh\195\164nger-Missionsliste, wenn hier das H\195\164kchen fehlt."
L["Allowed Rewards"] = "Erlaubte Belohnungen"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "Erlaubt eine geringere Erfolgschance f\195\188r Ressourcenmissionen. Mit \"/gac gui\" kannst du diesen Prozentwert \195\164ndern. Standard ist 80%."
L["Applied when 'maximize result' is enabled. Default is 80%"] = "Nur wirksam, wenn 'Ergebnis maximieren' aktiv ist. Standard ist 80%"
L["Applies the best armor set"] = "Wendet das beste R\195\188stungsset an."
L["Applies the best armor upgrade"] = "Wendet die beste R\195\188stungsverbesserung an."
L["Applies the best weapon set"] = "Wendet das beste Waffenset an."
L["Applies the best weapon upgrade"] = "Wendet die beste Waffenverbesserung an."
L["Archaelogy"] = "Arch\195\164ologie"
L["Big screen"] = "Gro\195\159es Fenster"
L["Blacklisted"] = "Ignoriert"
L["Blacklisted missions are ignored in Mission Control"] = "Ignorierte Missionen werden in der Missionssteuerung ignoriert"
L["Building Final report"] = "Erstelle Abschlussbericht"
L["Capped %1$s. Spend at least %2$d of them"] = "Maximalwert von %1$s erreicht. Gib mindestens %2$d davon aus"
L["Complete all missions without confirmation"] = "Beende alle Missionen ohne Best\195\164tigung"
L["Consider again"] = "Wieder ber\195\188cksichtigen"
L["Disable if you dont want the full Garrison Commander Header."] = "Deaktiviere diese Option, wenn du den Header vom Garrison Commander nicht haben willst."
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "Deaktiviert das automatische Bef\195\188llen von Missionen auf der Missionsseite. Du kannst auch STRG+MAUSKLICK dr\195\188cken, um einzelne Missionen zu bef\195\188llen."
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "Durch Deaktivieren dieser Option erh\195\164ltst du das Interface von 1.1.8. Das Interface muss dabei neu geladen werden."
L["Do not show follower icon on plots"] = "Anh\195\164ngersymbole auf den Fl\195\164chen nicht anzeigen"
L["Duration Time"] = "Zeitdauer"
L["Enhance tooltip"] = "Tooltip verbessern"
L["Environment Preference"] = "Bevorzugte Umgebung"
L["Epic followers are NOT sent alone on xp only missions"] = "Epische Anh\195\164nger werden NICHT allein auf EP-Missionen geschickt"
L["Expiration Time"] = "Ablaufzeit"
L["Follower"] = "Anh\195\164nger"
L["Follower equipment set or upgrade"] = "Anh\195\164ngerausr\195\188stungsset oder -verbesserung"
L["Follower experience"] = "Anh\195\164ngererfahrung"
L["Follower set minimum upgrade"] = "Minimale Aufwertung f\195\188r Anh\195\164ngersets"
L["Follower Training"] = "Anh\195\164ngerausbildung"
L["Followers status "] = "Anh\195\164ngerstatus"
L["Garrison Appearance"] = "Garnisonsdarstellung"
L["Garrison Comander Quick Mission Completion"] = "GC-Schnellmissionsabschluss"
L["Garrison Commander Mission Control"] = "GC-Missionssteuerung"
L["Global approx. xp reward"] = "Globale ungef\195\164hre EP-Belohnung"
L["Global success chance"] = "Gesamte Erfolgschance"
L["Gold incremented!"] = "Gold erh\195\182ht!"
L["Hide followers"] = "Anh\195\164nger verstecken"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[Wenn aktiviert, wird beim Anklicken eines Aufwertungssymbols der Gegenstand verbraucht und der Anh\195\164nger verbessert
|cFFFF0000OHNE BEST\195\132TIGUNGSABFRAGE|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "Wenn markiert, werden R\195\188stungen auf der linken Seite und Waffen auf der rechten Seite angezeigt"
L["If you continue, you will lose them"] = "Wenn du weitermachst, wirst du sie verlieren"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "Wenn du ein Wiederverwertungsgeb\195\164ude hast, sollte diese Option deaktiviert bleiben"
L["Ignore \"maxed\""] = "\"Maximierte\" ignorieren"
L["Ignore epic for xp missions."] = "Epische Anh. bei Erfahrungsmissionen ignorieren"
L["Ignore for all missions"] = "Bei allen Missionen ignorieren"
L["Ignore for this mission"] = "Bei dieser Mission ignorieren"
L["Ignore rare missions"] = "Seltene Missionen ignorieren"
L["Increased Rewards"] = "Belohnungsbonus"
L["Item minimum level"] = "Minimale Gegenstandsstufe"
L["Item Tokens"] = "Gegenstandsmarken"
L["Left Click to see available missions"] = "Linksklicke hier, um alle verf\195\188gbaren Missionen zu sehen"
L["Legendary Items"] = "Legend\195\164re Gegenst\195\164nde"
L["Level 100 epic followers are not used for xp only missions."] = "Epische Stufe-100-Anh\195\164nger werden nicht bei Nur-EP-Missionen benutzt."
L["Makes main mission panel movable"] = "Macht das Hauptmissionsfenster verschiebbar"
L["Makes shipyard panel movable"] = "Macht das Werftfenster verschiebbar"
L["Maximize result"] = "Ergebnis maximieren"
L["Maximum mission duration."] = "Maximale Missionsdauer"
L["Minimum chance"] = "Minimalchance"
L["Minimum mission duration."] = "Minimale Missionsdauer"
L["Minimum needed chance"] = "Kleinstm\195\182gliche Chance"
L["Minimum requested level for equipment rewards"] = "Kleinstm\195\182gliche Stufe f\195\188r Ausr\195\188stungsbelohnungen"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "Kleinstm\195\182gliche Aufwertung f\195\188r Anh\195\164ngersets (Verbesserungen sind immer enthalten)"
L["Minimun chance success under which ignore missions"] = "Minimale Erfolgschance \226\128\147 alle Missionen, die darunter liegen, werden ignoriert"
L["Minumum needed chance"] = "Kleinstm\195\182gliche Chance"
L["Mission Control"] = "Missionssteuerung"
L["Mission Duration"] = "Missionsdauer"
L["Mission shown"] = "Anzahl gezeigter Missionen"
L["Mission shown for follower"] = "Angezeigte Missionen f\195\188r einen Anh\195\164nger"
L["Mission Success"] = "Missionserfolg"
L["Mission time reduced!"] = "Missionszeit reduziert!"
L["Mission with lower success chance will be ignored"] = "Missionen mit geringerer Erfolgschance werden ignoriert"
L["Missionlist"] = "Missionsliste"
L["Must reload interface to apply"] = "Das Interface muss neu geladen werden"
L["No confirmation"] = "Ohne Nachfragen"
L["No follower gained xp"] = "Kein Anh\195\164nger bekam Erfahrung"
L["No mission prefill"] = "Kein Vorab-Auff\195\188llen bei Missionen"
L["Not blacklisted"] = "Nicht ignoriert"
L["Nothing to report"] = "Es gibt nichts zu berichten"
L["Number of followers"] = "Anzahl der Anh\195\164nger"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "Nur die ersten %1$d Missionen mit einer Erfolgschance von \195\188ber %2$d%% werden angezeigt"
L["Only meaningful upgrades are shown"] = "Nur sinnvolle Aufwertungen werden angezeigt"
L["Original concept and interface by %s"] = "Originales Konzept und Interface von %s"
L["Original method"] = "Originale Methode"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "Originale Sortierung stellt die originale Sortiermethode wieder her, was auch immer sie war (wenn du ein anderes Addon zum Sortieren der Missionen hast, sollte dieses wieder wirksam werden)"
L["Other"] = "Andere"
L["Other rewards"] = "Sonstige Belohnungen"
L["Other settings"] = "Sonstige Einstellungen"
L["Other useful followers"] = "Andere n\195\188tzliche Anh\195\164nger"
L["Processing mission %d of %d"] = "Bearbeite Mission %d von %d"
L["Profession"] = "Beruf"
L["Racial Preference"] = "Volksvorliebe"
L["Rare missions will not be considered"] = "Seltene Missionen werden ignoriert"
L["Reagents"] = "Reagenzien"
L["Reputation Items"] = "Rufgegenst\195\164nde"
L["Reward type"] = "Belohnungstyp"
L["Right-Click to blacklist"] = "Rechtsklicken, um sie auf die Ignorierliste zu setzen"
L["Right-Click to remove from blacklist"] = "Rechtsklicken, um sie aus der Ignorierliste zu entfernen"
L["Rush orders"] = "Eilauftr\195\164ge"
L["Shipyard Appearance"] = "Werftdarstellung"
L["Show Garrison Commander menu"] = "Das Men\195\188 von Garrison Commander zeigen"
L["Show itemlevel"] = "Gegenstandsstufe zeigen"
L["Show upgrades"] = "Aufwertungen zeigen"
L["Show xp"] = "EP zeigen"
L["Slayer"] = "Schl\195\164chter"
L["Some follower"] = "Manche Anh\195\164nger"
L["Sort missions by:"] = "Sortiere Missionen nach:"
L["Submit all your mission at once. No question asked."] = "Beginne alle Missionen mit einem Klick. Es werden keine Fragen gestellt."
L["Success Chance"] = "Erfolgschance"
L["Swap upgrades positions"] = "Positionen der Aufwertungen tauschen"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "Schalte bei Missionen zwischen Garrison-Commander- und Master-Plan-Interface um."
L["Threat Counter"] = "Bedrohungskonter"
L["To go: %d"] = "Noch zu machen: %d"
L["Toggles Garrison Commander Menu Header on/off"] = "Schalte Men\195\188-Header vom Garrison Commander an/aus"
L["Toys and Mounts"] = "Spielzeuge und Reittiere"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "Entferne hier das H\195\164kchen, wenn du f\195\188r jeden Belohnungstyp eine spezifische Erfolgschance angeben willst."
L["Unlock Panel"] = "Fenster freigeben"
L["Upgrade %1$s to  %2$d itemlevel"] = "Werte %1$s um %2$d Gegenstandsstufe(n) auf"
L["Upgrading to |cff00ff00%d|r"] = "Verbessere auf |cff00ff00%d|r"
L["Use big screen"] = "Benutze das gro\195\159e Fenster"
L["Use GC Interface"] = "GC-Interface benutzen"
L["Uses armor token"] = "Benutzt R\195\188stungsverbesserung"
L["Uses weapon token"] = "Benutzt Waffenverbesserung"
L["When checked, show on each follower button missing xp to next level"] = "Wenn aktiviert, wird auf jedem Anh\195\164nger-Button die fehlende EP bis zur n\195\164chsten Stufe angezeigt"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "Wenn aktiviert, wird auf jedem Anh\195\164nger-Button die Waffen- und R\195\188stungsstufe bei maximierten Anh\195\164ngern angezeigt"
L["Xp incremented!"] = "EP erh\195\182ht!"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "Du verschwendest |cffff0000%d|cffffd200 Punkt(e)!!!"
L["You can also send mission one by one clicking on each button."] = "Du kannst eine Mission auch einzeln beginnen, indem du sie jeweils anklickst."
L["You can open the menu clicking on the icon in top right corner"] = "Du kannst das Men\195\188 \195\182ffnen, indem du auf das Symbol in der oberen rechten Ecke klickst."
L["You have ignored followers"] = "Du hast ignorierte Anh\195\164nger"
L["You never performed this mission"] = "Du hast diese Mission noch nie durchgef\195\188hrt."
L["You performed this mission %d times with a win ratio of"] = "Du hast diese Mission %d-mal durchgef\195\188hrt, mit einem Gewinnverh\195\164ltnis von"

	end
	L=l:NewLocale(me,"itIT")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4seguace:seguaci; con %s"
L["(Ignores low bias ones)"] = "(Ignorati i seguaci di livello basso)"
L["Add %1$d levels to %2$s"] = "Aggiunge %1$d livelli a %2$s"
L["Adds a list of other useful followers to tooltip"] = "Aggiunge altri seguaci utili al tooltip"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "Si applica solo alla modalit\195\160 dimensioni native, nascode la lista missioni per seguace se inattivo"
L["Allowed Rewards"] = "Ricompense ammesse"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "Accetta una minor percentuale di successo per le missioni che danno risorse. Con /gac gui puoi cambiare la percentuale (deault 80%)"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "Si applica quando 'massimizza risultato' \195\168 abilitato. Default 80%"
L["Applies the best armor set"] = "Applica il miglior set di armatura"
L["Applies the best armor upgrade"] = "Applica il miglior incremento di armatura"
L["Applies the best weapon set"] = "Applica il miglior set di armi"
L["Applies the best weapon upgrade"] = "Applica il milgior incremento di armi"
L["Archaelogy"] = "Archeologia"
L["Big screen"] = "Pannello grande"
L["Blacklisted"] = "Blacklistato"
L["Blacklisted missions are ignored in Mission Control"] = "Le missioni blacklistate vengono ignorate in Controllo Missione"
L["Building Final report"] = "Preparo il report finale"
L["Capped %1$s. Spend at least %2$d of them"] = "Limitato a %1$s. Spendine almeno %2$d"
L["Complete all missions without confirmation"] = "Completa tutte le mission senza conferme"
L["Consider again"] = "Prendi in considerazione di nuovo"
L["Disable if you dont want the full Garrison Commander Header."] = "Disabilita se vuoi la testata completa di Garrison Commander"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "Disabilita la popolazione automatica della pagina di missione. Puoi anche tenere premuto ctrl mentre clicchi il pulsante missione per non popolare quella specifica missione"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "Disabilitando questo avrete la vecchia interfaccia (1.1.8). Verr\195\160 effettuato un reload dell' interfaccia"
L["Do not show follower icon on plots"] = "Nascondi le icone dei seguaci dalle piazzole"
L["Duration Time"] = "Durata"
L["Enhance tooltip"] = "Migliora il tooltip"
L["Environment Preference"] = "Preferenze Ambientali"
L["Epic followers are NOT sent alone on xp only missions"] = "I seguaci epici NON vengono mandati da soli nelle missioni \"solo pe\""
L["Expiration Time"] = "Ora di scadenza"
L["Follower"] = "Seguace"
L["Follower equipment set or upgrade"] = "Milgioramento armi seguace"
L["Follower experience"] = "Esperienza del seguace"
L["Follower set minimum upgrade"] = "Incremento miniimo del seguace"
L["Follower Training"] = "Istruzione seguace"
L["Followers status "] = "Stato del seguace"
L["Garrison Appearance"] = "Aspetto della Garrison"
L["Garrison Comander Quick Mission Completion"] = "Completamento veloce missioni di Garrison Commander"
L["Garrison Commander Mission Control"] = "Controllo missione di Garrison Commander"
L["Global approx. xp reward"] = "Pe globali approssimativi"
L["Global success chance"] = "Chance globale di successo"
L["Gold incremented!"] = "Oro incrementato!"
L["Hide followers"] = "Nascondi seguaci"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = "Se marcato, cliccando un upgrade l'oggetto verr\195\160 consumato e il seguace aggiornato |cFFFF0000SENZA CONFERME|r"
L["IF checked, shows armors on the left and weapons on the right "] = "Inverte la posizione di armi e armature"
L["If you continue, you will lose them"] = "Se continui, le perderai"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "Se avete il Salvage Yard probabilmente questo non lo volete attivo"
L["Ignore \"maxed\""] = "Ignora \"maxati\""
L["Ignore epic for xp missions."] = "Ignora gli epici per le missioni solo pe"
L["Ignore for all missions"] = "Ignora per tutte le missioni"
L["Ignore for this mission"] = "Ignore per questa missione"
L["Ignore rare missions"] = "Ignora le missioni rare"
L["Increased Rewards"] = "Ricompensa Migliorata"
L["Item minimum level"] = "Livello minimo oggetto"
L["Item Tokens"] = "Gettone per oggetti"
L["Left Click to see available missions"] = "Clicca col sinistro per vedere le missioni disponibili"
L["Legendary Items"] = "Oggetti Leggendari"
L["Level 100 epic followers are not used for xp only missions."] = "I seguaci di livello 100 e qualit\195\160 epica non sono usati per le missioni di soli pe"
L["Makes main mission panel movable"] = "Rende movibile il pannello principale"
L["Makes shipyard panel movable"] = "Rende movibile il pannello dela Baia"
L["Maximize result"] = "Massimizza risultato"
L["Maximum mission duration."] = "Durata massima"
L["Minimum chance"] = "Chance minima"
L["Minimum mission duration."] = "Durata minima"
L["Minimum needed chance"] = "Percentuale minima di successo"
L["Minimum requested level for equipment rewards"] = "Livello minimo richiesto per le ricompense di tipo equipaggiamento"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "Livello minimo richiesto per gli upgrade dei followers (I token di miglioramenteo sono sempre inclusi)"
L["Minimun chance success under which ignore missions"] = "Chance di successo minima sotto cui ignorare le missioni"
L["Minumum needed chance"] = "Chance minima richiesta"
L["Mission Control"] = "Controllo Missione"
L["Mission Duration"] = "Durata della Missione"
L["Mission shown"] = "Missione mostrata"
L["Mission shown for follower"] = "Numero di missioni mostrato per seguace"
L["Mission Success"] = "Missione Completata"
L["Mission time reduced!"] = "Durata ridotta!"
L["Mission with lower success chance will be ignored"] = "Missioni con percentuale di successo inferiore verranno ignorate"
L["Missionlist"] = "Lista Missioni"
L["Must reload interface to apply"] = "E' necessario ricaricare l'interfaccia per applicarlo"
L["No confirmation"] = "Nessuna conferma"
L["No follower gained xp"] = "Nessun seguage ha ottenuto punti esperienza"
L["No mission prefill"] = "Non assegnare alle missioni"
L["Not blacklisted"] = "Non blacklistata"
L["Nothing to report"] = "Niente da riportare"
L["Number of followers"] = "Numero di seguaci"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "Vengono mostrare solo le prime %1$d missions con una speranza di successo supseriore al %2$d%%"
L["Only meaningful upgrades are shown"] = "Vengono mostrati solo gli upgrade che hanno senso per il seguace corrente"
L["Original concept and interface by %s"] = "Concetto originale e interfaccia di %s"
L["Original method"] = "Ordinamento originale"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "Ripristina il metodo di ordinamento originale, Se avete un altro addon che oridna le missioni, sara\195\160 questo addon a agestirlo."
L["Other"] = "Altro"
L["Other rewards"] = "Atre ricompense"
L["Other settings"] = "Altre impostazioni"
L["Other useful followers"] = "Altri seguagi che possono aiutare"
L["Processing mission %d of %d"] = "Elaboro la missione %d di %d"
L["Profession"] = "Professione"
L["Racial Preference"] = "Intesa Razziale"
L["Rare missions will not be considered"] = "Le missioni rare non vengono considerate"
L["Reagents"] = "Reagenti"
L["Reputation Items"] = "Item di reputazione"
L["Reward type"] = "Tipo ricompensa"
L["Right-Click to blacklist"] = "Clicca col destro per blacklistare"
L["Right-Click to remove from blacklist"] = "Clicca col destro per rimuovere dalla blacklist"
L["Rush orders"] = "Commissione"
L["Shipyard Appearance"] = "Aspetto della Baia"
L["Show Garrison Commander menu"] = "Mostra il menu di Garrison Commander"
L["Show itemlevel"] = "Mostra il livello degli item"
L["Show upgrades"] = "Mostra miglioramenti"
L["Show xp"] = "Mostrape"
L["Slayer"] = "Sterminio"
L["Some follower"] = "Un seguace"
L["Sort missions by:"] = "Ordina le missioni per:"
L["Submit all your mission at once. No question asked."] = "Lancia tutte le missioni con un click. Non chiede conferma"
L["Success Chance"] = "Probabilit\195\160 di successo"
L["Swap upgrades positions"] = "Inverti la posizione degli upgrades"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "Alterna fra l'interfaccia di Garrison Commander e quella di Master Plan"
L["Threat Counter"] = "Contrasto Minaccia"
L["To go: %d"] = "Mancano: %d"
L["Toggles Garrison Commander Menu Header on/off"] = "Attiva/disattiva il menu di Garrison Commander"
L["Toys and Mounts"] = "Giocattoli e Cavalcature"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "Disabilita per impostare una percentuale specifica di successo per ogni ricompensa"
L["Unlock Panel"] = "Sblocca il pannello"
L["Upgrade %1$s to  %2$d itemlevel"] = "Aggiorna %1$s a %2$d itemlevel"
L["Upgrading to |cff00ff00%d|r"] = "Aggiorno a |cff00ff00%d|r"
L["Use big screen"] = "Utilizza il pannello ingrandito"
L["Use GC Interface"] = "Usa l'interfaccia di GC"
L["Uses armor token"] = "Usa il token per l'armatura"
L["Uses weapon token"] = "Usa il token per le armi"
L["When checked, show on each follower button missing xp to next level"] = "Se attivo, su ogni seguace vengono mostrati i pe mancanti al prossimo livello"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "Se attivo, su ogni seguace viene mostrato l'itemlevel di armi e armatura"
L["Xp incremented!"] = "Pe aumentati!"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "Stai sprecando |cffff0000%d|cffffd200 punti!!!"
L["You can also send mission one by one clicking on each button."] = "Puoi anche inviare le missioni una per una cliccando sui pulsanti"
L["You can open the menu clicking on the icon in top right corner"] = "Puoi aprire il menu cliccando l'icona in alto a destra"
L["You have ignored followers"] = "Hai seguaci ignorati"
L["You never performed this mission"] = "Non hai mai fatto questa missione"
L["You performed this mission %d times with a win ratio of"] = "Hai fatto questa missione %d volde, con una percentuale di successo del"

	end
	L=l:NewLocale(me,"koKR")
	if (L) then
L["%s |4follower:followers; with %s"] = "%2$s|1\236\157\180;\234\176\128; \236\158\136\235\138\148 %1$s \236\182\148\236\162\133\236\158\144"
L["(Ignores low bias ones)"] = "(\237\149\152\235\130\152\236\157\152 \235\130\174\236\157\128 \236\132\177\237\150\165 \235\172\180\236\139\156)"
L["Add %1$d levels to %2$s"] = "%2$s\236\151\144 %1$d \235\160\136\235\178\168 \236\182\148\234\176\128"
L["Adds a list of other useful followers to tooltip"] = "\235\139\164\235\165\184 \236\156\160\236\154\169\237\149\156 \236\182\148\236\162\133\236\158\144\236\157\152 \235\170\169\235\161\157\236\157\132 \237\136\180\237\140\129\236\151\144 \236\182\148\234\176\128"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "\236\158\145\236\157\128 \237\153\148\235\169\180 \235\170\168\235\147\156\236\151\144\235\167\140 \236\152\129\237\150\165\236\157\132 \236\164\141\235\139\136\235\139\164, \236\132\160\237\131\157\237\149\152\236\167\128 \236\149\138\236\156\188\235\169\180 \236\182\148\236\162\133\236\158\144 \235\179\132\235\161\156 \236\158\132\235\172\180 \235\170\169\235\161\157\236\157\132 \236\136\168\234\185\129\235\139\136\235\139\164"
L["Allowed Rewards"] = "\236\160\129\236\154\169\235\144\156 \235\179\180\236\131\129"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "\236\158\144\236\155\144 \236\158\132\235\172\180\236\151\144 \235\130\174\236\157\128 \236\132\177\234\179\181 \237\153\149\235\165\160\236\157\132 \237\151\136\236\154\169\237\149\169\235\139\136\235\139\164. \235\176\177\235\182\132\236\156\168\236\157\132 \235\179\128\234\178\189\237\149\152\235\160\164\235\169\180 /gac gui\235\165\188 \236\130\172\236\154\169\237\149\152\236\132\184\236\154\148. \234\184\176\235\179\184\234\176\146\236\157\128 80%\236\158\133\235\139\136\235\139\164"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "'\234\178\176\234\179\188 \236\181\156\235\140\128\237\153\148'\234\176\128 \237\153\156\236\132\177\237\153\148\235\144\152\236\150\180 \236\158\136\236\157\132 \235\149\140 \236\160\129\236\154\169\235\144\169\235\139\136\235\139\164. \234\184\176\235\179\184\234\176\146\236\157\128 80%\236\158\133\235\139\136\235\139\164"
L["Applies the best armor set"] = "\236\181\156\234\179\160 \235\176\169\236\150\180\234\181\172 \236\132\184\237\138\184 \236\160\129\236\154\169"
L["Applies the best armor upgrade"] = "\236\181\156\234\179\160 \235\176\169\236\150\180\234\181\172 \234\176\149\237\153\148 \236\160\129\236\154\169"
L["Applies the best weapon set"] = "\236\181\156\234\179\160 \235\172\180\234\184\176 \236\132\184\237\138\184 \236\160\129\236\154\169"
L["Applies the best weapon upgrade"] = "\236\181\156\234\179\160 \235\172\180\234\184\176 \234\176\149\237\153\148 \236\160\129\236\154\169"
L["Archaelogy"] = "\234\179\160\234\179\160\237\149\153"
L["Big screen"] = "\237\129\176 \237\153\148\235\169\180"
L["Blacklisted"] = "\236\176\168\235\139\168\235\144\168"
L["Blacklisted missions are ignored in Mission Control"] = "\236\176\168\235\139\168\235\144\156 \236\158\132\235\172\180\235\138\148 \236\158\132\235\172\180 \236\160\156\236\150\180\236\151\144\236\132\156 \235\172\180\236\139\156\235\144\169\235\139\136\235\139\164"
L["Building Final report"] = "\236\181\156\236\162\133 \235\179\180\234\179\160\236\132\156 \236\158\145\236\132\177"
L["Capped %1$s. Spend at least %2$d of them"] = "%1$s\236\151\144 \235\143\132\235\139\172\237\150\136\236\138\181\235\139\136\235\139\164. \236\181\156\236\134\140 %2$d\236\157\152 \236\158\144\236\155\144\236\157\132 \236\130\172\236\154\169\237\149\152\236\132\184\236\154\148"
L["Complete all missions without confirmation"] = "\237\153\149\236\157\184\236\151\134\236\157\180 \235\170\168\235\147\160 \236\158\132\235\172\180 \236\153\132\235\163\140"
L["Consider again"] = "\235\139\164\236\139\156 \234\179\160\235\160\164\237\149\152\234\184\176"
L["Disable if you dont want the full Garrison Commander Header."] = "\236\160\132\236\178\180 Garrison Commander \237\151\164\235\141\148\235\165\188 \236\155\144\237\149\152\236\167\128 \236\149\138\236\156\188\235\169\180 \235\185\132\237\153\156\236\132\177\237\149\152\236\132\184\236\154\148."
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "\236\158\132\235\172\180 \237\142\152\236\157\180\236\167\128 \237\153\148\235\169\180\236\157\152 \236\158\144\235\143\153 \236\177\132\236\154\176\234\184\176\235\165\188 \235\185\132\237\153\156\236\132\177\237\149\169\235\139\136\235\139\164. \235\152\144\237\149\156 Ctrl \237\130\164\235\165\188 \235\136\132\235\165\180\234\179\160 \237\129\180\235\166\173\237\149\152\235\169\180 \235\139\168\236\157\188 \236\158\132\235\172\180\236\151\144\236\132\156 \235\185\132\237\153\156\236\132\177\237\149\169\235\139\136\235\139\164"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "\236\157\180\234\178\131\236\157\132 \235\185\132\237\153\156\236\132\177\237\149\152\235\169\180 1.1.8\236\157\152 \236\157\184\237\132\176\237\142\152\236\157\180\236\138\164\235\165\188 \236\160\156\234\179\181\237\149\169\235\139\136\235\139\164, \236\157\184\237\132\176\237\142\152\236\157\180\236\138\164 \236\158\172\236\139\156\236\158\145\236\157\180 \237\149\132\236\154\148\237\149\169\235\139\136\235\139\164"
L["Do not show follower icon on plots"] = "\234\181\172\236\132\177\236\151\144 \236\182\148\236\162\133\236\158\144 \236\149\132\236\157\180\236\189\152 \237\145\156\236\139\156\237\149\152\236\167\128 \236\149\138\234\184\176"
L["Duration Time"] = "\236\158\132\235\172\180 \236\136\152\237\150\137 \236\139\156\234\176\132"
L["Enhance tooltip"] = "\237\136\180\237\140\129 \234\176\149\237\153\148"
L["Environment Preference"] = "\236\132\160\237\152\184 \237\153\152\234\178\189"
L["Epic followers are NOT sent alone on xp only missions"] = "\236\152\129\236\155\133 \235\147\177\234\184\137 \236\182\148\236\162\133\236\158\144\235\138\148 \234\178\189\237\151\152\236\185\152 \236\158\132\235\172\180\236\151\144 \237\152\188\236\158\144 \235\179\180\235\130\180\236\167\128\236\167\128 \236\149\138\236\138\181\235\139\136\235\139\164"
L["Expiration Time"] = "\235\167\140\235\163\140 \236\139\156\234\176\132"
L["Follower"] = "\236\182\148\236\162\133\236\158\144"
L["Follower equipment set or upgrade"] = "\236\182\148\236\162\133\236\158\144 \236\158\165\235\185\132 \236\132\184\237\138\184 \235\152\144\235\138\148 \234\176\149\237\153\148"
L["Follower experience"] = "\236\182\148\236\162\133\236\158\144 \234\178\189\237\151\152\236\185\152"
L["Follower set minimum upgrade"] = "\236\182\148\236\162\133\236\158\144 \236\132\184\237\138\184 \236\181\156\236\134\140 \234\176\149\237\153\148"
L["Follower Training"] = "\236\182\148\236\162\133\236\158\144 \237\155\136\235\160\168"
L["Followers status "] = "\236\182\148\236\162\133\236\158\144 \236\131\129\237\131\156"
L["Garrison Appearance"] = "\236\163\188\235\145\148\236\167\128 \235\170\168\236\150\145"
L["Garrison Comander Quick Mission Completion"] = "Garrison Comander \235\185\160\235\165\184 \236\158\132\235\172\180 \236\153\132\235\163\140"
L["Garrison Commander Mission Control"] = "Garrison Commander \236\158\132\235\172\180 \236\160\156\236\150\180"
L["Global approx. xp reward"] = "\236\160\132\236\151\173 \236\152\136\236\131\129 \234\178\189\237\151\152\236\185\152 \235\179\180\236\131\129"
L["Global success chance"] = "\234\179\181\237\134\181 \236\132\177\234\179\181 \237\153\149\235\165\160"
L["Gold incremented!"] = "\234\179\168\235\147\156 \236\166\157\234\176\128\235\144\168!"
L["Hide followers"] = "\236\182\148\236\162\133\236\158\144 \236\136\168\234\184\176\234\184\176"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = "\236\132\160\237\131\157\237\149\152\234\179\160 \234\176\149\237\153\148 \236\149\132\236\157\180\236\189\152\236\157\132 \237\129\180\235\166\173\237\149\152\235\169\180 \236\149\132\236\157\180\237\133\156\236\157\132 \236\134\140\235\185\132\237\149\152\234\179\160 \236\182\148\236\162\133\236\158\144\235\165\188 \234\176\149\237\153\148\237\149\169\235\139\136\235\139\164, |cFFFF0000\236\149\132\235\172\180\234\178\131\235\143\132 \235\172\187\236\167\128 \236\149\138\236\138\181\235\139\136\235\139\164|r"
L["IF checked, shows armors on the left and weapons on the right "] = "\236\132\160\237\131\157\237\149\152\235\169\180 \235\176\169\236\150\180\234\181\172\235\165\188 \236\153\188\236\170\189\236\151\144 \235\172\180\234\184\176\235\165\188 \236\152\164\235\165\184\236\170\189\236\151\144 \237\145\156\236\139\156\237\149\169\235\139\136\235\139\164"
L["If you continue, you will lose them"] = "\234\179\132\236\134\141\237\149\152\235\169\180 \234\183\184\234\178\131\235\147\164\236\157\132 \236\158\131\236\138\181\235\139\136\235\139\164"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "\236\158\172\237\153\156\236\154\169 \236\178\152\235\166\172\236\158\165\236\157\180 \236\158\136\235\139\164\235\169\180 \236\157\180\234\178\131\236\157\132 \236\132\160\237\131\157\237\149\152\234\179\160 \236\139\182\236\167\128 \236\149\138\236\157\132 \234\178\131\236\158\133\235\139\136\235\139\164"
L["Ignore \"maxed\""] = "\"\236\181\156\235\140\128 \235\160\136\235\178\168\" \235\172\180\236\139\156"
L["Ignore epic for xp missions."] = "\234\178\189\237\151\152\236\185\152 \236\158\132\235\172\180\236\151\144 \236\152\129\236\155\133 \235\147\177\234\184\137 \235\172\180\236\139\156."
L["Ignore for all missions"] = "\235\170\168\235\147\160 \236\158\132\235\172\180 \235\172\180\236\139\156"
L["Ignore for this mission"] = "\236\157\180 \236\158\132\235\172\180 \235\172\180\236\139\156"
L["Ignore rare missions"] = "\237\157\172\234\183\128 \236\158\132\235\172\180 \235\172\180\236\139\156"
L["Increased Rewards"] = "\236\166\157\234\176\128\235\144\156 \235\179\180\236\131\129"
L["Item minimum level"] = "\236\149\132\236\157\180\237\133\156 \236\181\156\236\134\140 \235\160\136\235\178\168"
L["Item Tokens"] = "\236\149\132\236\157\180\237\133\156 \237\134\160\237\129\176"
L["Left Click to see available missions"] = "\236\153\188\236\170\189 \237\129\180\235\166\173\237\149\152\236\151\172 \236\136\152\237\150\137 \234\176\128\235\138\165\237\149\156 \236\158\132\235\172\180 \237\153\149\236\157\184"
L["Legendary Items"] = "\236\160\132\236\132\164 \236\149\132\236\157\180\237\133\156"
L["Level 100 epic followers are not used for xp only missions."] = "\235\160\136\235\178\168 100 \236\152\129\236\155\133 \235\147\177\234\184\137 \236\182\148\236\162\133\236\158\144\235\138\148 \234\178\189\237\151\152\236\185\152 \236\158\132\235\172\180\236\151\144 \236\130\172\236\154\169\237\149\152\236\167\128 \236\149\138\236\138\181\235\139\136\235\139\164."
L["Makes main mission panel movable"] = "\236\163\188 \236\158\132\235\172\180 \236\176\189 \236\157\180\235\143\153 \234\176\128\235\138\165\237\149\152\234\178\140 \235\167\140\235\147\164\234\184\176"
L["Makes shipyard panel movable"] = "\237\149\180\236\131\129 \236\158\132\235\172\180 \236\176\189 \236\157\180\235\143\153 \234\176\128\235\138\165\237\149\152\234\178\140 \235\167\140\235\147\164\234\184\176"
L["Maximize result"] = "\234\178\176\234\179\188 \236\181\156\235\140\128\237\153\148"
L["Maximum mission duration."] = "\236\181\156\235\140\128 \236\158\132\235\172\180 \236\167\128\236\134\141\236\139\156\234\176\132."
L["Minimum chance"] = "\236\181\156\236\134\140 \237\153\149\235\165\160"
L["Minimum mission duration."] = "\236\181\156\236\134\140 \236\158\132\235\172\180 \236\167\128\236\134\141\236\139\156\234\176\132."
L["Minimum needed chance"] = "\236\181\156\236\134\140 \236\154\148\234\181\172 \237\153\149\235\165\160"
L["Minimum requested level for equipment rewards"] = "\236\158\165\235\185\132 \235\179\180\236\131\129\236\151\144 \235\140\128\237\149\156 \236\181\156\236\134\140 \236\154\148\234\181\172 \235\160\136\235\178\168"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "\236\182\148\236\162\133\236\158\144 \236\132\184\237\138\184\236\151\144 \235\140\128\237\149\156 \236\181\156\236\134\140 \236\154\148\234\181\172 \234\176\149\237\153\148 (\237\150\165\236\131\129\236\157\128 \236\150\184\236\160\156\235\130\152 \237\143\172\237\149\168)"
L["Minimun chance success under which ignore missions"] = "\236\158\132\235\172\180\235\165\188 \235\172\180\236\139\156\237\149\160 \236\181\156\236\134\140 \236\132\177\234\179\181 \237\153\149\235\165\160"
L["Minumum needed chance"] = "\236\181\156\236\134\140 \236\154\148\234\181\172 \237\153\149\235\165\160"
L["Mission Control"] = "\236\158\132\235\172\180 \236\160\156\236\150\180"
L["Mission Duration"] = "\236\158\132\235\172\180 \236\167\128\236\134\141\236\139\156\234\176\132"
L["Mission shown"] = "\237\145\156\236\139\156\235\144\156 \236\158\132\235\172\180"
L["Mission shown for follower"] = "\236\182\148\236\162\133\236\158\144\236\151\144 \237\145\156\236\139\156\235\144\156 \236\158\132\235\172\180"
L["Mission Success"] = "\236\158\132\235\172\180 \236\132\177\234\179\181"
L["Mission time reduced!"] = "\236\158\132\235\172\180 \236\139\156\234\176\132 \234\176\144\236\134\140\235\144\168!"
L["Mission with lower success chance will be ignored"] = "\235\130\174\236\157\128 \236\132\177\234\179\181 \237\153\149\235\165\160\236\157\152 \236\158\132\235\172\180\235\138\148 \235\172\180\236\139\156\237\149\169\235\139\136\235\139\164"
L["Missionlist"] = "\236\158\132\235\172\180 \235\170\169\235\161\157"
L["Must reload interface to apply"] = "\236\160\129\236\154\169\237\149\152\235\160\164\235\169\180 \236\157\184\237\132\176\237\142\152\236\157\180\236\138\164\235\165\188 \235\176\152\235\147\156\236\139\156 \236\158\172\236\139\156\236\158\145\237\149\180\236\149\188 \237\149\169\235\139\136\235\139\164"
L["No confirmation"] = "\237\153\149\236\157\184 \236\151\134\236\157\140"
L["No follower gained xp"] = "\234\178\189\237\151\152\236\185\152\235\165\188 \237\154\141\235\147\157\237\149\156 \236\182\148\236\162\133\236\158\144 \236\151\134\236\157\140"
L["No mission prefill"] = "\236\158\132\235\172\180 \235\175\184\235\166\172 \236\177\132\236\154\176\236\167\128 \236\149\138\234\184\176"
L["Not blacklisted"] = "\236\176\168\235\139\168 \235\170\169\235\161\157 \236\151\134\236\157\140"
L["Nothing to report"] = "\235\179\180\234\179\160\237\149\160 \235\130\180\236\154\169 \236\151\134\236\157\140"
L["Number of followers"] = "\236\182\148\236\162\133\236\158\144\236\157\152 \236\136\152"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "\236\132\177\234\179\181 \237\153\149\235\165\160 %2$d%% \236\157\180\236\131\129\236\157\152 \236\178\171 %1$d\234\176\156 \236\158\132\235\172\180\235\167\140 \237\145\156\236\139\156\237\149\169\235\139\136\235\139\164"
L["Only meaningful upgrades are shown"] = "\236\157\152\235\175\184\236\158\136\235\138\148 \234\176\149\237\153\148\235\167\140 \237\145\156\236\139\156\237\149\169\235\139\136\235\139\164"
L["Original concept and interface by %s"] = "%s\236\151\144 \236\157\152\237\149\156 \236\155\144\235\158\152\236\157\152 \234\176\156\235\133\144\234\179\188 \236\157\184\237\132\176\237\142\152\236\157\180\236\138\164"
L["Original method"] = "\236\155\144\235\158\152\236\157\152 \235\176\169\235\178\149"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "\236\155\144\235\158\152\236\157\152 \236\160\149\235\160\172\236\157\128 \236\155\144\235\158\152\236\157\152 \236\160\149\235\160\172 \235\176\169\235\178\149\236\157\132 \235\179\181\236\155\144\237\149\169\235\139\136\235\139\164 (\236\158\132\235\172\180\235\165\188 \236\160\149\235\160\172\237\149\152\235\138\148 \235\139\164\235\165\184 \236\149\160\235\147\156\236\152\168\236\157\180 \236\158\136\235\139\164\235\169\180 \235\139\164\236\139\156 \236\139\156\236\158\145\237\149\180\236\149\188 \237\149\169\235\139\136\235\139\164)"
L["Other"] = "\234\184\176\237\131\128"
L["Other rewards"] = "\234\184\176\237\131\128 \235\179\180\236\131\129"
L["Other settings"] = "\234\184\176\237\131\128 \236\132\164\236\160\149"
L["Other useful followers"] = "\235\139\164\235\165\184 \236\156\160\236\154\169\237\149\156 \236\182\148\236\162\133\236\158\144"
L["Processing mission %d of %d"] = "%d / %d \236\158\132\235\172\180 \236\178\152\235\166\172 \236\164\145"
L["Profession"] = "\236\160\132\235\172\184 \234\184\176\236\136\160"
L["Racial Preference"] = "\236\132\160\237\152\184 \236\162\133\236\161\177"
L["Rare missions will not be considered"] = "\237\157\172\234\183\128 \236\158\132\235\172\180\235\138\148 \234\179\160\235\160\164\237\149\152\236\167\128 \236\149\138\236\138\181\235\139\136\235\139\164"
L["Reagents"] = "\236\158\172\235\163\140"
L["Reputation Items"] = "\237\143\137\237\140\144 \236\149\132\236\157\180\237\133\156"
L["Reward type"] = "\235\179\180\236\131\129 \236\156\160\237\152\149"
L["Right-Click to blacklist"] = "\236\152\164\235\165\184\236\170\189 \237\129\180\235\166\173\237\149\152\236\151\172 \236\176\168\235\139\168"
L["Right-Click to remove from blacklist"] = "\236\152\164\235\165\184\236\170\189 \237\129\180\235\166\173\237\149\152\236\151\172 \236\176\168\235\139\168 \235\170\169\235\161\157\236\151\144\236\132\156 \236\160\156\234\177\176"
L["Rush orders"] = "\234\184\180\234\184\137 \236\163\188\235\172\184"
L["Shipyard Appearance"] = "\237\149\180\236\131\129 \237\149\168\235\140\128 \235\170\168\236\150\145"
L["Show Garrison Commander menu"] = "Garrison Commander \235\169\148\235\137\180 \237\145\156\236\139\156"
L["Show itemlevel"] = "\236\149\132\236\157\180\237\133\156 \235\160\136\235\178\168 \237\145\156\236\139\156"
L["Show upgrades"] = "\234\176\149\237\153\148 \237\145\156\236\139\156"
L["Show xp"] = "\234\178\189\237\151\152\236\185\152 \237\145\156\236\139\156"
L["Slayer"] = "\237\149\153\236\130\180\236\158\144"
L["Some follower"] = "\235\170\135\235\170\135 \236\182\148\236\162\133\236\158\144"
L["Sort missions by:"] = "\236\158\132\235\172\180 \236\160\149\235\160\172 \235\176\169\235\178\149:"
L["Submit all your mission at once. No question asked."] = "\235\139\185\236\139\160\236\157\152 \236\158\132\235\172\180\235\165\188 \237\149\156\235\178\136\236\151\144 \236\160\156\236\182\156\237\149\169\235\139\136\235\139\164. \236\149\132\235\172\180 \234\178\131\235\143\132 \235\172\187\236\167\128 \236\149\138\236\138\181\235\139\136\235\139\164."
L["Success Chance"] = "\236\132\177\234\179\181 \237\153\149\235\165\160"
L["Swap upgrades positions"] = "\234\176\149\237\153\148 \236\156\132\236\185\152 \236\160\132\237\153\152"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "\236\158\132\235\172\180\236\151\144 Garrison Commander\236\153\128 Master Plan \236\157\184\237\132\176\237\142\152\236\157\180\236\138\164 \234\176\132\236\151\144 \236\160\132\237\153\152\237\149\152\234\184\176"
L["Threat Counter"] = "\236\156\132\237\152\145 \236\154\148\236\134\140 \235\140\128\236\157\145"
L["To go: %d"] = "\235\160\136\235\178\168 \236\131\129\236\138\185: %d"
L["Toggles Garrison Commander Menu Header on/off"] = "Garrison Commander \235\169\148\235\137\180 \237\151\164\235\141\148 \236\188\156\234\184\176/\235\129\132\234\184\176 \236\160\132\237\153\152"
L["Toys and Mounts"] = "\236\158\165\235\130\156\234\176\144\234\179\188 \237\131\136\234\178\131"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "\236\132\160\237\131\157\237\149\180\236\160\156\237\149\152\235\169\180 \234\176\129 \235\179\180\236\131\129 \236\156\160\237\152\149\236\151\144 \237\138\185\236\160\149 \236\132\177\234\179\181 \237\153\149\235\165\160\236\157\132 \236\132\164\236\160\149\237\149\160 \236\136\152 \236\158\136\236\138\181\235\139\136\235\139\164"
L["Unlock Panel"] = "\236\176\189 \236\158\160\234\184\136\237\149\180\236\160\156"
L["Upgrade %1$s to  %2$d itemlevel"] = "%1$s\236\151\144\236\132\156 %2$d \236\149\132\236\157\180\237\133\156 \235\160\136\235\178\168\235\161\156 \234\176\149\237\153\148"
L["Upgrading to |cff00ff00%d|r"] = "|cff00ff00%d|r|1\236\156\188\235\161\156;\235\161\156; \236\151\133\234\183\184\235\160\136\236\157\180\235\147\156 \236\164\145"
L["Use big screen"] = "\237\129\176 \237\153\148\235\169\180 \236\130\172\236\154\169"
L["Use GC Interface"] = "GC \236\157\184\237\132\176\237\142\152\236\157\180\236\138\164 \236\130\172\236\154\169"
L["Uses armor token"] = "\235\176\169\236\150\180\234\181\172 \237\134\160\237\129\176 \236\130\172\236\154\169"
L["Uses weapon token"] = "\235\172\180\234\184\176 \237\134\160\237\129\176 \236\130\172\236\154\169"
L["When checked, show on each follower button missing xp to next level"] = "\236\132\160\237\131\157\237\149\152\235\169\180 \234\176\129 \236\182\148\236\162\133\236\158\144 \235\178\132\237\138\188\236\151\144 \235\139\164\236\157\140 \235\160\136\235\178\168\234\185\140\236\167\128 \235\182\128\236\161\177\237\149\156 \234\178\189\237\151\152\236\185\152\234\176\128 \237\145\156\236\139\156\235\144\169\235\139\136\235\139\164"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "\236\132\160\237\131\157\237\149\152\235\169\180 \236\181\156\234\179\160 \235\160\136\235\178\168 \236\182\148\236\162\133\236\158\144\236\157\152 \235\172\180\234\184\176\236\153\128 \235\176\169\236\150\180\234\181\172 \235\160\136\235\178\168\236\157\180 \234\176\129 \236\182\148\236\162\133\236\158\144 \235\178\132\237\138\188\236\151\144 \237\145\156\236\139\156\235\144\169\235\139\136\235\139\164"
L["Xp incremented!"] = "\234\178\189\237\151\152\236\185\152 \236\166\157\234\176\128\235\144\168!"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "|cffff0000%d|cffffd200 \237\143\172\236\157\184\237\138\184\235\165\188 \235\130\173\235\185\132 \236\164\145\236\158\133\235\139\136\235\139\164!!!"
L["You can also send mission one by one clicking on each button."] = "\234\176\129 \235\178\132\237\138\188\236\157\132 \237\149\156\235\178\136 \237\129\180\235\166\173\237\149\152\236\151\172 \236\158\132\235\172\180\235\165\188 \237\149\152\235\130\152\236\148\169 \235\179\180\235\130\188 \236\136\152 \236\158\136\236\138\181\235\139\136\235\139\164."
L["You can open the menu clicking on the icon in top right corner"] = "\236\154\176\236\184\161 \236\131\129\235\139\168 \235\170\168\236\132\156\235\166\172\236\151\144 \236\158\136\235\138\148 \236\149\132\236\157\180\236\189\152\236\157\132 \237\129\180\235\166\173\237\149\152\235\169\180 \235\169\148\235\137\180\235\165\188 \236\151\180 \236\136\152 \236\158\136\236\138\181\235\139\136\235\139\164"
L["You have ignored followers"] = "\235\172\180\236\139\156\235\144\156 \236\182\148\236\162\133\236\158\144\234\176\128 \236\158\136\236\138\181\235\139\136\235\139\164"
L["You never performed this mission"] = "\236\157\180 \236\158\132\235\172\180\235\165\188 \236\136\152\237\150\137\237\149\156 \236\160\129\236\157\180 \236\151\134\236\138\181\235\139\136\235\139\164"
L["You performed this mission %d times with a win ratio of"] = "\236\157\180 \236\158\132\235\172\180\235\165\188 \235\139\164\236\157\140\236\157\152 \236\132\177\234\179\181 \237\153\149\235\165\160\235\161\156 %d\235\178\136 \236\136\152\237\150\137\237\150\136\236\138\181\235\139\136\235\139\164:"

	end
	L=l:NewLocale(me,"esMX")
	if (L) then
--[[Translation missing --]]
--[[ L["%s |4follower:followers; with %s"] = ""--]] 
--[[Translation missing --]]
--[[ L["(Ignores low bias ones)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Add %1$d levels to %2$s"] = ""--]] 
--[[Translation missing --]]
--[[ L["Adds a list of other useful followers to tooltip"] = ""--]] 
--[[Translation missing --]]
--[[ L["Affects only little screen mode, hiding the per follower mission list if not checked"] = ""--]] 
--[[Translation missing --]]
--[[ L["Allowed Rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applied when 'maximize result' is enabled. Default is 80%"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best armor set"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best armor upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best weapon set"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best weapon upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Archaelogy"] = ""--]] 
--[[Translation missing --]]
--[[ L["Big screen"] = ""--]] 
--[[Translation missing --]]
--[[ L["Blacklisted"] = ""--]] 
--[[Translation missing --]]
--[[ L["Blacklisted missions are ignored in Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Building Final report"] = ""--]] 
--[[Translation missing --]]
--[[ L["Capped %1$s. Spend at least %2$d of them"] = ""--]] 
--[[Translation missing --]]
--[[ L["Complete all missions without confirmation"] = ""--]] 
--[[Translation missing --]]
--[[ L["Consider again"] = ""--]] 
--[[Translation missing --]]
--[[ L["Disable if you dont want the full Garrison Commander Header."] = ""--]] 
--[[Translation missing --]]
--[[ L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = ""--]] 
--[[Translation missing --]]
--[[ L["Do not show follower icon on plots"] = ""--]] 
--[[Translation missing --]]
--[[ L["Duration Time"] = ""--]] 
--[[Translation missing --]]
--[[ L["Enhance tooltip"] = ""--]] 
--[[Translation missing --]]
--[[ L["Environment Preference"] = ""--]] 
--[[Translation missing --]]
--[[ L["Epic followers are NOT sent alone on xp only missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Expiration Time"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower equipment set or upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower experience"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower set minimum upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower Training"] = ""--]] 
--[[Translation missing --]]
--[[ L["Followers status "] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Appearance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Comander Quick Mission Completion"] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Commander Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Global approx. xp reward"] = ""--]] 
--[[Translation missing --]]
--[[ L["Global success chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Gold incremented!"] = ""--]] 
--[[Translation missing --]]
--[[ L["Hide followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = ""--]] 
--[[Translation missing --]]
--[[ L["IF checked, shows armors on the left and weapons on the right "] = ""--]] 
--[[Translation missing --]]
--[[ L["If you continue, you will lose them"] = ""--]] 
--[[Translation missing --]]
--[[ L["IF you have a Salvage Yard you probably dont want to have this one checked"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore \"maxed\""] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore epic for xp missions."] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore for all missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore for this mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore rare missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Increased Rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Item minimum level"] = ""--]] 
--[[Translation missing --]]
--[[ L["Item Tokens"] = ""--]] 
--[[Translation missing --]]
--[[ L["Left Click to see available missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Legendary Items"] = ""--]] 
--[[Translation missing --]]
--[[ L["Level 100 epic followers are not used for xp only missions."] = ""--]] 
--[[Translation missing --]]
--[[ L["Makes main mission panel movable"] = ""--]] 
--[[Translation missing --]]
--[[ L["Makes shipyard panel movable"] = ""--]] 
--[[Translation missing --]]
--[[ L["Maximize result"] = ""--]] 
--[[Translation missing --]]
--[[ L["Maximum mission duration."] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum mission duration."] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum needed chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum requested level for equipment rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum requested upgrade for followers set (Enhancements are always included)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimun chance success under which ignore missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minumum needed chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Duration"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission shown for follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Success"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission time reduced!"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission with lower success chance will be ignored"] = ""--]] 
--[[Translation missing --]]
--[[ L["Missionlist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Must reload interface to apply"] = ""--]] 
--[[Translation missing --]]
--[[ L["No confirmation"] = ""--]] 
--[[Translation missing --]]
--[[ L["No follower gained xp"] = ""--]] 
--[[Translation missing --]]
--[[ L["No mission prefill"] = ""--]] 
--[[Translation missing --]]
--[[ L["Not blacklisted"] = ""--]] 
--[[Translation missing --]]
--[[ L["Nothing to report"] = ""--]] 
--[[Translation missing --]]
--[[ L["Number of followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Only first %1$d missions with over %2$d%% chance of success are shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Only meaningful upgrades are shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original concept and interface by %s"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original method"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other settings"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other useful followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Processing mission %d of %d"] = ""--]] 
--[[Translation missing --]]
--[[ L["Profession"] = ""--]] 
--[[Translation missing --]]
--[[ L["Racial Preference"] = ""--]] 
--[[Translation missing --]]
--[[ L["Rare missions will not be considered"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reagents"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reputation Items"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reward type"] = ""--]] 
--[[Translation missing --]]
--[[ L["Right-Click to blacklist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Right-Click to remove from blacklist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Rush orders"] = ""--]] 
--[[Translation missing --]]
--[[ L["Shipyard Appearance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show Garrison Commander menu"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show itemlevel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show upgrades"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show xp"] = ""--]] 
--[[Translation missing --]]
--[[ L["Slayer"] = ""--]] 
--[[Translation missing --]]
--[[ L["Some follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Sort missions by:"] = ""--]] 
--[[Translation missing --]]
--[[ L["Submit all your mission at once. No question asked."] = ""--]] 
--[[Translation missing --]]
--[[ L["Success Chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Swap upgrades positions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Switch between Garrison Commander and Master Plan interface for missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Threat Counter"] = ""--]] 
--[[Translation missing --]]
--[[ L["To go: %d"] = ""--]] 
--[[Translation missing --]]
--[[ L["Toggles Garrison Commander Menu Header on/off"] = ""--]] 
--[[Translation missing --]]
--[[ L["Toys and Mounts"] = ""--]] 
--[[Translation missing --]]
--[[ L["Unchecking this will allow you to set specific success chance for each reward type"] = ""--]] 
--[[Translation missing --]]
--[[ L["Unlock Panel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Upgrade %1$s to  %2$d itemlevel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Upgrading to |cff00ff00%d|r"] = ""--]] 
--[[Translation missing --]]
--[[ L["Use big screen"] = ""--]] 
--[[Translation missing --]]
--[[ L["Use GC Interface"] = ""--]] 
--[[Translation missing --]]
--[[ L["Uses armor token"] = ""--]] 
--[[Translation missing --]]
--[[ L["Uses weapon token"] = ""--]] 
--[[Translation missing --]]
--[[ L["When checked, show on each follower button missing xp to next level"] = ""--]] 
--[[Translation missing --]]
--[[ L["When checked, show on each follower button weapon and armor level for maxed followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Xp incremented!"] = ""--]] 
--[[Translation missing --]]
--[[ L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = ""--]] 
--[[Translation missing --]]
--[[ L["You can also send mission one by one clicking on each button."] = ""--]] 
--[[Translation missing --]]
--[[ L["You can open the menu clicking on the icon in top right corner"] = ""--]] 
--[[Translation missing --]]
--[[ L["You have ignored followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["You never performed this mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["You performed this mission %d times with a win ratio of"] = ""--]] 

	end
	L=l:NewLocale(me,"ruRU")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4\209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176:\209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\184; \209\129 %s"
L["(Ignores low bias ones)"] = "(\208\152\208\179\208\189\208\190\209\128\208\184\209\128\209\131\208\181\209\130 \208\189\208\184\208\183\208\186\208\184\208\185 \209\131\209\128\208\190\208\178\208\181\208\189\209\140 \209\129\208\188\208\181\209\137\208\181\208\189\208\184\209\143)"
L["Add %1$d levels to %2$s"] = "\208\148\208\190\208\177\208\176\208\178\209\140\209\130\208\181 %1$d \209\131\209\128\208\190\208\178\208\189\208\184 \208\178 %2$s"
L["Adds a list of other useful followers to tooltip"] = "\208\148\208\190\208\177\208\176\208\178\208\187\209\143\208\181\209\130 \209\129\208\191\208\184\209\129\208\190\208\186 \208\180\209\128\209\131\208\179\208\184\209\133 \208\191\208\190\208\187\208\181\208\183\208\189\209\139\209\133 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\190\208\178 \208\178\208\190 \208\178\209\129\208\191\208\187\209\139\208\178\208\176\209\142\209\137\209\131\209\142 \208\191\208\190\208\180\209\129\208\186\208\176\208\183\208\186\209\131"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "\208\146\208\187\208\184\209\143\208\181\209\130 \209\130\208\190\208\187\209\140\208\186\208\190 \208\189\208\176 \208\189\208\181\208\177\208\190\208\187\209\140\209\136\208\190\208\185 \209\141\208\186\209\128\208\176\208\189\208\189\209\139\208\185 \209\128\208\181\208\182\208\184\208\188, \209\129\208\186\209\128\209\139\208\178\208\176\209\143 \209\129\208\191\208\184\209\129\208\190\208\186 \208\188\208\184\209\129\209\129\208\184\208\185 \208\180\208\187\209\143 \208\186\208\176\208\182\208\180\208\190\208\179\208\190 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176, \208\181\209\129\208\187\208\184 \208\189\208\181 \209\131\209\129\209\130\208\176\208\189\208\190\208\178\208\187\208\181\208\189 \209\132\208\187\208\176\208\182\208\190\208\186"
L["Allowed Rewards"] = "\208\160\208\176\208\183\209\128\208\181\209\136\208\181\208\189\208\189\209\139\208\181 \208\189\208\176\208\179\209\128\208\176\208\180\209\139"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "\208\159\208\190\208\183\208\178\208\190\208\187\209\143\208\181\209\130 \209\129\208\189\208\184\208\183\208\184\209\130\209\140 \208\191\209\128\208\190\209\134\208\181\208\189\209\130 \209\131\209\129\208\191\208\181\209\133\208\176 \208\180\208\187\209\143 \208\188\208\184\209\129\209\129\208\184\208\185 \209\129 \209\128\208\181\209\129\209\131\209\128\209\129\208\176\208\188\208\184. \208\152\209\129\208\191\208\190\208\187\209\140\208\183\209\131\208\185\209\130\208\181 \208\186\208\190\208\188\208\176\208\189\208\180\209\131 /gac \208\180\208\187\209\143 \208\184\208\183\208\188\208\181\208\189\208\181\208\189\208\184\209\143 \208\191\209\128\208\190\209\134\208\181\208\189\209\130\208\176. \208\159\208\190 \209\131\208\188\208\190\208\187\209\135\208\176\208\189\208\184\209\142 80%"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "\208\159\209\128\208\184\208\188\208\181\208\189\209\143\208\181\209\130\209\129\209\143, \208\186\208\190\208\179\208\180\208\176 \208\178\208\186\208\187\209\142\209\135\208\181\208\189 \208\191\208\176\209\128\208\176\208\188\208\181\209\130\209\128 \194\171\208\188\208\176\208\186\209\129\208\184\208\188\208\184\208\183\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \209\128\208\181\208\183\209\131\208\187\209\140\209\130\208\176\209\130\194\187. \208\159\208\190 \209\131\208\188\208\190\208\187\209\135\208\176\208\189\208\184\209\142 80%"
L["Applies the best armor set"] = "\208\159\209\128\208\184\208\188\208\181\208\189\209\143\208\181\209\130 \208\187\209\131\209\135\209\136\208\184\208\185 \208\186\208\190\208\188\208\191\208\187\208\181\208\186\209\130 \208\177\209\128\208\190\208\189\208\184"
L["Applies the best armor upgrade"] = "\208\159\209\128\208\184\208\188\208\181\208\189\209\143\208\181\209\130 \208\187\209\131\209\135\209\136\208\181\208\181 \208\190\208\177\208\189\208\190\208\178\208\187\208\181\208\189\208\184\208\181 \208\177\209\128\208\190\208\189\208\184"
L["Applies the best weapon set"] = "\208\159\209\128\208\184\208\188\208\181\208\189\209\143\208\181\209\130 \208\187\209\131\209\135\209\136\208\184\208\185 \208\189\208\176\208\177\208\190\209\128 \208\190\209\128\209\131\208\182\208\184\209\143"
L["Applies the best weapon upgrade"] = "\208\159\209\128\208\184\208\188\208\181\208\189\209\143\208\181\209\130 \208\187\209\131\209\135\209\136\208\181\208\181 \208\190\208\177\208\189\208\190\208\178\208\187\208\181\208\189\208\184\208\181 \208\190\209\128\209\131\208\182\208\184\209\143"
L["Archaelogy"] = "\208\144\209\128\209\133\208\181\208\190\208\187\208\190\208\179\208\184\209\143"
L["Big screen"] = "\208\145\208\190\208\187\209\140\209\136\208\190\208\185 \209\141\208\186\209\128\208\176\208\189"
L["Blacklisted"] = "\208\167\208\181\209\128\208\189\209\139\208\185 \208\161\208\191\208\184\209\129\208\190\208\186"
L["Blacklisted missions are ignored in Mission Control"] = "\208\167\208\181\209\128\208\189\209\139\208\185 \209\129\208\191\208\184\209\129\208\190\208\186 \208\188\208\184\209\129\209\129\208\184\208\185 \208\184\208\179\208\189\208\190\209\128\208\184\209\128\209\131\209\142\209\130\209\129\209\143 \208\178 \209\131\208\191\209\128\208\176\208\178\208\187\208\181\208\189\208\184\208\184 \208\188\208\184\209\129\209\129\208\184\209\143\208\188\208\184"
L["Building Final report"] = "\208\158\208\186\208\190\208\189\209\135\208\176\209\130\208\181\208\187\209\140\208\189\208\190\208\181 \208\191\208\190\209\129\209\130\209\128\208\190\208\181\208\189\208\184\208\181 \208\190\209\130\209\135\208\181\209\130\208\176"
L["Capped %1$s. Spend at least %2$d of them"] = [=[\208\148\208\190\209\129\209\130\208\184\208\179\208\189\209\131\209\130\208\190 %1$. \208\159\208\190\209\130\209\128\208\176\209\130\209\140\209\130\208\181 \209\133\208\190\209\130\209\143 \208\177\209\139 2%$
]=]
L["Complete all missions without confirmation"] = "\208\151\208\176\208\178\208\181\209\128\209\136\208\184\209\130\209\140 \208\178\209\129\208\181 \208\183\208\176\208\180\208\176\208\189\208\184\209\143 \208\177\208\181\208\183 \208\191\208\190\208\180\209\130\208\178\208\181\209\128\208\182\208\180\208\181\208\189\208\184\209\143"
L["Consider again"] = "\208\146\208\189\208\190\208\178\209\140 \209\128\208\176\209\129\209\129\208\188\208\190\209\130\209\128\208\181\209\130\209\140"
L["Disable if you dont want the full Garrison Commander Header."] = "\208\158\209\130\208\186\208\187\209\142\209\135\208\184\209\130\208\181, \208\181\209\129\208\187\208\184 \208\178\209\139 \208\189\208\181 \209\133\208\190\209\130\208\184\209\130\208\181 \208\191\208\190\208\187\208\189\209\139\208\185 \208\183\208\176\208\179\208\190\208\187\208\190\208\178\208\190\208\186 Garrison Commander."
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "\208\158\209\130\208\186\208\187\209\142\209\135\208\176\208\181\209\130 \208\176\208\178\209\130\208\190\208\188\208\176\209\130\208\184\209\135\208\181\209\129\208\186\208\190\208\181 \208\183\208\176\208\191\208\190\208\187\208\189\208\181\208\189\208\184\208\181 \209\141\208\186\209\128\208\176\208\189\208\176 \209\129\209\130\209\128\208\176\208\189\208\184\209\134\209\139 \208\188\208\184\209\129\209\129\208\184\208\184. \208\146\209\139 \209\130\208\176\208\186\208\182\208\181 \208\188\208\190\208\182\208\181\209\130\208\181 \208\189\208\176\208\182\208\176\209\130\209\140 \208\186\208\189\208\190\208\191\208\186\209\131 \209\131\208\191\209\128\208\176\208\178\208\187\208\181\208\189\208\184\209\143, \209\135\209\130\208\190\208\177\209\139 \208\190\209\130\208\186\208\187\209\142\209\135\208\184\209\130\209\140 \208\181\208\179\208\190 \208\180\208\187\209\143 \208\190\208\180\208\189\208\190\208\185 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "\208\158\209\130\208\186\208\187\209\142\209\135\208\181\208\189\208\184\208\181 \209\141\209\130\208\190\208\179\208\190 \208\191\208\176\209\128\208\176\208\188\208\181\209\130\209\128\208\176 \208\180\208\176\209\129\209\130 \208\178\208\176\208\188 \208\184\208\189\209\130\208\181\209\128\209\132\208\181\208\185\209\129 \208\178\208\181\209\128\209\129\208\184\208\184 1.1.8. \208\157\208\181\208\190\208\177\209\133\208\190\208\180\208\184\208\188\208\190 \208\191\208\181\209\128\208\181\208\183\208\176\208\179\209\128\209\131\208\183\208\184\209\130\209\140 \208\184\208\189\209\130\208\181\209\128\209\132\208\181\208\185\209\129"
L["Do not show follower icon on plots"] = "\208\157\208\181 \208\191\208\190\208\186\208\176\208\183\209\139\208\178\208\176\209\130\209\140 \208\183\208\189\208\176\209\135\208\190\208\186 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176 \208\189\208\176 \208\179\209\128\208\176\209\132\208\184\208\186\208\176\209\133"
L["Duration Time"] = "\208\159\209\128\208\190\208\180\208\190\208\187\208\182\208\184\209\130\208\181\208\187\209\140\208\189\208\190\209\129\209\130\209\140"
L["Enhance tooltip"] = "\208\163\208\187\209\131\209\135\209\136\208\184\209\130\209\140 \208\191\208\190\208\180\209\129\208\186\208\176\208\183\208\186\209\131"
L["Environment Preference"] = "\208\158\208\186\209\128\209\131\208\182\208\176\209\142\209\137\208\176\209\143 \209\129\209\128\208\181\208\180\208\176"
L["Epic followers are NOT sent alone on xp only missions"] = "\208\173\208\191\208\184\209\135\208\181\209\129\208\186\208\184\208\181 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\184 \208\189\208\181 \208\190\209\130\208\191\209\128\208\176\208\178\208\187\209\143\209\142\209\130\209\129\209\143 \208\178 \208\190\208\180\208\184\208\189\208\190\209\135\208\186\209\131 \208\189\208\176 XP \208\188\208\184\209\129\209\129\208\184\208\184"
L["Expiration Time"] = "\208\146\209\128\208\181\208\188\209\143 \208\190\208\186\208\190\208\189\209\135\208\176\208\189\208\184\209\143 \209\129\209\128\208\190\208\186\208\176 \208\180\208\181\208\185\209\129\209\130\208\178\208\184\209\143"
L["Follower"] = "\208\161\208\190\209\128\208\176\209\130\208\189\208\184\208\186"
L["Follower equipment set or upgrade"] = "\208\163\208\187\209\131\209\135\209\136\208\181\208\189\208\184\208\181 \209\141\208\186\208\184\208\191\208\184\209\128\208\190\208\178\208\186\208\184 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176"
L["Follower experience"] = "\208\158\208\191\209\139\209\130 \208\161\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176"
L["Follower set minimum upgrade"] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\208\190\208\181 \209\131\208\187\209\131\209\135\209\136\208\181\208\189\208\184\208\181 \209\141\208\186\208\184\208\191\208\184\209\128\208\190\208\178\208\186\208\184 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176"
L["Follower Training"] = "\208\162\209\128\208\181\208\189\208\184\209\128\208\190\208\178\208\186\208\176 \208\161\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176"
L["Followers status "] = "\208\161\209\130\208\176\209\130\209\131\209\129 \208\161\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176"
L["Garrison Appearance"] = "\208\146\208\189\208\181\209\136\208\189\208\184\208\185 \208\178\208\184\208\180 \208\179\208\176\209\128\208\189\208\184\208\183\208\190\208\189\208\176"
L["Garrison Comander Quick Mission Completion"] = "Garrison Comander \208\145\209\139\209\129\209\130\209\128\208\190\208\181 \208\183\208\176\208\178\208\181\209\128\209\136\208\181\208\189\208\184\208\181 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Garrison Commander Mission Control"] = "Garrison Commander \208\166\208\181\208\189\209\130\209\128 \208\163\208\191\209\128\208\176\208\178\208\187\208\181\208\189\208\184\209\143 "
L["Global approx. xp reward"] = "\208\147\208\187\208\190\208\177\208\176\208\187\209\140\208\189\209\139\208\185 \208\190\208\186. \208\157\208\176\208\179\209\128\208\176\208\180\208\176 XP"
L["Global success chance"] = "\208\147\208\187\208\190\208\177\208\176\208\187\209\140\208\189\209\139\208\185 \209\136\208\176\208\189\209\129 \208\189\208\176 \209\131\209\129\208\191\208\181\209\133"
L["Gold incremented!"] = "\208\151\208\190\208\187\208\190\209\130\208\190 \208\191\209\128\208\184\208\177\208\176\208\178\208\184\208\187\208\190\209\129\209\140!"
L["Hide followers"] = "\208\161\208\186\209\128\209\139\209\130\209\140 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\190\208\178"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = "\208\149\209\129\208\187\208\184 \209\141\209\130\208\190\209\130 \209\132\208\187\208\176\208\182\208\190\208\186 \209\131\209\129\209\130\208\176\208\189\208\190\208\178\208\187\208\181\208\189, \208\189\208\176\208\182\208\176\209\130\208\184\208\181 \208\189\208\176 \208\183\208\189\208\176\209\135\208\190\208\186 \208\190\208\177\208\189\208\190\208\178\208\187\208\181\208\189\208\184\209\143 \208\191\209\128\208\184\208\178\208\181\208\180\208\181\209\130 \208\186 \209\131\209\129\208\184\208\187\208\181\208\189\208\184\209\142 \209\141\208\186\208\184\208\191\208\184\209\128\208\190\208\178\208\186\208\184 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176, |cFFFF0000NO QUESTION ASKED|r"
L["IF checked, shows armors on the left and weapons on the right "] = "\208\149\209\129\208\187\208\184 \208\190\209\130\208\188\208\181\209\135\208\181\208\189, \208\191\208\190\208\186\208\176\208\183\209\139\208\178\208\176\208\181\209\130 \208\180\208\190\209\129\208\191\208\181\209\133\208\184 \209\129\208\187\208\181\208\178\208\176 \208\184 \208\190\209\128\209\131\208\182\208\184\208\181 \209\129\208\191\209\128\208\176\208\178\208\176"
L["If you continue, you will lose them"] = "\208\149\209\129\208\187\208\184 \208\178\209\139 \208\191\209\128\208\190\208\180\208\190\208\187\208\182\208\184\209\130\208\181, \208\178\209\139 \208\191\208\190\209\130\208\181\209\128\209\143\208\181\209\130\208\181 \208\184\209\133"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "\208\149\209\129\208\187\208\184 \209\131 \208\178\208\176\209\129 \208\181\209\129\209\130\209\140 \208\161\208\186\208\187\208\176\208\180 \208\163\209\130\208\184\208\187\209\143 \208\178\209\139 \208\178\208\181\209\128\208\190\209\143\209\130\208\189\208\190 \208\189\208\181 \209\133\208\190\209\130\208\184\209\130\208\181 \209\135\209\130\208\190\208\177\209\139 \208\181\208\179\208\190 \208\191\209\128\208\190\208\178\208\181\209\128\208\184\208\187\208\184 "
L["Ignore \"maxed\""] = "\208\152\208\179\208\189\208\190\209\128\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \"maxed\""
L["Ignore epic for xp missions."] = "\208\152\208\179\208\189\208\190\209\128\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \209\141\208\191\208\184\208\186\208\184 \208\180\208\187\209\143 \208\188\208\184\209\129\209\129\208\184\208\185 \208\189\208\176 \208\190\208\191\209\139\209\130. "
L["Ignore for all missions"] = "\208\152\208\179\208\189\208\190\209\128\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \208\178\209\129\208\181 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Ignore for this mission"] = "\208\152\208\179\208\189\208\190\209\128\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \209\141\209\130\209\131 \208\188\208\184\209\129\209\129\208\184\209\142"
L["Ignore rare missions"] = "\208\152\208\179\208\189\208\190\209\128\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \209\128\208\181\208\180\208\186\208\184\208\181 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Increased Rewards"] = "\208\163\208\178\208\181\208\187\208\184\209\135\208\181\208\189\208\184\208\181 \208\178\208\190\208\183\208\189\208\176\208\179\209\128\208\176\208\182\208\180\208\181\208\189\208\184\209\143"
L["Item minimum level"] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\209\139\208\185 \209\131\209\128\208\190\208\178\208\181\208\189\209\140 \208\191\209\128\208\181\208\180\208\188\208\181\209\130\208\190\208\178"
L["Item Tokens"] = "\208\162\208\190\208\186\208\181\208\189"
L["Left Click to see available missions"] = "\208\169\208\181\208\187\208\186\208\189\208\184\209\130\208\181 \208\187\208\181\208\178\208\190\208\185 \208\186\208\189\208\190\208\191\208\186\208\190\208\185 \208\188\209\139\209\136\208\184, \209\135\209\130\208\190\208\177\209\139 \209\131\208\178\208\184\208\180\208\181\209\130\209\140 \208\180\208\190\209\129\209\130\209\131\208\191\208\189\209\139\208\181 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Legendary Items"] = "\208\155\208\181\208\179\208\181\208\189\208\180\208\176\209\128\208\189\209\139\208\185 \208\191\209\128\208\181\208\180\208\188\208\181\209\130"
L["Level 100 epic followers are not used for xp only missions."] = "\208\173\208\191\208\184\209\135\208\181\209\129\208\186\208\184\208\181 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\184 100 \209\131\209\128\208\190\208\178\208\189\209\143 \208\189\208\181 \208\184\209\129\208\191\208\190\208\187\209\140\208\183\209\131\209\142\209\130\209\129\209\143 \209\130\208\190\208\187\209\140\208\186\208\190 \208\180\208\187\209\143 \208\188\208\184\209\129\209\129\208\184\208\185 \208\189\208\176 \208\190\208\191\209\139\209\130."
L["Makes main mission panel movable"] = "\208\148\208\181\208\187\208\176\208\181\209\130 \208\179\208\187\208\176\208\178\208\189\209\131\209\142 \208\191\208\176\208\189\208\181\208\187\209\140 \208\188\208\184\209\129\209\129\208\184\208\184 \208\191\208\190\208\180\208\178\208\184\208\182\208\189\208\190\208\185"
L["Makes shipyard panel movable"] = "\208\148\208\181\208\187\208\176\208\181\209\130 \208\191\208\176\208\189\208\181\208\187\209\140 \209\132\208\187\208\190\209\130\208\176 \208\191\208\190\208\180\208\178\208\184\208\182\208\189\208\190\208\185"
L["Maximize result"] = "\208\156\208\176\208\186\209\129\208\184\208\188\208\184\208\183\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \209\128\208\181\208\183\209\131\208\187\209\140\209\130\208\176\209\130"
L["Maximum mission duration."] = "\208\156\208\176\208\186\209\129\208\184\208\188\208\176\208\187\209\140\208\189\208\176\209\143 \208\191\209\128\208\190\208\180\208\190\208\187\208\182\208\184\209\130\208\181\208\187\209\140\208\189\208\190\209\129\209\130\209\140 \208\188\208\184\209\129\209\129\208\184\208\184."
L["Minimum chance"] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\209\139\208\181 \209\136\208\176\208\189\209\129\209\139"
L["Minimum mission duration."] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\208\176\209\143 \208\191\209\128\208\190\208\180\208\190\208\187\208\182\208\184\209\130\208\181\208\187\209\140\208\189\208\190\209\129\209\130\209\140 \208\188\208\184\209\129\209\129\208\184\208\184."
L["Minimum needed chance"] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\209\139\208\185 \209\136\208\176\208\189\209\129"
L["Minimum requested level for equipment rewards"] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\209\139\208\185 \208\183\208\176\208\191\209\128\208\176\209\136\208\184\208\178\208\176\208\181\208\188\209\139\208\185 \209\131\209\128\208\190\208\178\208\181\208\189\209\140 \208\178\208\190\208\183\208\189\208\176\208\179\209\128\208\176\208\182\208\180\208\181\208\189\208\184\209\143 \208\183\208\176 \208\183\208\176\208\180\208\176\208\189\208\184\208\181"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\208\190 \209\130\209\128\208\181\208\177\209\131\208\181\208\188\208\190\208\181 \208\190\208\177\208\189\208\190\208\178\208\187\208\181\208\189\208\184\208\181 \208\180\208\187\209\143 \209\141\208\186\208\184\208\191\208\184\209\128\208\190\208\178\208\186\208\184 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176 (\209\131\208\187\209\131\209\135\209\136\208\181\208\189\208\184\209\143 \208\178\209\129\208\181\208\179\208\180\208\176 \208\178\208\186\208\187\209\142\209\135\208\181\208\189\209\139)"
L["Minimun chance success under which ignore missions"] = "\208\156\208\184\208\189\208\184\208\188\208\176\208\187\209\140\208\189\209\139\208\181 \209\136\208\176\208\189\209\129\209\139 \208\189\208\176 \209\131\209\129\208\191\208\181\209\133, \208\191\209\128\208\184 \208\186\208\190\209\130\208\190\209\128\208\190\208\188 \208\184\208\179\208\189\208\190\209\128\208\184\209\128\209\131\209\142\209\130\209\129\209\143 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Minumum needed chance"] = "\208\156\208\184\208\189\208\184\208\188\209\131\208\188 \208\189\209\131\208\182\208\181\208\189 \209\136\208\176\208\189\209\129"
L["Mission Control"] = "\208\166\208\181\208\189\209\130\209\128 \208\154\208\190\208\189\209\130\209\128\208\190\208\187\209\143"
L["Mission Duration"] = "\208\159\209\128\208\190\208\180\208\190\208\187\208\182\208\184\209\130\208\181\208\187\209\140\208\189\208\190\209\129\209\130\209\140 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Mission shown"] = "\208\156\208\184\209\129\209\129\208\184\209\143 \208\191\208\190\208\186\208\176\208\183\208\176\208\189\208\176"
L["Mission shown for follower"] = "\208\156\208\184\209\129\209\129\208\184\209\143 \208\191\208\190\208\186\208\176\208\183\208\176\208\189\208\176 \208\180\208\187\209\143 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176"
L["Mission Success"] = "\208\163\209\129\208\191\208\181\209\133 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Mission time reduced!"] = "\208\146\209\128\208\181\208\188\209\143 \208\188\208\184\209\129\209\129\208\184\208\184 \209\129\208\190\208\186\209\128\208\176\209\137\208\181\208\189\208\190!"
L["Mission with lower success chance will be ignored"] = "\208\156\208\184\209\129\209\129\208\184\209\143 \209\129 \208\188\208\181\208\189\209\140\209\136\208\184\208\188 \209\136\208\176\208\189\209\129\208\190\208\188 \208\189\208\176 \209\131\209\129\208\191\208\181\209\133 \208\177\209\131\208\180\208\181\209\130 \208\191\209\128\208\190\208\184\208\179\208\189\208\190\209\128\208\184\209\128\208\190\208\178\208\176\208\189\208\176"
L["Missionlist"] = "\208\161\208\191\208\184\209\129\208\190\208\186 \208\188\208\184\209\129\209\129\208\184\208\185"
L["Must reload interface to apply"] = "\208\157\209\131\208\182\208\189\208\190 \208\191\208\181\209\128\208\181\208\183\208\176\208\179\209\128\209\131\208\183\208\184\209\130\209\140 \208\184\208\189\209\130\208\181\209\128\209\132\208\181\208\185\209\129 \208\180\208\187\209\143 \208\191\209\128\208\184\208\188\208\181\208\189\208\181\208\189\208\184\209\143"
L["No confirmation"] = "\208\157\208\181\209\130 \208\191\208\190\208\180\209\130\208\178\208\181\209\128\208\182\208\180\208\181\208\189\208\184\209\143 "
L["No follower gained xp"] = "\208\157\208\184 \208\190\208\180\208\184\208\189 \208\184\208\183 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\190\208\178 \208\189\208\181 \208\191\208\190\208\187\209\131\209\135\208\184\208\187 \208\190\208\191\209\139\209\130"
L["No mission prefill"] = "\208\157\208\184\208\186\208\176\208\186\208\190\208\185 \208\191\209\128\208\181\208\180\208\178\209\139\208\177\208\190\209\128\208\186\208\184 \208\188\208\184\209\129\209\129\208\184\208\184"
L["Not blacklisted"] = "\208\157\208\181 \208\178 \209\135\208\181\209\128\208\189\209\139\208\185 \209\129\208\191\208\184\209\129\208\190\208\186"
L["Nothing to report"] = "\208\157\208\181\209\135\208\181\208\179\208\190 \208\180\208\190\208\186\208\187\208\176\208\180\209\139\208\178\208\176\209\130\209\140"
L["Number of followers"] = "\208\154\208\190\208\187\208\184\209\135\208\181\209\129\209\130\208\178\208\190 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\190\208\178"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "\208\159\208\190\208\186\208\176\208\183\208\176\208\189\209\139 \209\130\208\190\208\187\209\140\208\186\208\190 \208\191\208\181\209\128\208\178\209\139\208\181 %1$d \208\188\208\184\209\129\209\129\208\184\208\184 \209\129 \208\178\208\181\209\128\208\190\209\143\209\130\208\189\208\190\209\129\209\130\209\140\209\142 \209\131\209\129\208\191\208\181\209\133\208\176 %2$d%%"
L["Only meaningful upgrades are shown"] = "\208\159\208\190\208\186\208\176\208\183\208\176\208\189\209\139 \209\130\208\190\208\187\209\140\208\186\208\190 \208\183\208\189\208\176\209\135\208\184\208\188\209\139\208\181 \208\190\208\177\208\189\208\190\208\178\208\187\208\181\208\189\208\184\209\143"
L["Original concept and interface by %s"] = "\208\158\209\128\208\184\208\179\208\184\208\189\208\176\208\187\209\140\208\189\208\176\209\143 \208\186\208\190\208\189\209\134\208\181\208\191\209\134\208\184\209\143 \208\184 \208\184\208\189\209\130\208\181\209\128\209\132\208\181\208\185\209\129 \208\189\208\176 %s"
L["Original method"] = "\208\158\209\128\208\184\208\179\208\184\208\189\208\176\208\187\209\140\208\189\209\139\208\185 \208\188\208\181\209\130\208\190\208\180"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "\208\158\209\128\208\184\208\179\208\184\208\189\208\176\208\187\209\140\208\189\208\176\209\143 \209\129\208\190\209\128\209\130\208\184\209\128\208\190\208\178\208\186\208\176 \208\178\208\190\209\129\209\129\209\130\208\176\208\189\208\176\208\178\208\187\208\184\208\178\208\176\208\181\209\130 \208\184\209\129\209\133\208\190\208\180\208\189\209\139\208\185 \208\188\208\181\209\130\208\190\208\180 \209\129\208\190\209\128\209\130\208\184\209\128\208\190\208\178\208\186\208\184, \208\189\208\181\208\183\208\176\208\178\208\184\209\129\208\184\208\188\208\190 \208\190\209\130 \209\130\208\190\208\179\208\190, \209\135\209\130\208\190 \208\177\209\139\208\187\208\190 (\208\181\209\129\208\187\208\184 \209\131 \208\178\208\176\209\129 \208\181\209\129\209\130\209\140 \208\180\209\128\209\131\208\179\208\176\209\143 \208\186\208\190\208\188\208\176\208\189\208\180\208\176 \209\129\208\190\209\128\209\130\208\184\209\128\208\190\208\178\208\186\208\184 \208\176\208\180\208\180\208\190\208\189\208\176, \208\190\208\189\208\176 \208\180\208\190\208\187\208\182\208\189\208\176 \209\129\208\189\208\190\208\178\208\176 \208\177\209\139\209\130\209\140 \208\178\208\178\208\181\208\180\208\181\208\189\208\176)"
L["Other"] = "\208\148\209\128\209\131\208\179\208\184\208\181"
L["Other rewards"] = "\208\148\209\128\209\131\208\179\208\184\208\181 \208\189\208\176\208\179\209\128\208\176\208\180\209\139"
L["Other settings"] = "\208\148\209\128\209\131\208\179\208\184\208\181 \208\189\208\176\209\129\209\130\209\128\208\190\208\185\208\186\208\184"
L["Other useful followers"] = "\208\148\209\128\209\131\208\179\208\184\208\181 \208\191\208\190\208\187\208\181\208\183\208\189\209\139\208\181 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\184"
L["Processing mission %d of %d"] = "\208\158\208\177\209\128\208\176\208\177\208\190\209\130\208\186\208\176 \208\188\208\184\209\129\209\129\208\184\208\184 %d \208\184\208\183 %d"
L["Profession"] = "\208\159\209\128\208\190\209\132\208\181\209\129\209\129\208\184\209\143"
L["Racial Preference"] = "\208\160\208\176\209\129\208\190\208\178\208\190\208\181 \208\191\209\128\208\181\208\180\208\191\208\190\209\135\209\130\208\181\208\189\208\184\208\181"
L["Rare missions will not be considered"] = "\208\160\208\181\208\180\208\186\208\184\208\181 \208\188\208\184\209\129\209\129\208\184\208\184 \208\189\208\181 \208\177\209\131\208\180\209\131\209\130 \209\128\208\176\209\129\209\129\208\188\208\176\209\130\209\128\208\184\208\178\208\176\209\130\209\140\209\129\209\143"
L["Reagents"] = "\208\160\208\181\208\176\208\179\208\181\208\189\209\130\209\139"
L["Reputation Items"] = "\208\159\209\128\208\181\208\180\208\188\208\181\209\130\209\139 \208\180\208\187\209\143 \208\160\208\181\208\191\209\131\209\130\208\176\209\134\208\184\208\184"
L["Reward type"] = "\208\162\208\184\208\191 \208\178\208\190\208\183\208\189\208\176\208\179\209\128\208\176\208\182\208\180\208\181\208\189\208\184\209\143"
L["Right-Click to blacklist"] = "\208\169\208\181\208\187\208\186\208\189\208\184\209\130\208\181 \208\191\209\128\208\176\208\178\208\190\208\185 \208\186\208\189\208\190\208\191\208\186\208\190\208\185 \208\188\209\139\209\136\208\184 \208\180\208\187\209\143 \208\180\208\190\208\177\208\176\208\178\208\187\208\181\208\189\208\184\209\143 \208\178 \209\135\208\181\209\128\208\189\209\139\208\185 \209\129\208\191\208\184\209\129\208\190\208\186"
L["Right-Click to remove from blacklist"] = "\208\169\208\181\208\187\208\186\208\189\208\184\209\130\208\181 \208\191\209\128\208\176\208\178\208\190\208\185 \208\186\208\189\208\190\208\191\208\186\208\190\208\185 \208\188\209\139\209\136\208\184, \209\135\209\130\208\190\208\177\209\139 \209\131\208\180\208\176\208\187\208\184\209\130\209\140 \208\184\208\183 \209\135\208\181\209\128\208\189\208\190\208\179\208\190 \209\129\208\191\208\184\209\129\208\186\208\176"
L["Rush orders"] = "\208\161\209\128\208\190\209\135\208\189\209\139\208\185 \208\183\208\176\208\186\208\176\208\183"
L["Shipyard Appearance"] = "\208\146\208\189\208\181\209\136\208\189\208\184\208\185 \208\178\208\184\208\180 \208\164\208\187\208\190\209\130\208\176"
L["Show Garrison Commander menu"] = "\208\159\208\190\208\186\208\176\208\183\208\176\209\130\209\140 \208\188\208\181\208\189\209\142 Garrison Commander"
L["Show itemlevel"] = "\208\159\208\190\208\186\208\176\208\183\208\176\209\130\209\140 itemlevel"
L["Show upgrades"] = "\208\159\208\190\208\186\208\176\208\183\208\176\209\130\209\140 \209\131\208\187\209\131\209\135\209\136\208\181\208\189\208\184\209\143"
L["Show xp"] = "\208\159\208\190\208\186\208\176\208\183\208\176\209\130\209\140 \208\190\208\191\209\139\209\130"
L["Slayer"] = "\208\163\208\177\208\184\208\185\209\134\208\176"
L["Some follower"] = "\208\157\208\181\208\186\208\190\209\130\208\190\209\128\209\139\208\181 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\184"
L["Sort missions by:"] = "\208\161\208\190\209\128\209\130\208\184\209\128\208\190\208\178\208\186\208\176 \208\188\208\184\209\129\209\129\208\184\208\185 \208\191\208\190:"
L["Submit all your mission at once. No question asked."] = "\208\158\209\130\208\191\209\128\208\176\208\178\208\184\209\130\209\140 \208\178\209\129\208\181\209\133 \208\189\208\176 \208\188\208\184\209\129\209\129\208\184\208\184. \208\145\208\181\208\183 \208\178\208\190\208\191\209\128\208\190\209\129\208\190\208\178."
L["Success Chance"] = "\208\168\208\176\208\189\209\129 \209\131\209\129\208\191\208\181\209\133\208\176"
L["Swap upgrades positions"] = true
L["Switch between Garrison Commander and Master Plan interface for missions"] = "\208\159\208\181\209\128\208\181\208\186\208\187\209\142\209\135\208\181\208\189\208\184\208\181 \208\188\208\181\208\182\208\180\209\131 Garrison Commander \208\184 Master Plan \208\180\208\187\209\143 \208\188\208\184\209\129\209\129\208\184\208\185"
L["Threat Counter"] = "\208\161\209\135\208\181\209\130\209\135\208\184\208\186 \209\131\208\179\209\128\208\190\208\183"
L["To go: %d"] = "\208\152\208\180\209\130\208\184: %d"
L["Toggles Garrison Commander Menu Header on/off"] = "\208\146\208\186\208\187\209\142\209\135\208\181\208\189\208\184\208\181/\208\178\209\139\208\186\208\187\209\142\209\135\208\181\208\189\208\184\208\181 \208\183\208\176\208\179\208\190\208\187\208\190\208\178\208\186\208\176 \208\188\208\181\208\189\209\142 Garrison Commander"
L["Toys and Mounts"] = "\208\152\208\179\209\128\209\131\209\136\208\186\208\184 \208\184 \208\161\209\128\208\181\208\180\209\129\209\130\208\178\208\176 \208\159\208\181\209\128\208\181\208\180\208\178\208\184\208\182\208\181\208\189\208\184\209\143"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "\208\161\208\189\208\184\208\188\208\184\209\130\208\181 \209\132\208\187\208\176\208\182\208\190\208\186, \209\135\209\130\208\190\208\177\209\139 \209\131\209\129\209\130\208\176\208\189\208\190\208\178\208\184\209\130\209\140 \208\190\208\191\209\128\208\181\208\180\208\181\208\187\208\181\208\189\208\189\209\139\208\185 \209\136\208\176\208\189\209\129 \208\189\208\176 \209\131\209\129\208\191\208\181\209\133 \208\180\208\187\209\143 \208\186\208\176\208\182\208\180\208\190\208\179\208\190 \209\130\208\184\208\191\208\176 \208\178\208\190\208\183\208\189\208\176\208\179\209\128\208\176\208\182\208\180\208\181\208\189\208\184\209\143"
L["Unlock Panel"] = "\208\160\208\176\208\183\208\177\208\187\208\190\208\186\208\184\209\128\208\190\208\178\208\176\209\130\209\140 \208\191\208\176\208\189\208\181\208\187\209\140"
L["Upgrade %1$s to  %2$d itemlevel"] = "\208\163\208\187\209\131\209\135\209\136\208\184\209\130\209\140 %1$s \208\186  %2$d itemlevel"
L["Upgrading to |cff00ff00%d|r"] = "\208\163\208\187\209\131\209\135\209\136\208\184\209\130\209\140 \208\186 |cff00ff00%d|r"
L["Use big screen"] = "\208\152\209\129\208\191\208\190\208\187\209\140\208\183\209\131\208\185\209\130\208\181 \208\177\208\190\208\187\209\140\209\136\208\190\208\185 \209\141\208\186\209\128\208\176\208\189"
L["Use GC Interface"] = "\208\152\209\129\208\191\208\190\208\187\209\140\208\183\208\190\208\178\208\176\209\130\209\140 \208\184\208\189\209\130\208\181\209\128\209\132\208\181\208\185\209\129 GC"
L["Uses armor token"] = "\208\152\209\129\208\191\208\190\208\187\209\140\208\183\209\131\208\185\209\130\208\181 \208\180\208\187\209\143 \209\131\208\187\209\131\209\135\209\136\208\181\208\189\208\184\209\143 \208\177\209\128\208\190\208\189\208\184 "
L["Uses weapon token"] = "\208\152\209\129\208\191\208\190\208\187\209\140\208\183\209\131\208\185\209\130\208\181 \208\180\208\187\209\143 \209\131\208\187\209\131\209\135\209\136\208\181\208\189\208\184\209\143 \208\190\209\128\209\131\208\182\208\184\209\143"
L["When checked, show on each follower button missing xp to next level"] = "\208\154\208\190\208\179\208\180\208\176 \209\131\209\129\209\130\208\176\208\189\208\190\208\178\208\187\208\181\208\189 \209\132\208\187\208\176\208\182\208\190\208\186, \208\191\208\190\208\186\208\176\208\183\208\176\209\130\209\140 \208\189\208\176 \208\186\208\176\208\182\208\180\208\190\208\185 \208\184\208\186\208\190\208\189\208\186\208\184 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176 \209\129\208\186\208\190\208\187\209\140\208\186\208\190 \208\190\208\191\209\139\209\130\208\176 \208\189\209\131\208\182\208\189\208\190 \208\189\208\176 \209\129\208\187\208\181\208\180\209\131\209\142\209\137\208\184\208\185 \209\131\209\128\208\190\208\178\208\181\208\189\209\140."
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "\208\154\208\190\208\179\208\180\208\176 \209\131\209\129\209\130\208\176\208\189\208\190\208\178\208\187\208\181\208\189 \209\132\208\187\208\176\208\182\208\190\208\186, \208\191\208\190\208\186\208\176\208\183\208\176\209\130\209\140 \208\189\208\176 \208\186\208\176\208\182\208\180\208\190\208\185 \208\184\208\186\208\190\208\189\208\186\208\184 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\176 \209\129\208\186\208\190\208\187\209\140\208\186\208\190 \208\191\209\128\208\181\208\180\208\188\208\181\209\130\208\190\208\178 \208\190\209\128\209\131\208\182\208\184\208\184 \208\184 \208\177\209\128\208\190\208\189\208\184 \208\181\208\188\209\131 \208\181\209\137\208\181 \208\189\209\131\208\182\208\189\208\190"
L["Xp incremented!"] = "\208\158\208\191\209\139\209\130 \209\131\208\178\208\181\208\187\208\184\209\135\208\184\208\178\208\176\208\181\209\130\209\129\209\143!"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "\208\146\209\139 \208\183\209\128\209\143 \209\130\209\128\208\176\209\130\208\184\209\130\208\181 |cffff0000%d|cffffd200 \208\191\209\128\208\181\208\180\208\188\208\181\209\130\209\139(s)!!!"
L["You can also send mission one by one clicking on each button."] = "\208\146\209\139 \209\130\208\176\208\186\208\182\208\181 \208\188\208\190\208\182\208\181\209\130\208\181 \208\190\209\130\208\191\209\128\208\176\208\178\208\184\209\130\209\140 \208\188\208\184\209\129\209\129\208\184\209\142 \208\191\208\190 \208\190\208\180\208\189\208\190\208\188\209\131 \208\189\208\176\208\182\208\176\209\130\208\184\209\142 \208\189\208\176 \208\186\208\176\208\182\208\180\209\131\209\142 \208\186\208\189\208\190\208\191\208\186\209\131."
L["You can open the menu clicking on the icon in top right corner"] = "\208\146\209\139 \208\188\208\190\208\182\208\181\209\130\208\181 \208\190\209\130\208\186\209\128\209\139\209\130\209\140 \208\188\208\181\208\189\209\142, \208\189\208\176\208\182\208\176\208\178 \208\189\208\176 \208\183\208\189\208\176\209\135\208\190\208\186 \208\178 \208\178\208\181\209\128\209\133\208\189\208\181\208\188 \208\191\209\128\208\176\208\178\208\190\208\188 \209\131\208\179\208\187\209\131"
L["You have ignored followers"] = "\208\146\209\139 \208\191\209\128\208\190\208\184\208\179\208\189\208\190\209\128\208\184\209\128\208\190\208\178\208\176\208\187\208\184 \209\129\208\190\209\128\208\176\209\130\208\189\208\184\208\186\208\190\208\178"
L["You never performed this mission"] = "\208\146\209\139 \208\189\208\184\208\186\208\190\208\179\208\180\208\176 \208\189\208\181 \208\178\209\139\208\191\208\190\208\187\208\189\209\143\208\187\208\184 \209\141\209\130\209\131 \208\188\208\184\209\129\209\129\208\184\209\142"
L["You performed this mission %d times with a win ratio of"] = "\208\146\209\139 \208\178\209\139\208\191\208\190\208\187\208\189\208\184\208\187\208\184 \209\141\209\130\209\131 \208\188\208\184\209\129\209\129\208\184\209\142 %d \209\128\208\176\208\183 \209\129 \208\186\208\190\209\141\209\132\209\132\208\184\209\134\208\184\208\181\208\189\209\130\208\190\208\188 \208\178\209\139\208\184\208\179\209\128\209\139\209\136\208\176"

	end
	L=l:NewLocale(me,"zhCN")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4\233\154\143\228\187\142\239\188\154\233\154\143\228\187\142\229\144\171\230\156\137 %s"
L["(Ignores low bias ones)"] = "\239\188\136\229\191\189\231\149\165\228\189\142\229\140\185\233\133\141\231\154\132\239\188\137"
L["Add %1$d levels to %2$s"] = "\229\162\158\229\138\160 %1$d \231\173\137\231\186\167\229\136\176 %2$s"
L["Adds a list of other useful followers to tooltip"] = "\233\188\160\230\160\135\230\143\144\231\164\186\228\184\173\230\183\187\229\138\160\229\133\182\228\187\150\230\156\137\231\148\168\231\154\132\233\154\143\228\187\142\229\136\151\232\161\168"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "\229\143\150\230\182\136\233\128\137\228\184\173\228\187\165\233\154\144\232\151\143\230\175\143\228\184\170\232\191\189\233\154\143\232\128\133\231\154\132\228\187\187\229\138\161\229\136\151\232\161\168\239\188\140\228\187\133\229\176\143\231\170\151\229\143\163\230\168\161\229\188\143\230\156\137\230\149\136"
L["Allowed Rewards"] = "\229\143\175\231\148\168\230\148\182\231\155\138"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "\229\133\129\232\174\184\232\181\132\230\186\144\228\187\187\229\138\161\228\189\191\231\148\168\232\190\131\228\189\142\231\154\132\230\136\144\229\138\159\231\142\135\227\128\130\228\189\191\231\148\168 /gac \230\137\147\229\188\128\231\149\140\233\157\162\232\176\131\230\149\180\229\135\160\231\142\135\239\188\140\233\187\152\232\174\16480%"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "\230\156\128\229\164\167\229\140\150\231\187\147\230\158\156\233\128\137\233\161\185\229\144\175\231\148\168\230\151\182\231\148\159\230\149\136\239\188\140\233\187\152\232\174\16480%"
L["Applies the best armor set"] = "\228\189\191\231\148\168\230\156\128\228\189\179\230\138\164\231\148\178\231\187\132\229\144\136"
L["Applies the best armor upgrade"] = "\228\189\191\231\148\168\230\156\128\228\189\179\230\138\164\231\148\178\229\141\135\231\186\167"
L["Applies the best weapon set"] = "\228\189\191\231\148\168\230\156\128\228\189\179\230\173\166\229\153\168\231\187\132\229\144\136"
L["Applies the best weapon upgrade"] = "\228\189\191\231\148\168\230\156\128\228\189\179\230\173\166\229\153\168\229\141\135\231\186\167"
L["Archaelogy"] = "\232\128\131\229\143\164\229\173\166"
L["Big screen"] = "\229\164\167\231\170\151\229\143\163"
L["Blacklisted"] = "\229\183\178\229\138\160\229\133\165\233\187\145\229\144\141\229\141\149"
L["Blacklisted missions are ignored in Mission Control"] = "\229\156\168\228\187\187\229\138\161\233\157\162\230\157\191\229\183\178\229\136\151\229\133\165\233\187\145\229\144\141\229\141\149\231\154\132\228\187\187\229\138\161\229\176\134\232\162\171\229\191\189\231\149\165"
L["Building Final report"] = "\230\158\132\229\187\186\230\156\128\231\187\136\230\138\165\229\145\138"
L["Capped %1$s. Spend at least %2$d of them"] = "\230\156\128\229\164\154 %1$s\239\188\140\228\189\191\231\148\168\232\135\179\229\176\145 %2$d"
L["Complete all missions without confirmation"] = "\230\151\160\233\156\128\231\161\174\232\174\164\229\174\140\230\136\144\230\137\128\230\156\137\228\187\187\229\138\161"
L["Consider again"] = "\231\161\174\232\174\164"
L["Disable if you dont want the full Garrison Commander Header."] = "\231\166\129\231\148\168\229\174\140\230\149\180\231\154\132 Garrison Commander \230\160\135\233\162\152"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "\229\143\150\230\182\136\228\187\187\229\138\161\233\161\181\232\135\170\229\138\168\229\136\134\233\133\141\227\128\130\228\189\160\228\185\159\229\143\175\228\187\165\230\140\137\228\189\143Ctrl\233\148\174\231\130\185\229\135\187\229\143\150\230\182\136\229\141\149\228\184\170\228\187\187\229\138\161\227\128\130"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "\229\143\150\230\182\136\229\176\134\233\135\141\230\150\176\232\189\189\229\133\1651.1.8\231\137\136\230\156\172\231\149\140\233\157\162\239\188\140\229\143\150\230\182\136\230\136\150\231\161\174\232\174\164\227\128\130\233\156\128\232\166\129\233\135\141\232\189\189\231\149\140\233\157\162\227\128\130"
L["Do not show follower icon on plots"] = "\228\184\141\232\166\129\229\156\168\232\174\161\229\136\146\230\157\161\228\184\138\230\152\190\231\164\186\232\191\189\233\154\143\232\128\133\229\155\190\230\160\135"
L["Duration Time"] = "\229\145\168\230\156\159\230\151\182\233\151\180"
L["Enhance tooltip"] = "\229\188\186\229\140\150\233\188\160\230\160\135\230\143\144\231\164\186"
L["Environment Preference"] = "\231\142\175\229\162\131\232\174\190\231\189\174"
L["Epic followers are NOT sent alone on xp only missions"] = "\231\180\171\232\137\178\232\191\189\233\154\143\232\128\133\228\184\141\228\188\154\229\141\149\231\139\172\229\136\134\233\133\141\229\136\176\229\143\170\230\156\137\231\187\143\233\170\140\231\154\132\228\187\187\229\138\161\228\184\138"
L["Expiration Time"] = "\232\191\135\230\156\159\230\151\182\233\151\180"
L["Follower"] = "\233\154\143\228\187\142"
L["Follower equipment set or upgrade"] = "\233\154\143\228\187\142\232\163\133\229\164\135\232\174\190\231\189\174\230\136\150\229\141\135\231\186\167"
L["Follower experience"] = "\233\154\143\228\187\142\231\187\143\233\170\140"
L["Follower set minimum upgrade"] = "\233\154\143\228\187\142\232\174\190\231\189\174\230\156\128\229\176\143\229\141\135\231\186\167"
L["Follower Training"] = "\233\154\143\228\187\142\232\174\173\231\187\131"
L["Followers status "] = "\232\191\189\233\154\143\232\128\133\231\138\182\230\128\129"
L["Garrison Appearance"] = "\229\133\181\232\144\165\231\149\140\233\157\162"
L["Garrison Comander Quick Mission Completion"] = "GC \229\191\171\233\128\159\228\187\187\229\138\161\229\174\140\230\136\144"
L["Garrison Commander Mission Control"] = "GC \228\187\187\229\138\161\231\174\161\231\144\134"
L["Global approx. xp reward"] = "\229\133\168\229\177\128\229\164\167\231\186\166\231\187\143\233\170\140\229\165\150\229\138\177"
L["Global success chance"] = "\229\133\168\229\177\128\230\136\144\229\138\159\231\142\135"
L["Gold incremented!"] = "\233\135\145\229\184\129\229\162\158\229\138\160\239\188\129"
L["Hide followers"] = "\233\154\144\232\151\143\232\191\189\233\154\143\232\128\133"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[\229\166\130\230\158\156\233\128\137\228\184\173\239\188\140\231\130\185\229\135\187\229\141\135\231\186\167\229\155\190\230\160\135\229\136\153\228\189\191\231\148\168\231\137\169\229\147\129\229\141\135\231\186\167\232\191\189\233\154\143\232\128\133
|cFFFF0000\230\151\160\233\156\128\231\161\174\232\174\164|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "\233\128\137\228\184\173\230\151\182\239\188\140\229\183\166\228\190\167\230\152\190\231\164\186\230\138\164\231\148\178\239\188\140\229\143\179\228\190\167\230\152\190\231\164\186\230\173\166\229\153\168"
L["If you continue, you will lose them"] = "\229\166\130\230\158\156\233\128\137\230\139\169\231\187\167\231\187\173\239\188\140\228\189\160\229\143\175\232\131\189\228\188\154\229\164\177\229\142\187\228\187\150\228\187\172"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "\229\166\130\230\158\156\228\189\160\230\156\137\230\137\147\230\141\158\229\153\168\239\188\140\228\189\160\229\143\175\232\131\189\228\184\141\230\132\191\230\132\143\233\128\137\228\184\173\232\191\153\228\184\170"
L["Ignore \"maxed\""] = "\229\191\189\231\149\165\226\128\156\230\187\161\231\186\167\231\154\132\226\128\157"
L["Ignore epic for xp missions."] = "\231\187\143\233\170\140\228\187\187\229\138\161\229\191\189\231\149\165\229\143\178\232\175\151\233\154\143\228\187\142"
L["Ignore for all missions"] = "\229\191\189\231\149\165\230\137\128\230\156\137\228\187\187\229\138\161"
L["Ignore for this mission"] = "\229\191\189\231\149\165\232\191\153\228\184\170\228\187\187\229\138\161"
L["Ignore rare missions"] = "\229\191\189\231\149\165\231\168\128\230\156\137\228\187\187\229\138\161"
L["Increased Rewards"] = "\229\183\178\229\162\158\229\138\160\230\148\182\231\155\138"
L["Item minimum level"] = "\231\137\169\229\147\129\230\156\128\228\189\142\231\173\137\231\186\167"
L["Item Tokens"] = "\231\137\169\229\147\129\228\187\163\229\184\129"
L["Left Click to see available missions"] = "\231\130\185\229\135\187\230\152\190\231\164\186\229\143\175\231\148\168\228\187\187\229\138\161"
L["Legendary Items"] = "\228\188\160\229\165\135\231\137\169\229\147\129"
L["Level 100 epic followers are not used for xp only missions."] = "100\231\186\167\231\154\132\231\180\171\232\137\178\232\191\189\233\154\143\232\128\133\228\184\141\228\188\154\231\148\168\228\186\142\229\143\170\230\156\137\231\187\143\233\170\140\231\154\132\228\187\187\229\138\161"
L["Makes main mission panel movable"] = "\228\189\191\228\187\187\229\138\161\228\184\187\231\170\151\228\189\147\229\143\175\228\187\165\231\167\187\229\138\168"
L["Makes shipyard panel movable"] = "\228\189\191\232\136\176\232\136\185\233\157\162\230\157\191\229\143\175\228\187\165\231\167\187\229\138\168"
L["Maximize result"] = "\230\156\128\229\164\167\229\140\150\230\148\182\231\155\138"
L["Maximum mission duration."] = "\230\156\128\229\164\167\228\187\187\229\138\161\229\145\168\230\156\159"
L["Minimum chance"] = "\230\156\128\229\176\143\229\135\160\231\142\135"
L["Minimum mission duration."] = "\230\156\128\229\176\143\228\187\187\229\138\161\229\145\168\230\156\159"
L["Minimum needed chance"] = "\230\156\128\229\176\143\229\191\133\233\161\187\229\135\160\231\142\135"
L["Minimum requested level for equipment rewards"] = "\232\174\190\229\164\135\229\165\150\229\138\177\230\137\128\233\156\128\230\156\128\229\176\143\231\173\137\231\186\167"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "\233\154\143\228\187\142\231\187\132\229\144\136\239\188\136\229\183\178\232\128\131\232\153\145\231\187\132\229\144\136\229\188\186\229\140\150\239\188\137\230\137\128\233\156\128\230\156\128\229\176\143\229\141\135\231\186\167"
L["Minimun chance success under which ignore missions"] = "\229\191\189\231\149\165\228\187\187\229\138\161\231\154\132\230\156\128\228\189\142\230\136\144\229\138\159\231\142\135"
L["Minumum needed chance"] = "\230\156\128\229\176\143\230\137\128\233\156\128\229\135\160\231\142\135"
L["Mission Control"] = "\228\187\187\229\138\161\233\157\162\230\157\191"
L["Mission Duration"] = "\228\187\187\229\138\161\229\145\168\230\156\159"
L["Mission shown"] = "\228\187\187\229\138\161\229\177\149\231\164\186"
L["Mission shown for follower"] = "\228\187\187\229\138\161\230\152\190\231\164\186\232\191\189\233\154\143\232\128\133"
L["Mission Success"] = "\228\187\187\229\138\161\230\136\144\229\138\159"
L["Mission time reduced!"] = "\228\187\187\229\138\161\230\151\182\233\151\180\229\135\143\229\176\145\239\188\129"
L["Mission with lower success chance will be ignored"] = "\228\189\142\230\136\144\229\138\159\231\142\135\228\187\187\229\138\161\229\176\134\232\162\171\229\191\189\231\149\165"
L["Missionlist"] = "\228\187\187\229\138\161\229\136\151\232\161\168"
L["Must reload interface to apply"] = "\233\156\128\232\166\129\233\135\141\232\189\189\231\149\140\233\157\162\228\187\165\231\148\159\230\149\136"
L["No confirmation"] = "\230\178\161\230\156\137\231\161\174\232\174\164"
L["No follower gained xp"] = "\230\178\161\230\156\137\233\154\143\228\187\142\232\142\183\229\190\151\231\187\143\233\170\140"
L["No mission prefill"] = "\230\178\161\230\156\137\233\162\132\229\136\134\233\133\141\228\187\187\229\138\161"
L["Not blacklisted"] = "\230\178\161\230\156\137\232\162\171\229\136\151\229\133\165\233\187\145\229\144\141\229\141\149"
L["Nothing to report"] = "\230\178\161\230\156\137\229\143\175\231\148\168\230\138\165\229\145\138"
L["Number of followers"] = "\232\191\189\233\154\143\232\128\133\230\149\176\233\135\143"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "\229\143\170\230\156\137\230\136\144\229\138\159\231\142\135\233\171\152\228\186\142 %2$d%% \231\154\132\229\137\141 %1$d \228\184\170\228\187\187\229\138\161\228\188\154\230\152\190\231\164\186"
L["Only meaningful upgrades are shown"] = "\229\143\170\230\156\137\230\152\142\230\152\190\231\154\132\229\141\135\231\186\167\228\188\154\230\152\190\231\164\186"
L["Original concept and interface by %s"] = "\229\142\159\230\166\130\229\191\181\229\146\140\231\149\140\233\157\162\228\187\142 %s"
L["Original method"] = "\229\142\159\230\150\185\230\179\149"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "\229\188\186\229\136\182\230\129\162\229\164\141\229\142\159\230\142\146\229\186\143\239\188\136\229\166\130\230\158\156\228\189\160\230\156\137\229\143\166\228\184\128\228\184\170\230\143\146\228\187\182\230\142\146\229\186\143\228\187\187\229\138\161\239\188\140\229\174\131\229\186\148\232\175\165\228\188\154\229\134\141\230\172\161\229\144\175\229\138\168\239\188\137"
L["Other"] = "\229\133\182\228\187\150"
L["Other rewards"] = "\229\133\182\228\187\150\230\148\182\231\155\138"
L["Other settings"] = "\229\133\182\228\187\150\232\174\190\231\189\174"
L["Other useful followers"] = "\229\133\182\228\187\150\230\156\137\231\148\168\231\154\132\232\191\189\233\154\143\232\128\133"
L["Processing mission %d of %d"] = "\230\137\167\232\161\140\228\187\187\229\138\161 %d / %d"
L["Profession"] = "\228\184\147\228\184\154\229\140\185\233\133\141"
L["Racial Preference"] = "\231\167\141\230\151\143\229\140\185\233\133\141"
L["Rare missions will not be considered"] = "\231\168\128\230\156\137\228\187\187\229\138\161\229\176\134\228\184\141\232\162\171\232\128\131\232\153\145"
L["Reagents"] = "\232\175\149\229\137\130"
L["Reputation Items"] = "\229\163\176\230\156\155\231\137\169\229\147\129"
L["Reward type"] = "\230\148\182\231\155\138\231\177\187\229\158\139"
L["Right-Click to blacklist"] = "\229\143\179\229\135\187\229\138\160\229\133\165\233\187\145\229\144\141\229\141\149"
L["Right-Click to remove from blacklist"] = "\229\143\179\229\135\187\228\187\142\233\187\145\229\144\141\229\141\149\231\167\187\233\153\164"
L["Rush orders"] = "\229\136\183\232\174\162\229\141\149"
L["Shipyard Appearance"] = "\233\128\160\232\136\185\229\142\130\229\164\150\232\167\130"
L["Show Garrison Commander menu"] = "\230\152\190\231\164\186 GC \232\143\156\229\141\149"
L["Show itemlevel"] = "\230\152\190\231\164\186\231\137\169\229\147\129\231\173\137\231\186\167"
L["Show upgrades"] = "\230\152\190\231\164\186\229\141\135\231\186\167"
L["Show xp"] = "\230\152\190\231\164\186\231\187\143\233\170\140"
L["Slayer"] = "\231\148\159\231\137\169\229\140\185\233\133\141"
L["Some follower"] = "\228\184\128\228\186\155\233\154\143\228\187\142"
L["Sort missions by:"] = "\230\142\146\229\186\143\228\190\157\230\141\174\239\188\154"
L["Submit all your mission at once. No question asked."] = "\230\143\144\228\186\164\230\137\128\230\156\137\228\187\187\229\138\161\227\128\130\230\151\160\233\156\128\231\161\174\232\174\164\227\128\130"
L["Success Chance"] = "\230\136\144\229\138\159\231\142\135"
L["Swap upgrades positions"] = "\228\186\164\230\141\162\229\141\135\231\186\167\228\189\141\231\189\174"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "\228\184\186\228\187\187\229\138\161\229\136\135\230\141\162 Garrison Commander \229\146\140 Master Plan \231\149\140\233\157\162"
L["Threat Counter"] = "\230\138\128\232\131\189\229\140\185\233\133\141"
L["To go: %d"] = "\232\189\172\229\136\176\239\188\154%d"
L["Toggles Garrison Commander Menu Header on/off"] = "\229\136\135\230\141\162 GC \232\143\156\229\141\149\230\160\135\233\162\152\229\188\128\229\133\179"
L["Toys and Mounts"] = "\231\142\169\229\133\183\229\146\140\229\157\144\233\170\145"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "\229\143\150\230\182\136\232\191\153\228\184\170\233\128\137\233\161\185\239\188\140\228\189\160\229\143\175\228\187\165\232\135\170\232\161\140\232\174\190\231\189\174\229\144\132\233\161\185\230\148\182\231\155\138\231\154\132\230\136\144\229\138\159\231\142\135"
L["Unlock Panel"] = "\232\167\163\233\148\129\233\157\162\230\157\191"
L["Upgrade %1$s to  %2$d itemlevel"] = "\229\141\135\231\186\167 %1$s \229\136\176 %2$d \231\137\169\229\147\129\231\173\137\231\186\167"
L["Upgrading to |cff00ff00%d|r"] = "\230\173\163\229\156\168\229\141\135\231\186\167\232\135\179 |cff00ff00%d|r"
L["Use big screen"] = "\228\189\191\231\148\168\229\164\167\229\177\143"
L["Use GC Interface"] = "\228\189\191\231\148\168GC\231\149\140\233\157\162"
L["Uses armor token"] = "\228\189\191\231\148\168\230\138\164\231\148\178\228\187\163\229\184\129"
L["Uses weapon token"] = "\228\189\191\231\148\168\230\173\166\229\153\168\228\187\163\229\184\129"
L["When checked, show on each follower button missing xp to next level"] = "\233\128\137\228\184\173\229\144\142\239\188\140\229\156\168\230\175\143\228\184\170\232\191\189\233\154\143\232\128\133\230\140\137\233\146\174\228\184\138\230\152\190\231\164\186\229\141\135\232\135\179\228\184\139\228\184\128\231\186\167\230\137\128\233\156\128\231\187\143\233\170\140"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "\233\128\137\228\184\173\229\144\142\239\188\140\229\156\168\230\175\143\228\184\170\230\187\161\231\186\167\232\191\189\233\154\143\232\128\133\230\140\137\233\146\174\228\184\138\230\152\190\231\164\186\230\173\166\229\153\168\229\146\140\230\138\164\231\148\178\231\173\137\231\186\167"
L["Xp incremented!"] = "\231\187\143\233\170\140\229\162\158\229\138\160\239\188\129"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "\228\189\160\230\181\170\232\180\185\228\186\134 |cffff0000%d|cffffd200 \231\130\185\239\188\129"
L["You can also send mission one by one clicking on each button."] = "\228\189\160\228\185\159\229\143\175\228\187\165\231\130\185\229\135\187\230\140\137\233\146\174\233\128\144\228\184\170\229\136\134\233\133\141\228\187\187\229\138\161\227\128\130"
L["You can open the menu clicking on the icon in top right corner"] = "\228\189\160\229\143\175\228\187\165\231\130\185\229\135\187\229\143\179\228\184\138\232\167\146\231\154\132\229\155\190\230\160\135\230\137\147\229\188\128\232\143\156\229\141\149"
L["You have ignored followers"] = "\228\189\160\230\156\137\229\191\189\231\149\165\231\154\132\232\191\189\233\154\143\232\128\133"
L["You never performed this mission"] = "\228\189\160\228\187\142\230\156\170\230\137\167\232\161\140\232\191\153\228\184\170\228\187\187\229\138\161"
L["You performed this mission %d times with a win ratio of"] = "\228\189\160\230\137\167\232\161\140\232\191\153\228\184\170\228\187\187\229\138\161 %d \230\172\161\239\188\140\230\136\144\229\138\159\231\142\135\228\184\186"

	end
	L=l:NewLocale(me,"esES")
	if (L) then
--[[Translation missing --]]
--[[ L["%s |4follower:followers; with %s"] = ""--]] 
--[[Translation missing --]]
--[[ L["(Ignores low bias ones)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Add %1$d levels to %2$s"] = ""--]] 
--[[Translation missing --]]
--[[ L["Adds a list of other useful followers to tooltip"] = ""--]] 
--[[Translation missing --]]
--[[ L["Affects only little screen mode, hiding the per follower mission list if not checked"] = ""--]] 
--[[Translation missing --]]
--[[ L["Allowed Rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applied when 'maximize result' is enabled. Default is 80%"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best armor set"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best armor upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best weapon set"] = ""--]] 
--[[Translation missing --]]
--[[ L["Applies the best weapon upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Archaelogy"] = ""--]] 
--[[Translation missing --]]
--[[ L["Big screen"] = ""--]] 
--[[Translation missing --]]
--[[ L["Blacklisted"] = ""--]] 
--[[Translation missing --]]
--[[ L["Blacklisted missions are ignored in Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Building Final report"] = ""--]] 
--[[Translation missing --]]
--[[ L["Capped %1$s. Spend at least %2$d of them"] = ""--]] 
--[[Translation missing --]]
--[[ L["Complete all missions without confirmation"] = ""--]] 
--[[Translation missing --]]
--[[ L["Consider again"] = ""--]] 
--[[Translation missing --]]
--[[ L["Disable if you dont want the full Garrison Commander Header."] = ""--]] 
--[[Translation missing --]]
--[[ L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = ""--]] 
--[[Translation missing --]]
--[[ L["Do not show follower icon on plots"] = ""--]] 
--[[Translation missing --]]
--[[ L["Duration Time"] = ""--]] 
--[[Translation missing --]]
--[[ L["Enhance tooltip"] = ""--]] 
--[[Translation missing --]]
--[[ L["Environment Preference"] = ""--]] 
--[[Translation missing --]]
--[[ L["Epic followers are NOT sent alone on xp only missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Expiration Time"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower equipment set or upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower experience"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower set minimum upgrade"] = ""--]] 
--[[Translation missing --]]
--[[ L["Follower Training"] = ""--]] 
--[[Translation missing --]]
--[[ L["Followers status "] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Appearance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Comander Quick Mission Completion"] = ""--]] 
--[[Translation missing --]]
--[[ L["Garrison Commander Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Global approx. xp reward"] = ""--]] 
--[[Translation missing --]]
--[[ L["Global success chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Gold incremented!"] = ""--]] 
--[[Translation missing --]]
--[[ L["Hide followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = ""--]] 
--[[Translation missing --]]
--[[ L["IF checked, shows armors on the left and weapons on the right "] = ""--]] 
--[[Translation missing --]]
--[[ L["If you continue, you will lose them"] = ""--]] 
--[[Translation missing --]]
--[[ L["IF you have a Salvage Yard you probably dont want to have this one checked"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore \"maxed\""] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore epic for xp missions."] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore for all missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore for this mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["Ignore rare missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Increased Rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Item minimum level"] = ""--]] 
--[[Translation missing --]]
--[[ L["Item Tokens"] = ""--]] 
--[[Translation missing --]]
--[[ L["Left Click to see available missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Legendary Items"] = ""--]] 
--[[Translation missing --]]
--[[ L["Level 100 epic followers are not used for xp only missions."] = ""--]] 
--[[Translation missing --]]
--[[ L["Makes main mission panel movable"] = ""--]] 
--[[Translation missing --]]
--[[ L["Makes shipyard panel movable"] = ""--]] 
--[[Translation missing --]]
--[[ L["Maximize result"] = ""--]] 
--[[Translation missing --]]
--[[ L["Maximum mission duration."] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum mission duration."] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum needed chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum requested level for equipment rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimum requested upgrade for followers set (Enhancements are always included)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minimun chance success under which ignore missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Minumum needed chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Control"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Duration"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission shown for follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission Success"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission time reduced!"] = ""--]] 
--[[Translation missing --]]
--[[ L["Mission with lower success chance will be ignored"] = ""--]] 
--[[Translation missing --]]
--[[ L["Missionlist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Must reload interface to apply"] = ""--]] 
--[[Translation missing --]]
--[[ L["No confirmation"] = ""--]] 
--[[Translation missing --]]
--[[ L["No follower gained xp"] = ""--]] 
--[[Translation missing --]]
--[[ L["No mission prefill"] = ""--]] 
--[[Translation missing --]]
--[[ L["Not blacklisted"] = ""--]] 
--[[Translation missing --]]
--[[ L["Nothing to report"] = ""--]] 
--[[Translation missing --]]
--[[ L["Number of followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Only first %1$d missions with over %2$d%% chance of success are shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Only meaningful upgrades are shown"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original concept and interface by %s"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original method"] = ""--]] 
--[[Translation missing --]]
--[[ L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other rewards"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other settings"] = ""--]] 
--[[Translation missing --]]
--[[ L["Other useful followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Processing mission %d of %d"] = ""--]] 
--[[Translation missing --]]
--[[ L["Profession"] = ""--]] 
--[[Translation missing --]]
--[[ L["Racial Preference"] = ""--]] 
--[[Translation missing --]]
--[[ L["Rare missions will not be considered"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reagents"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reputation Items"] = ""--]] 
--[[Translation missing --]]
--[[ L["Reward type"] = ""--]] 
--[[Translation missing --]]
--[[ L["Right-Click to blacklist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Right-Click to remove from blacklist"] = ""--]] 
--[[Translation missing --]]
--[[ L["Rush orders"] = ""--]] 
--[[Translation missing --]]
--[[ L["Shipyard Appearance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show Garrison Commander menu"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show itemlevel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show upgrades"] = ""--]] 
--[[Translation missing --]]
--[[ L["Show xp"] = ""--]] 
--[[Translation missing --]]
--[[ L["Slayer"] = ""--]] 
--[[Translation missing --]]
--[[ L["Some follower"] = ""--]] 
--[[Translation missing --]]
--[[ L["Sort missions by:"] = ""--]] 
--[[Translation missing --]]
--[[ L["Submit all your mission at once. No question asked."] = ""--]] 
--[[Translation missing --]]
--[[ L["Success Chance"] = ""--]] 
--[[Translation missing --]]
--[[ L["Swap upgrades positions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Switch between Garrison Commander and Master Plan interface for missions"] = ""--]] 
--[[Translation missing --]]
--[[ L["Threat Counter"] = ""--]] 
--[[Translation missing --]]
--[[ L["To go: %d"] = ""--]] 
--[[Translation missing --]]
--[[ L["Toggles Garrison Commander Menu Header on/off"] = ""--]] 
--[[Translation missing --]]
--[[ L["Toys and Mounts"] = ""--]] 
--[[Translation missing --]]
--[[ L["Unchecking this will allow you to set specific success chance for each reward type"] = ""--]] 
--[[Translation missing --]]
--[[ L["Unlock Panel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Upgrade %1$s to  %2$d itemlevel"] = ""--]] 
--[[Translation missing --]]
--[[ L["Upgrading to |cff00ff00%d|r"] = ""--]] 
--[[Translation missing --]]
--[[ L["Use big screen"] = ""--]] 
--[[Translation missing --]]
--[[ L["Use GC Interface"] = ""--]] 
--[[Translation missing --]]
--[[ L["Uses armor token"] = ""--]] 
--[[Translation missing --]]
--[[ L["Uses weapon token"] = ""--]] 
--[[Translation missing --]]
--[[ L["When checked, show on each follower button missing xp to next level"] = ""--]] 
--[[Translation missing --]]
--[[ L["When checked, show on each follower button weapon and armor level for maxed followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["Xp incremented!"] = ""--]] 
--[[Translation missing --]]
--[[ L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = ""--]] 
--[[Translation missing --]]
--[[ L["You can also send mission one by one clicking on each button."] = ""--]] 
--[[Translation missing --]]
--[[ L["You can open the menu clicking on the icon in top right corner"] = ""--]] 
--[[Translation missing --]]
--[[ L["You have ignored followers"] = ""--]] 
--[[Translation missing --]]
--[[ L["You never performed this mission"] = ""--]] 
--[[Translation missing --]]
--[[ L["You performed this mission %d times with a win ratio of"] = ""--]] 

	end
	L=l:NewLocale(me,"zhTW")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4\232\191\189\233\154\168\232\128\133:\232\191\189\233\154\168\232\128\133; \230\156\137 %s"
L["(Ignores low bias ones)"] = "(\229\191\189\231\149\165\228\189\142\231\173\137\229\129\143\229\165\189\231\154\132)"
L["Add %1$d levels to %2$s"] = "\229\162\158\229\138\160 %1$d \231\173\137\231\180\154\229\136\176 %2$s"
L["Adds a list of other useful followers to tooltip"] = "\229\156\168\229\183\165\229\133\183\230\143\144\231\164\186\229\162\158\229\138\160\229\133\182\228\187\150\230\156\137\231\148\168\231\154\132\232\191\189\233\154\168\232\128\133\230\184\133\229\150\174"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "\229\143\170\229\189\177\233\159\191\229\176\143\232\158\162\229\185\149\230\168\161\229\188\143\239\188\140\229\166\130\230\158\156\230\156\170\229\139\190\233\129\184\229\137\135\233\154\177\232\151\143\230\175\143\229\128\139\232\191\189\233\154\168\232\128\133\231\154\132\228\187\187\229\139\153\230\184\133\229\150\174"
L["Allowed Rewards"] = "\229\133\129\232\168\177\231\154\132\231\141\142\229\139\181"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "\229\133\129\232\168\177\228\189\142\230\136\144\229\138\159\231\142\135\231\154\132\232\179\135\230\186\144\228\187\187\229\139\153\227\128\130\228\189\191\231\148\168/gac gui\228\190\134\230\148\185\232\174\138\231\153\190\229\136\134\230\175\148\227\128\130\233\160\144\232\168\173\231\130\18680%"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "\229\143\170\229\156\168'\230\156\128\229\164\167\229\140\150\231\181\144\230\158\156'\229\149\159\231\148\168\230\153\130\229\189\177\233\159\191\239\188\140\233\160\144\232\168\173\231\130\18680%"
L["Applies the best armor set"] = "\230\135\137\231\148\168\229\156\168\230\156\128\228\189\179\232\173\183\231\148\178\228\184\138"
L["Applies the best armor upgrade"] = "\230\135\137\231\148\168\229\156\168\230\156\128\228\189\179\232\173\183\231\148\178\229\141\135\231\180\154\228\184\138"
L["Applies the best weapon set"] = "\230\135\137\231\148\168\229\156\168\230\156\128\228\189\179\230\173\166\229\153\168\228\184\138"
L["Applies the best weapon upgrade"] = "\230\135\137\231\148\168\229\156\168\230\156\128\228\189\179\230\173\166\229\153\168\229\141\135\231\180\154\228\184\138"
L["Archaelogy"] = "\232\128\131\229\143\164\229\173\184"
L["Big screen"] = "\229\164\167\232\158\162\229\185\149"
L["Blacklisted"] = "\229\136\151\229\133\165\233\187\145\229\144\141\229\150\174"
L["Blacklisted missions are ignored in Mission Control"] = "\233\187\145\229\144\141\229\150\174\228\184\173\231\154\132\228\187\187\229\139\153\230\156\131\229\156\168\228\187\187\229\139\153\230\142\167\229\136\182\228\184\173\229\191\189\231\149\165"
L["Building Final report"] = "\230\173\163\229\156\168\229\187\186\231\171\139\231\184\189\231\181\144\229\160\177\229\145\138"
L["Capped %1$s. Spend at least %2$d of them"] = "%1$s\229\183\178\231\182\147\230\187\191\228\186\134\239\188\140\232\135\179\229\176\145\230\156\131\230\181\170\232\178\187 %2$d \229\128\139\227\128\130"
L["Complete all missions without confirmation"] = "\229\174\140\230\136\144\230\137\128\230\156\137\228\187\187\229\139\153\228\184\141\233\160\136\231\162\186\232\170\141"
L["Consider again"] = "\229\134\141\230\172\161\232\128\131\233\135\143"
L["Disable if you dont want the full Garrison Commander Header."] = "\229\166\130\230\158\156\230\130\168\228\184\141\230\131\179\232\166\129\229\174\140\230\149\180\231\154\132Garrison Commander\230\168\153\233\161\140\229\143\175\228\187\165\229\129\156\231\148\168"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "\229\143\150\230\182\136\232\135\170\229\139\149\229\136\134\230\180\190\229\156\168\228\187\187\229\139\153\233\160\129\231\175\169\233\129\184\227\128\130\230\130\168\228\185\159\229\143\175\228\187\165\229\156\168\229\150\174\228\184\128\228\187\187\229\139\153\228\184\138\233\187\158\230\147\138Ctrl\228\190\134\229\143\150\230\182\136\227\128\130"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "\229\143\150\230\182\136\230\173\164\230\156\131\231\181\166\230\130\1681.1.8\228\187\165\228\190\134\231\154\132\228\187\139\233\157\162\239\188\140\231\181\166\228\186\136\230\136\150\229\143\150\229\190\151\227\128\130\233\156\128\232\166\129\233\135\141\232\188\137UI\227\128\130"
L["Do not show follower icon on plots"] = "\228\184\141\229\156\168\231\173\150\231\149\171\228\184\138\233\161\175\231\164\186\232\191\189\233\154\168\232\128\133\229\156\150\231\164\186"
L["Duration Time"] = "\230\140\129\231\186\140\230\153\130\233\150\147"
L["Enhance tooltip"] = "\229\162\158\229\188\183\230\143\144\231\164\186"
L["Environment Preference"] = "\231\146\176\229\162\131\229\129\143\229\165\189"
L["Epic followers are NOT sent alone on xp only missions"] = "\229\143\178\232\169\169\232\191\189\233\154\168\232\128\133\"\228\184\141\"\230\156\131\229\150\174\231\141\168\230\180\190\231\153\188\229\136\176\229\143\170\230\156\137\231\182\147\233\169\151\229\128\188\231\154\132\228\187\187\229\139\153"
L["Expiration Time"] = "\233\129\142\230\156\159\230\153\130\233\150\147"
L["Follower"] = "\232\191\189\233\154\168\232\128\133"
L["Follower equipment set or upgrade"] = "\232\191\189\233\154\168\232\128\133\232\163\157\229\130\153\229\165\151\232\163\157\230\136\150\229\141\135\231\180\154"
L["Follower experience"] = "\232\191\189\233\154\168\232\128\133\231\182\147\233\169\151"
L["Follower set minimum upgrade"] = "\232\191\189\233\154\168\232\128\133\229\165\151\232\163\157\230\156\128\229\176\143\231\154\132\229\141\135\231\180\154"
L["Follower Training"] = "\232\191\189\233\154\168\232\128\133\232\168\147\231\183\180"
L["Followers status "] = "\232\191\189\233\154\168\232\128\133\231\139\128\230\133\139"
L["Garrison Appearance"] = "\232\166\129\229\161\158\229\164\150\232\167\128"
L["Garrison Comander Quick Mission Completion"] = "Garrison Comander\228\187\187\229\139\153\229\191\171\233\128\159\229\174\140\230\136\144"
L["Garrison Commander Mission Control"] = "Garrison Commander\228\187\187\229\139\153\230\142\167\229\136\182"
L["Global approx. xp reward"] = "\233\128\154\231\148\168\229\164\167\231\180\132\231\154\132\231\182\147\233\169\151\229\128\188\231\141\142\232\179\158"
L["Global success chance"] = "\229\133\168\229\177\128\230\136\144\229\138\159\230\169\159\231\142\135"
L["Gold incremented!"] = "\233\187\131\233\135\145\229\162\158\229\138\160\239\188\129"
L["Hide followers"] = "\233\154\177\232\151\143\232\191\189\233\154\168\232\128\133"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[\229\166\130\230\158\156\229\139\190\233\129\184\239\188\140\230\140\137\228\184\128\228\184\139\229\141\135\231\180\154\229\156\150\231\164\186\229\176\135\228\189\191\231\148\168\232\169\178\231\137\169\229\147\129\229\146\140\229\141\135\231\180\154\232\191\189\233\154\168\232\128\133
|cFFFF0000\228\184\141\233\160\136\231\162\186\232\170\141|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "\229\166\130\230\158\156\229\139\190\233\129\184\239\188\140\233\161\175\231\164\186\232\173\183\231\148\178\229\156\168\229\183\166\230\173\166\229\153\168\229\156\168\229\143\179"
L["If you continue, you will lose them"] = "\229\166\130\230\158\156\230\130\168\231\185\188\231\186\140\239\188\140\230\130\168\230\156\131\229\164\177\229\142\187\229\174\131\229\128\145"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "\229\166\130\230\158\156\230\130\168\230\156\137\229\155\158\230\148\182\229\187\160\229\143\175\232\131\189\228\184\141\230\131\179\232\166\129\229\139\190\233\129\184\230\173\164\233\129\184\233\160\133"
L["Ignore \"maxed\""] = "\229\191\189\231\149\165\"\230\187\191\231\180\154\231\154\132\""
L["Ignore epic for xp missions."] = "\229\191\189\231\149\165\229\143\178\232\169\169\231\182\147\233\169\151\228\187\187\229\139\153\227\128\130"
L["Ignore for all missions"] = "\229\191\189\231\149\165\230\137\128\230\156\137\228\187\187\229\139\153"
L["Ignore for this mission"] = "\229\191\189\231\149\165\230\173\164\228\187\187\229\139\153"
L["Ignore rare missions"] = "\229\191\189\231\149\165\231\168\128\230\156\137\228\187\187\229\139\153"
L["Increased Rewards"] = "\230\143\144\233\171\152\231\141\142\229\139\181"
L["Item minimum level"] = "\231\137\169\229\147\129\230\156\128\229\176\143\231\173\137\231\180\154"
L["Item Tokens"] = "\231\137\169\229\147\129\233\129\147\229\133\183"
L["Left Click to see available missions"] = "\229\183\166\233\141\181\233\187\158\230\147\138\228\187\165\230\170\162\232\166\150\229\143\175\231\148\168\228\187\187\229\139\153"
L["Legendary Items"] = "\229\130\179\229\165\135\231\137\169\229\147\129"
L["Level 100 epic followers are not used for xp only missions."] = "\231\173\137\231\180\154100\231\154\132\229\143\178\232\169\169\232\191\189\233\154\168\232\128\133\228\184\141\230\156\131\231\148\168\229\156\168\229\143\170\230\156\137\231\182\147\233\169\151\229\128\188\231\154\132\228\187\187\229\139\153\227\128\130"
L["Makes main mission panel movable"] = "\232\174\147\228\184\187\228\187\187\229\139\153\233\157\162\230\157\191\229\143\175\231\167\187\229\139\149"
L["Makes shipyard panel movable"] = "\232\174\147\232\136\185\229\161\162\233\157\162\230\157\191\229\143\175\231\167\187\229\139\149"
L["Maximize result"] = "\230\156\128\229\164\167\229\140\150\231\181\144\230\158\156"
L["Maximum mission duration."] = "\230\156\128\229\164\167\228\187\187\229\139\153\230\140\129\231\186\140\230\153\130\233\150\147\227\128\130"
L["Minimum chance"] = "\230\156\128\229\176\143\230\169\159\231\142\135"
L["Minimum mission duration."] = "\230\156\128\229\176\143\228\187\187\229\139\153\230\140\129\231\186\140\230\153\130\233\150\147\227\128\130"
L["Minimum needed chance"] = "\230\156\128\229\176\143\233\156\128\232\166\129\231\154\132\230\169\159\231\142\135"
L["Minimum requested level for equipment rewards"] = "\232\163\157\229\130\153\231\141\142\229\139\181\230\156\128\229\176\143\233\156\128\230\177\130\231\173\137\231\180\154"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "\232\191\189\233\154\168\232\128\133\229\165\151\232\163\157\230\156\128\229\176\143\233\156\128\230\177\130\229\141\135\231\180\154(\229\162\158\229\188\183\231\137\169\229\147\129\230\156\131\230\176\184\233\129\160\229\140\133\229\144\171\229\156\168\229\133\167)"
L["Minimun chance success under which ignore missions"] = "\228\189\142\230\150\188\229\164\154\229\176\145\230\136\144\229\138\159\230\169\159\231\142\135\231\154\132\228\187\187\229\139\153\232\166\129\232\162\171\229\191\189\231\149\165"
L["Minumum needed chance"] = "\230\156\128\229\176\143\233\156\128\230\177\130\230\169\159\231\142\135"
L["Mission Control"] = "\228\187\187\229\139\153\230\142\167\229\136\182"
L["Mission Duration"] = "\228\187\187\229\139\153\230\140\129\231\186\140\230\153\130\233\150\147"
L["Mission shown"] = "\228\187\187\229\139\153\233\161\175\231\164\186"
L["Mission shown for follower"] = "\228\187\187\229\139\153\228\184\138\233\161\175\231\164\186\232\191\189\233\154\168\232\128\133"
L["Mission Success"] = "\228\187\187\229\139\153\230\136\144\229\138\159"
L["Mission time reduced!"] = "\228\187\187\229\139\153\230\153\130\233\150\147\231\184\174\231\159\173\239\188\129"
L["Mission with lower success chance will be ignored"] = "\228\189\142\230\150\188\230\173\164\230\136\144\229\138\159\230\169\159\231\142\135\231\154\132\228\187\187\229\139\153\229\176\135\230\156\131\229\191\189\231\149\165"
L["Missionlist"] = "\228\187\187\229\139\153\229\136\151\232\161\168"
L["Must reload interface to apply"] = "\233\156\128\232\166\129\233\135\141\232\188\137UI\228\187\165\231\148\159\230\149\136"
L["No confirmation"] = "\228\184\141\231\162\186\232\170\141"
L["No follower gained xp"] = "\230\178\146\230\156\137\232\191\189\233\154\168\232\128\133\231\141\178\229\190\151\231\182\147\233\169\151\229\128\188"
L["No mission prefill"] = "\230\178\146\230\156\137\233\160\144\231\181\132\231\154\132\228\187\187\229\139\153"
L["Not blacklisted"] = "\233\157\158\233\187\145\229\144\141\229\150\174"
L["Nothing to report"] = "\230\178\146\228\187\128\233\186\188\229\165\189\229\160\177\229\145\138"
L["Number of followers"] = "\232\191\189\233\154\168\232\128\133\230\149\184\233\135\143"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "\229\143\170\230\156\137\233\171\152\230\150\188%2$d%%\230\136\144\229\138\159\230\169\159\231\142\135\231\154\132\229\137\141%1$d\228\187\187\229\139\153\230\156\131\233\161\175\231\164\186"
L["Only meaningful upgrades are shown"] = "\229\143\170\230\156\137\230\152\142\233\161\175\231\154\132\229\141\135\231\180\154\230\137\141\230\156\131\233\161\175\231\164\186"
L["Original concept and interface by %s"] = "\229\142\159\229\167\139\230\166\130\229\191\181\232\136\135\228\187\139\233\157\162\229\190\158%s"
L["Original method"] = "\229\142\159\229\167\139\231\154\132\230\150\185\230\179\149"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "\229\142\159\229\167\139\230\142\146\229\186\143\229\176\135\230\129\162\229\190\169\229\142\159\229\167\139\230\142\146\229\186\143\230\150\185\230\179\149\239\188\140\228\184\141\231\174\161\229\174\131\230\152\175\228\187\128\233\186\188(\229\166\130\230\158\156\228\189\160\230\156\137\229\143\166\228\184\128\229\128\139\230\143\146\228\187\182\230\142\146\229\186\143\228\187\187\229\139\153\239\188\140\229\174\131\230\135\137\232\169\178\229\134\141\229\149\159\229\139\149)"
L["Other"] = "\229\133\182\228\187\150"
L["Other rewards"] = "\229\133\182\228\187\150\231\141\142\229\139\181"
L["Other settings"] = "\229\133\182\228\187\150\232\168\173\229\174\154"
L["Other useful followers"] = "\229\133\182\228\187\150\230\156\137\231\148\168\231\154\132\232\191\189\233\154\168\232\128\133"
L["Processing mission %d of %d"] = "\232\153\149\231\144\134\228\184\173\228\187\187\229\139\153%d\231\154\132%d"
L["Profession"] = "\232\129\183\230\165\173"
L["Racial Preference"] = "\231\168\174\230\151\143\229\129\143\229\165\189"
L["Rare missions will not be considered"] = "\231\168\128\230\156\137\228\187\187\229\139\153\228\184\141\232\162\171\232\128\131\230\133\174"
L["Reagents"] = "\232\179\135\230\186\144"
L["Reputation Items"] = "\232\129\178\230\156\155\231\137\169\229\147\129"
L["Reward type"] = "\231\141\142\229\139\181\233\161\158\229\158\139"
L["Right-Click to blacklist"] = "\229\143\179\233\141\181\233\187\158\230\147\138\229\138\160\229\133\165\233\187\145\229\144\141\229\150\174"
L["Right-Click to remove from blacklist"] = "\229\143\179\233\141\181\233\187\158\230\147\138\229\190\158\233\187\145\229\144\141\229\150\174\231\167\187\233\153\164"
L["Rush orders"] = "\232\182\149\229\183\165\232\168\130\229\150\174"
L["Shipyard Appearance"] = "\232\136\185\229\161\162\229\164\150\232\167\128"
L["Show Garrison Commander menu"] = "\233\161\175\231\164\186Garrison Commander\233\129\184\229\150\174"
L["Show itemlevel"] = "\233\161\175\231\164\186\231\137\169\229\147\129\231\173\137\231\180\154"
L["Show upgrades"] = "\233\161\175\231\164\186\229\141\135\231\180\154"
L["Show xp"] = "\233\161\175\231\164\186\231\182\147\233\169\151\229\128\188"
L["Slayer"] = "\230\174\186\230\137\139"
L["Some follower"] = "\230\159\144\228\186\155\232\191\189\233\154\168\232\128\133"
L["Sort missions by:"] = "\230\142\146\229\186\143\228\187\187\229\139\153\228\190\157\230\147\154\239\188\154"
L["Submit all your mission at once. No question asked."] = "\228\184\128\230\172\161\230\180\190\233\129\163\230\130\168\230\137\128\230\156\137\231\154\132\228\187\187\229\139\153\227\128\130\231\132\161\233\160\136\231\162\186\232\170\141\227\128\130"
L["Success Chance"] = "\230\136\144\229\138\159\230\169\159\231\142\135"
L["Swap upgrades positions"] = "\228\186\164\230\143\155\229\141\135\231\180\154\228\189\141\231\189\174"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "\229\156\168Garrison Commander\232\136\135Master Plan\231\154\132\228\187\187\229\139\153\228\187\139\233\157\162\228\184\173\229\136\135\230\143\155"
L["Threat Counter"] = "\229\168\129\232\132\133\229\143\141\229\136\182"
L["To go: %d"] = "\233\130\132\233\156\128\232\166\129\239\188\154%d"
L["Toggles Garrison Commander Menu Header on/off"] = "\229\136\135\230\143\155Garrison Commander\233\129\184\229\150\174\230\168\153\233\161\140 \233\150\139/\233\151\156"
L["Toys and Mounts"] = "\231\142\169\229\133\183\232\136\135\229\157\144\233\168\142"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "\229\143\150\230\182\136\229\139\190\233\129\184\229\143\175\228\187\165\229\133\129\232\168\177\230\130\168\231\130\186\230\175\143\231\168\174\231\141\142\229\139\181\233\161\158\229\158\139\232\168\173\229\174\154\231\137\185\229\174\154\231\154\132\230\136\144\229\138\159\230\169\159\231\142\135"
L["Unlock Panel"] = "\232\167\163\233\142\150\233\157\162\230\157\191"
L["Upgrade %1$s to  %2$d itemlevel"] = "\229\141\135\231\180\154%1$s\229\136\176%2$d\231\137\169\229\147\129\231\173\137\231\180\154"
L["Upgrading to |cff00ff00%d|r"] = "\229\141\135\231\180\154\229\136\176 |cff00ff00%d|r"
L["Use big screen"] = "\228\189\191\231\148\168\229\164\167\232\158\162\229\185\149"
L["Use GC Interface"] = "\228\189\191\231\148\168GC\228\187\139\233\157\162"
L["Uses armor token"] = "\228\189\191\231\148\168\232\173\183\231\148\178\233\129\147\229\133\183"
L["Uses weapon token"] = "\228\189\191\231\148\168\230\173\166\229\153\168\233\129\147\229\133\183"
L["When checked, show on each follower button missing xp to next level"] = "\231\149\182\229\139\190\233\129\184\229\190\140\239\188\140\233\161\175\231\164\186\230\175\143\229\128\139\232\191\189\233\154\168\232\128\133\229\136\176\228\184\139\228\184\128\231\173\137\231\180\154\230\137\128\233\156\128\231\154\132\231\182\147\233\169\151\229\128\188"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "\231\149\182\229\139\190\233\129\184\229\190\140\239\188\140\233\161\175\231\164\186\230\175\143\229\128\139\230\187\191\231\180\154\232\191\189\233\154\168\232\128\133\230\173\166\229\153\168\232\136\135\232\173\183\231\148\178\231\173\137\231\180\154\231\154\132\230\140\137\233\136\149"
L["Xp incremented!"] = "\231\182\147\233\169\151\229\128\188\229\162\158\229\138\160\239\188\129"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "\230\130\168\230\181\170\232\178\187\228\186\134|cffff0000%d|cffffd200 \233\187\158\230\149\184!!!"
L["You can also send mission one by one clicking on each button."] = "\230\130\168\228\185\159\229\143\175\228\187\165\233\128\143\233\129\142\233\187\158\230\147\138\230\175\143\229\128\139\230\140\137\233\136\149\228\184\128\229\128\139\228\184\128\229\128\139\230\180\190\233\129\163\227\128\130"
L["You can open the menu clicking on the icon in top right corner"] = "\230\130\168\229\143\175\228\187\165\233\187\158\230\147\138\229\143\179\228\184\138\232\167\146\231\154\132\229\156\150\231\164\186\228\187\165\233\150\139\229\149\159\233\129\184\229\150\174"
L["You have ignored followers"] = "\230\130\168\230\156\137\229\191\189\231\149\165\231\154\132\232\191\189\233\154\168\232\128\133"
L["You never performed this mission"] = "\230\130\168\230\156\170\230\155\190\229\159\183\232\161\140\233\128\153\229\128\139\228\187\187\229\139\153"
L["You performed this mission %d times with a win ratio of"] = "\230\130\168\229\159\183\232\161\140\233\129\142\230\173\164\228\187\187\229\139\153 %d\230\172\161\228\184\166\228\184\148\230\136\144\229\138\159\230\169\159\231\142\135\230\156\137"

	end
end
L=LibStub("AceLocale-3.0"):GetLocale(me,true)

